@@ -3,6 +3,7 @@
 #ifndef ANNOTATEVALUES_H
 #define ANNOTATEVALUES_H
 
+#include <qdom.h>
 #include "Point.h"
 
 class AnnotateValues
@@ -12,7 +13,9 @@ public:
 	void draw(QPainter *p,int X, int Y, double x, double y, double z=0);	// draw to p @ X,Y using values x,y,z
 	void save(QTextStream *t);
 	void open(QTextStream *t, int version);
-	
+	QDomElement saveXML(QDomDocument doc);
+	void openXML(QDomNode node);
+
 	int Type() { return type; }
 	void setType(int t) { type=t; }
 	int Position() { return position; }
