@@ -8,21 +8,29 @@
 #include <kconfig.h>
 #include <knuminput.h>
 #include "MainWin.h"
+#include "Dialog.h"
 
 class ConfigureDialog: public KDialogBase
 {
 	Q_OBJECT
 public:
-	ConfigureDialog(MainWin *mw, const char *name, KConfig *config);
+	ConfigureDialog(MainWin *m, KConfig *config);
 private slots:
+	void selectFont();
 	void apply_clicked();
 	void ok_clicked();
 private:
+	MainWin *mw;
+	Dialog *dialog;
 	KConfig *config;
 	QRadioButton *fullscreen, *cascade;
+	QCheckBox *originalsize, *ps2eps, *ps2pdf;
+	KIntNumInput *recentnr;
 	QRadioButton *color, *grayscale;
 	KComboBox *pagesize, *orientation;
-	QCheckBox *autosave;
-	KIntNumInput *asIntervalInput;
+	QCheckBox *autosave, *auto_original, *speedmode, *keydatamode;
+	KIntNumInput *asIntervalInput, *speedmodevalue;
+	QFont defaultfont;	// local var for default font
+	KLineEdit *fontle;
 };
 #endif //CONFIGUREDIALOG_H
