@@ -18,6 +18,7 @@
 #include "Worksheet.h"
 
 #include "inputfilter.h"
+#include "binarytype.h"
 
 #ifdef HAVE_GL
 #include "qwt3d_surfaceplot.h"
@@ -30,12 +31,14 @@ public:
 	Dialog(class MainWin *mw, const char *name);
 	QVBox* surfaceStyle(QTabWidget *tw, bool fresh);
 	QVBox* simpleStyle(QTabWidget *tw, Style *style, Symbol *symbol);
+	QVBox* errorbarTab(QTabWidget *tw, Symbol *symbol);
 	void saveSimpleStyle();
 	void saveSurfaceStyle();
+	void saveErrorbarSettings();
 public slots:
-	void setDestination(int d) {sheetcb->setCurrentItem(d); }		//!< set current destination for new functions
-	void setFilename(QString f) { filele->setText(f); }			//!< set filename for import widget
-	void setFilter(int f) { filtercb->setCurrentItem(f); }			//!< set filter for importing
+	void setDestination(int v) {sheetcb->setCurrentItem(v); }		//!< set current destination for new functions
+	void setFilename(QString v) { filele->setText(v); }			//!< set filename for import widget
+	void setFilter(int v) { filtercb->setCurrentItem(v); }			//!< set filter for importing
 	void setSimplify(bool b=true) { simplifycb->setChecked(b); }		//!< set simplify whitespaces
 	void setEmpty(bool b=true) { emptycb->setChecked(b); }			//!< allow empty entries in data file
 	void setImportHeader(bool b=true) { headercb->setChecked(b); }		//!< import header from data file
@@ -47,21 +50,23 @@ public slots:
 	void setDataRange(int v, int e) { startle->setText(QString::number(v)); endle->setText(QString::number(e)); }
 										//!< set range for importing data
 	void setStart(int v) {startle->setText(QString::number(v));}
-	void setEnd(int e) {endle->setText(QString::number(e));}
+	void setEnd(int v) {endle->setText(QString::number(v));}
 
 	// binary data
 	void setVars(int v) { varle->setText(QString::number(v)); }		//!< number of vars for binary data
 	void setBinaryType(int t) { binarytypecb->setCurrentItem(t); }		//!< set type for binary data
-	
+	void setByteOrder(int b) { byteordercb->setCurrentItem(b); }		//!< set byte order of binary data
+
 	void setStyle(Style *s);						//!< set Style
 	void setSymbol(Symbol *s);						//!< set Symbol
 protected:
 	void resizeEvent(QResizeEvent *e);
 	QVBox* annotateValuesTab(QTabWidget *tw, Graph *graph);
-       	void importWidget(QVBox *vb,QString filename,InputFilter filter);
+       	void importWidget(QVBox *vb,QString filename, InputFilter filter);
 	void saveImportSettings();
-	double getBinaryValue(QDataStream *d, int type);
+	double getBinaryValue(QDataStream *d, BinaryType type);
 	bool openColorMap(QString fn);
+	void fillBrushBox(KComboBox *cb,SType t, QColor c,FType f, QColor s);
 	QGroupBox *vbox, *gbox;
 	class MainWin *mw;
 	class Worksheet *p;
@@ -71,6 +76,7 @@ protected:
 #endif
 	KPushButton *ok, *apply, *save, *cancel;
 	KLineEdit *filele;						// used from various dialogs
+	QLabel *fileinfo;
 	KComboBox *cb2, *pencb, *brushcb, *sbrushcb;			// simple
 	KComboBox *symbolcb, *symbolfillcb;				// simple
 	KColorButton *color, *fcolor, *scolor, *sfcolor;		// simple
@@ -80,17 +86,22 @@ protected:
 	KLineEdit *numberle, *thresholdle;					// surface
 	KComboBox *dbrushcb;							// surface
 	KColorButton *contourcolor;						// surface
+	KLineEdit *contourwidthle;						// surface
 	KComboBox *typecb, *positioncb;						// annotatetab
 	KIntNumInput *distance;							// annotatetab
+	KColorButton *ebarcolor, *ebarbcolor;					// errorbar
+	KIntNumInput *ebarxsize, *ebarysize, *ebarwidth, *ebarbwidth;		// errorbar
+	KComboBox *ebarstylecb, *ebarbstylecb, *ebarxtypecb, *ebarytypecb;	// errorbar
 	QCheckBox *simplifycb, *emptycb, *headercb, *samexcb;			// importWidget
 	QLabel *seplabel, *commlabel, *startlabel, *endlabel;			// importWidget
 	KLineEdit *startle, *endle;						// importWidget
 	KComboBox *filtercb, *sccb, *commcb;					// importWidget
-	QLabel *varlabel, *binarytypelabel;					// importWidget : binary
+	QLabel *varlabel, *binarytypelabel, *byteorderlabel;			// importWidget : binary
+	KComboBox *binarytypecb, *byteordercb;					// importWidget : binary
 	KLineEdit *varle;
-	KComboBox *binarytypecb;
 	KComboBox *sheetcb;					// for destination selection (list dialogs+function/data dialog)
 protected slots:
+	void updateFileInfo();
 	void selectFile();
 	void fileInfo();
 	void selectColormap();
@@ -98,7 +109,6 @@ protected slots:
 	void updateFilter(int item);
 	QStringList splitLine(QString line,QString sep, bool empty);
 private:
-	void fillBrushBox(KComboBox *cb,SType t, QColor c,FType f, QColor s);
 	void fillSymbolBox(QColor c, FType f, QColor s, int b);
 	void fillSymbolFillBox(SType t, QColor c, QColor s, int b);
 private slots:
