@@ -28,9 +28,9 @@ DifferencesListDialog::DifferencesListDialog(MainWin *mw, const char *name)
 	tw->addTab(styletab,i18n("Style"));
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
-        QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	save->setEnabled(false);
-	
+
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
@@ -42,7 +42,7 @@ int DifferencesListDialog::apply_clicked() {
 	if(s) {
 		QTable *table = s->Table();
 		int col = table->currentColumn();
-		
+
 		// add column if needed
 		bool empty = true;
 		for(int i=0;i<table->numRows();i++) {
@@ -55,11 +55,11 @@ int DifferencesListDialog::apply_clicked() {
 		int newcol = table->numCols()-1;
 		for (int i = 0;i<table->numRows()-1;i++) {
 			// insert into last column
-			table->setText(i,newcol,QString::number(table->text(i+1,col).toDouble()-table->text(i,col).toDouble()));
+			table->setText(i,newcol,QString::number(table->text(i+1,col).toDouble() - table->text(i,col).toDouble()));
 		}
 		return 0;
 	}
-	
+
 	GraphList *gl = p->getPlot(p->API())->getGraphList();
 	if(gl->Number()==0) {
 		KMessageBox::error(this,i18n("No graph found!"));
@@ -67,12 +67,12 @@ int DifferencesListDialog::apply_clicked() {
 	}
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
 
-	GRAPHType st = gl->getStruct(item);
-	
+	GRAPHType st = gl->getType(item);
+
 	Style *style=0;
 	Symbol *symbol=0;
 	if(st != GRAPHM) {
-		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
+		style = new Style((StylesType)cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
 			width->value(),pencb->currentItem(),brushcb->currentItem());
 		style->setBoxWidth(boxwidth->value());
 		style->setAutoBoxWidth(autobox->isChecked());
@@ -119,7 +119,7 @@ int DifferencesListDialog::apply_clicked() {
 
 			ptr[i].setPoint(x,y,z);
 		}
-		
+
 		mw->calculateRanges3D(ptr,nx-1,&xmin,&xmax,&ymin,&ymax,&zmin,&zmax);
 
 		LRange range[3];
@@ -149,7 +149,7 @@ int DifferencesListDialog::apply_clicked() {
 		}
 
 		mw->calculateRanges4D(ptr,nx-1,&xmin,&xmax,&ymin,&ymax,&zmin,&zmax,&tmin,&tmax);
-		
+
 		LRange range[4];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
