@@ -17,6 +17,7 @@
 #include <ktempfile.h>
 #include "ExportDialog.h"
 #include "FilterCDF.h"
+#include "FilterHDF5.h"
 #include "FilterAUDIOFILE.h"
 #include "Plot2DSurface.h"
 #include "export.h"
@@ -24,7 +25,9 @@
 #ifdef HAVE_CDF
 #include <cdf.h>
 #endif
+#ifdef HAVE_NETCDF
 #include <netcdf.h>
+#endif
 #include <audiofile.h>
 #ifdef HAVE_MAGICK
 #include <Magick++.h>
@@ -39,7 +42,7 @@ ExportDialog::ExportDialog(MainWin *mw, const char *name, int item)
 	setCaption(i18n("Export Data")+i18n(" : ")+QString(name));
 	KConfig *config = mw->Config();
 	config->setGroup( "Export" );
-	
+
 	plot=0;
 	if(item>=0) {
 		Worksheet *w = mw->activeWorksheet();
@@ -47,7 +50,6 @@ ExportDialog::ExportDialog(MainWin *mw, const char *name, int item)
 			plot = w->getPlot(w->API());
 	}
 
-
 	QHBox *hb = new QHBox(vbox);
 	new QLabel(i18n("Filename (append .gz or .bz2 for compression) : "),hb);
 	hb = new QHBox(vbox);
@@ -63,7 +65,7 @@ ExportDialog::ExportDialog(MainWin *mw, const char *name, int item)
 	}
 	else
 			headercb=0;
-	
+
 	hb = new QHBox(vbox);
 	new QLabel(i18n("Start Row : "),hb);
 	startrow = new KLineEdit(config->readEntry("Startrow","1"),hb);
@@ -74,17 +76,17 @@ ExportDialog::ExportDialog(MainWin *mw, const char *name, int item)
 
 	hb = new QHBox(vbox);
 	new QLabel(i18n("Export to : "),hb);
-        exportcb = new KComboBox(hb);
-//	if ( (plot && plot->Type() == PSURFACE) || item == -1) 
+	exportcb = new KComboBox(hb);
+//	if ( (plot && plot->Type() == PSURFACE) || item == -1)
 //		elist<<i18n("IMAGE");
 	exportcb->insertStrList(exports);
 	QObject::connect(exportcb,SIGNAL(activated (int)),SLOT(updateOptions(int)));
 	exportcb->setCurrentItem(config->readNumEntry("Format",0));
-	
+
 	// ASCII	TODO : use SEPARATOR
 	hb = new QHBox(vbox);
 	slabel = new QLabel(i18n("Separating character : "),hb);
-        sc= new KComboBox(hb);
+	sc= new KComboBox(hb);
 	QStringList slist;
 	slist << i18n("SPACE");
 	slist << i18n("TAB");
@@ -93,13 +95,12 @@ ExportDialog::ExportDialog(MainWin *mw, const char *name, int item)
 	sc->setCurrentItem(config->readNumEntry("SeparatingCharacter",0));
 
 	// IMAGE
-	hb = new QHBox(vbox);
 	flabel = new QLabel(i18n("Format : "),hb);
-        ic = new KComboBox(hb);
+	ic = new KComboBox(hb);
 	QStringList ilist;
-	
+
 	for ( unsigned int i = 0; i < QImageIO::outputFormats().count(); i++ ) {
-        	QString str = QString( QImageIO::outputFormats().at( i ) );
+		QString str = QString( QImageIO::outputFormats().at( i ) );
 		ilist<<str;
 	}
 
@@ -121,30 +122,27 @@ ExportDialog::ExportDialog(MainWin *mw, const char *name, int item)
 
 #ifdef HAVE_CDF
 	// cdf
-	hb = new QHBox(vbox);
 	cdfcomlabel = new QLabel(i18n("Compression : "),hb);
-        cdfcomcb = new KComboBox(hb);
+	cdfcomcb = new KComboBox(hb);
 	QStringList clist;
 	FilterCDF cdf;
 	for ( unsigned int i = 0; i < 6; i++ )
-        	clist << cdf.Comp(i);
+		clist << cdf.Comp(i);
 	cdfcomcb->insertStringList(clist);
 	cdfcomcb->setCurrentItem(config->readNumEntry("CDFCompression",0));
 
-	hb = new QHBox(vbox);
 	cdfenclabel = new QLabel(i18n("Encoding : "),hb);
-        cdfenccb = new KComboBox(hb);
+	cdfenccb = new KComboBox(hb);
 	QStringList enclist;
 	for ( unsigned int i = 1; i < 17; i++ )
-        	enclist << cdf.Enc(i);
+		enclist << cdf.Enc(i);
 	cdfenccb->insertStringList(enclist);
 	cdfenccb->setCurrentItem(config->readNumEntry("CDFEncoding",0));
 #endif
-	
+
 	// netcdf : nothing
-	
+
 	// audio
-	hb = new QHBox(vbox);
 	audioformatlabel = new QLabel(i18n("Format : "),hb);
 	audioformatcb= new KComboBox(hb);
 	QStringList alist;
@@ -160,25 +158,49 @@ ExportDialog::ExportDialog(MainWin *mw, const char *name, int item)
 	samplele->setValidator(new QIntValidator(samplele));
 
 	// binary
-	hb = new QHBox(vbox);
-        binarytypecb= new KComboBox(hb);
+	// TODO : byte order
+	binarytypecb = new KComboBox(hb);
 	QStringList blist;
 	blist<<QString("double")<<QString("float")<<QString("long");
 	blist<<QString("int (8 Bit)")<<QString("int (16 Bit)")<<QString("int (32 Bit)")<<QString("int (64 Bit)");
 	binarytypecb->insertStringList(blist);
 	binarytypecb->setCurrentItem(config->readNumEntry("BinaryType",0));
+	hb = new QHBox(vbox);
+	byteorderlabel = new QLabel(i18n("Byte Order : "),hb);
+	byteordercb = new KComboBox(hb);
+	QStringList bytelist;
+	bytelist<<i18n("big endian")<<i18n("little endian");
+	byteordercb->insertStringList(bytelist);
+	byteordercb->setCurrentItem(config->readBoolEntry("ByteOrder",1));
+
+#ifdef HAVE_HDF5
+	hdf5allcb = new QCheckBox(i18n("Export All Spreadsheets"),hb);
+	hdf5allcb->setChecked(config->readBoolEntry("HDF5All",true));
+	hb = new QHBox(vbox);
+	hdf5datatypecb= new KComboBox(hb);
+	QStringList hlist;
+	hlist<<QString("double")<<QString("int")<<QString("char");
+	hdf5datatypecb->insertStringList(hlist);
+	hdf5datatypecb->setCurrentItem(config->readNumEntry("HDF5Datatype",0));
+	hb = new QHBox(vbox);
+	hdf5ordercb= new KComboBox(hb);
+	QStringList holist;
+	holist<<QString("little endian")<<QString("big endian");
+	hdf5ordercb->insertStringList(holist);
+	hdf5ordercb->setCurrentItem(config->readNumEntry("HDF5Order",0));
+#endif
 
 	// TODO : only selected region
-	
+
 	updateOptions(0);
-	
+
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
-	
+
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
-	resize(minimumSize());
+	resize(minimumSize().width(),(int)(1.2*minimumSize().height()));
 }
 
 void ExportDialog::saveSettings() {
@@ -198,6 +220,10 @@ void ExportDialog::saveSettings() {
 	config->writeEntry("AudioFormat",audioformatcb->currentItem());
 	config->writeEntry("SampleRate",samplele->text());
 	config->writeEntry("BinaryType",binarytypecb->currentItem());
+	config->writeEntry("ByteOrder",byteordercb->currentItem());
+	config->writeEntry("HDF5All",hdf5allcb->isChecked());
+	config->writeEntry("HDF5Datatype",hdf5datatypecb->currentItem());
+	config->writeEntry("HDF5Order",hdf5ordercb->currentItem());
 }
 
 //! update options when changing exported format
@@ -215,12 +241,17 @@ void ExportDialog::updateOptions(int item) {
 	audioformatlabel->hide();audioformatcb->hide();
 	samplelabel->hide();samplele->hide();
 	binarytypecb->hide();
+	byteorderlabel->hide();
+	byteordercb->hide();
+	hdf5datatypecb->hide();
+	hdf5ordercb->hide();
+	hdf5allcb->hide();
 	QString filename =  filele->text();
-	
+
 	switch(item) {
-	case EASCII: 
-		slabel->show();sc->show(); 
-		filename.replace( QRegExp(QString("[.]+.*")), ".dat" );	
+	case EASCII:
+		slabel->show();sc->show();
+		filename.replace( QRegExp(QString("[.]+.*")), ".dat" );
 		break;
 #ifdef HAVE_CDF
 	case ECDF:
@@ -242,17 +273,25 @@ void ExportDialog::updateOptions(int item) {
 		filename.replace( QRegExp(QString("[.]+.*")), "." + ic->currentText().lower() );
 		break;
 	case EBINARY:
-		filename.replace( QRegExp(QString("[.]+.*")), ".bin" );	
+		filename.replace( QRegExp(QString("[.]+.*")), ".bin" );
 		audioformatlabel->show();
 		binarytypecb->show();
+		byteorderlabel->show();
+		byteordercb->show();
 		break;
 	case EKEXIDB:
 		filele->setReadOnly(true);
 		startrow->setReadOnly(true);
 		endrow->setReadOnly(true);
 		break;
+	case EHDF5:
+		filename.replace( QRegExp(QString("[.]+.*")), ".h5" );
+		hdf5allcb->show();
+		hdf5datatypecb->show();
+		hdf5ordercb->show();
+		break;
 	}
-        
+
 	filele->setText(filename);
 }
 
@@ -268,7 +307,7 @@ int ExportDialog::apply_clicked() {
 
 	// check if file exists
 	if ( QFile::exists(filename) ) {
-		int answer = KMessageBox::warningYesNoCancel( this, 
+		int answer = KMessageBox::warningYesNoCancel( this,
 			i18n( "Overwrite\n\'%1\'?" ).arg( filename ), i18n("Export data"));
 		if (answer != KMessageBox::Yes)
 			return 1;
@@ -298,7 +337,7 @@ int ExportDialog::apply_clicked() {
 			KMessageBox::error(this, i18n("Sorry. Could not open file for writing!"));
 			return 0;
 		}
-	
+
 		if(format == EASCII)
 			t.setDevice(file);
 		else if (format == EBINARY)
@@ -312,7 +351,8 @@ int ExportDialog::apply_clicked() {
 	case EAUDIO: 	dumpAUDIOFILE(filename); break;
 	case EIMAGE: dumpIMAGE(filename); break;
 	case EBINARY: dumpBINARY(&d); break;
-	case EKEXIDB: dumpKexiDB(); break;	
+	case EKEXIDB: dumpKexiDB(); break;
+	case EHDF5: dumpHDF5(filename); break;
 	}
 
 	if(file) file->close();
@@ -344,18 +384,18 @@ void ExportDialog::dumpASCII(QTextStream *t, QString sep) {
 				*t<<table->text(i,j);
 			}
 			*t<<endl;
-		}	
+		}
 	}
 	else {			// exporting data from GRAPH
 		GraphList *gl = plot->getGraphList();
-		GRAPHType st =  gl->getStruct(item);
+		GRAPHType st =  gl->getType(item);
 		switch(st) {
 		case GRAPH2D: {
 			Graph2D *g = gl->getGraph2D(item);
 			Point *ptr=g->Data();
 			for (int i=start-1;i<g->Number();i++) {
 				if(end>0 && i>end) return;
-				
+
 				*t<<ptr[i].X()<<sep<<ptr[i].Y()<<endl;
 			}}
 			break;
@@ -364,7 +404,7 @@ void ExportDialog::dumpASCII(QTextStream *t, QString sep) {
 			Point3D *ptr=g->Data();
 			for (int i=start-1;i< g->NX()*g->NY();i++) {
 				if(end>0 && i>end) return;
-			
+
 				*t<<ptr[i].X()<<sep<<ptr[i].Y()<<sep<<ptr[i].Z()<<endl;
 			}}
 			break;
@@ -373,7 +413,7 @@ void ExportDialog::dumpASCII(QTextStream *t, QString sep) {
 			Point4D *ptr=g->Data();
 			for (int i=start-1;i< g->Number();i++) {
 				if(end>0 && i>end) return;
-			
+
 				*t<<ptr[i].X()<<sep<<ptr[i].Y()<<sep<<ptr[i].Z()<<sep<<ptr[i].T()<<endl;
 			}}
 			break;
@@ -381,7 +421,7 @@ void ExportDialog::dumpASCII(QTextStream *t, QString sep) {
 			GraphM *g = gl->getGraphM(item);
 			double *array = g->Data();
 			int nx=g->NX(), ny = g->NY();
-		
+
 			for (int i=0;i<ny;i++) {
 				for (int j=0;j<nx;j++) {
 					if(j>0)
@@ -431,12 +471,12 @@ void ExportDialog::dumpCDF(QString filename) {
 		case 5: parms[0]=9;
 	}
 	CDFlib(PUT_,CDF_COMPRESSION_,(long) cdfcomcb->currentItem(),parms);
-	
+
 	static long varys[1]={NOVARY};
 	long indices[1]={0};
 	long varnum1,varnum2,varnum3,varnum4;
 	double v;
-	
+
 	if(item<0) {		// exporting data from spreadsheet
 		kdDebug()<<"exporting spreadsheet "<<endl;
 		Spreadsheet *s = mw->activeSpreadsheet();
@@ -450,11 +490,11 @@ void ExportDialog::dumpCDF(QString filename) {
 				v=table->text(i+start,j).toDouble();
 				CDFvarPut(id,varnum,i,indices,&v);
 			}
-		}	
+		}
 	}
 	else {
 		GraphList *gl = plot->getGraphList();
-		GRAPHType st =  gl->getStruct(item);
+		GRAPHType st =  gl->getType(item);
 		switch(st) {
 		case GRAPH2D: {
 			Graph2D *g = gl->getGraph2D(item);
@@ -528,7 +568,7 @@ void ExportDialog::dumpCDF(QString filename) {
 		default:	break;
 		}
 	}
-	
+
 	CDFclose(id);
 #else
 	KMessageBox::warningContinueCancel(this,i18n("Sorry. Your Installation doesn't support CDF!"));
@@ -536,6 +576,7 @@ void ExportDialog::dumpCDF(QString filename) {
 }
 
 void ExportDialog::dumpNETCDF(QString filename) {
+#ifdef HAVE_NETCDF
 	int start = startrow->text().toInt()-1;
 	int end = endrow->text().toInt();
 
@@ -560,11 +601,11 @@ void ExportDialog::dumpNETCDF(QString filename) {
 		int varid[table->numCols()];
 #endif
 		double *data = new double[N];
-		
+
 		for (int j=0;j<table->numCols();j++)
 			nc_def_var(ncid,s->columnTitle(j).latin1(),NC_DOUBLE, 1, dimids, &varid[j] );
 		nc_enddef(ncid);
-		
+
 		for (int j=0;j<table->numCols();j++) {
 			for(int i=start;i<end;i++)
 				data[i-start]=table->text(i,j).toDouble();
@@ -573,7 +614,7 @@ void ExportDialog::dumpNETCDF(QString filename) {
 	}
 	else {
 		GraphList *gl = plot->getGraphList();
-		GRAPHType st =  gl->getStruct(item);
+		GRAPHType st =  gl->getType(item);
 		switch(st) {
 		case GRAPH2D: {
 			Graph2D *g = gl->getGraph2D(item);
@@ -581,7 +622,7 @@ void ExportDialog::dumpNETCDF(QString filename) {
 			int nr = g->Number();
 			if (end==0) end=nr;
 			int N = end - start;
-		
+
 			int dimid;
 			nc_def_dim(ncid,"vector",N,&dimid);
 			int xvarid, yvarid;
@@ -605,7 +646,7 @@ void ExportDialog::dumpNETCDF(QString filename) {
 			int nr = g->Number();
 			if (end==0) end=nr;
 			int N = end - start;
-		
+
 			int dimid;
 			nc_def_dim(ncid,"vector",N,&dimid);
 			int xvarid, yvarid, zvarid;
@@ -633,7 +674,7 @@ void ExportDialog::dumpNETCDF(QString filename) {
 			int nr = g->Number();
 			if (end==0) end=nr;
 			int N = end - start;
-		
+
 			int dimid;
 			nc_def_dim(ncid,"vector",N,&dimid);
 			int xvarid, yvarid, zvarid, tvarid;
@@ -663,7 +704,7 @@ void ExportDialog::dumpNETCDF(QString filename) {
 			GraphM *g = gl->getGraphM(item);
 			double *data=g->Data();
 			int nx = g->NX(), ny = g->NY();
-		
+
 			// TODO : export array
 			int xdimid, ydimid;
 			nc_def_dim(ncid,"x",nx,&xdimid);
@@ -672,7 +713,7 @@ void ExportDialog::dumpNETCDF(QString filename) {
 			int dimids[2]={xdimid,ydimid};
 			nc_def_var(ncid,"value",NC_DOUBLE, 2, dimids, &varid );
 			nc_enddef(ncid);
-			
+
 			nc_put_var_double(ncid,varid,data);
 			} break;
 		case GRAPHIMAGE : {
@@ -681,8 +722,9 @@ void ExportDialog::dumpNETCDF(QString filename) {
 		default : break;
 		}
 	}
-		
+
 	nc_close(ncid);
+#endif
 }
 
 void ExportDialog::dumpAUDIOFILE(QString filename) {
@@ -704,14 +746,14 @@ void ExportDialog::dumpAUDIOFILE(QString filename) {
 		if (end==0) end=table->numRows();
 		int N = end - start;
 
-		if(table->numCols()<2) 
+		if(table->numCols()<2)
 			return;
 		else if(table->numCols()==2) {	// mono
 			afInitChannels(setup, AF_DEFAULT_TRACK, 1);
 			af = afOpenFile(filename.latin1(),"w",setup);
 
 			short *data = new short[N];	// frameCount=1(mono),2(stereo)
-		
+
 			for(int i=start;i<end;i++)
 				data[i-start] = table->text(i-start,1).toInt();
 
@@ -733,22 +775,22 @@ void ExportDialog::dumpAUDIOFILE(QString filename) {
 	}
 	else {
 		GraphList *gl = plot->getGraphList();
-		GRAPHType st =  gl->getStruct(item);
+		GRAPHType st =  gl->getType(item);
 		switch(st) {
 		case GRAPH2D: {
 			Graph2D *g = gl->getGraph2D(item);
 			Point *ptr=g->Data();
 			if (end==0) end=g->Number();
 			int N = end - start;
-	
+
 			afInitChannels(setup, AF_DEFAULT_TRACK, 1);
 			af = afOpenFile(filename.latin1(),"w",setup);
-	
+
 			short *data = new short[N];	// frameCount=1(mono),2(stereo)
-		
+
 			for(int i=start;i<end;i++)
 				data[i-start] = (int) ptr[i].Y();
-	
+
 			afWriteFrames(af,AF_DEFAULT_TRACK,(void *) data, N);
 			} break;
 		case GRAPH3D: {
@@ -756,23 +798,23 @@ void ExportDialog::dumpAUDIOFILE(QString filename) {
 			Point3D *ptr=g->Data();
 			if (end==0) end=g->Number();
 			int N = end - start;
-	
+
 			afInitChannels(setup, AF_DEFAULT_TRACK, 2);
 			af = afOpenFile(filename.latin1(),"w",setup);
-	
+
 			short *data = new short[2*N];
-			
+
 			for(int i=start;i<end;i++) {
 				data[2*i-start] = (int) ptr[i].Y();
 				data[2*i+1-start] = (int) ptr[i].Z();
 			}
-					
+
 			afWriteFrames(af,AF_DEFAULT_TRACK,(void *) data, N);
 			} break;
 		default: break;
 		}
 	}
-	
+
 	afCloseFile(af);
 #endif
 }
@@ -806,11 +848,11 @@ void ExportDialog::dumpIMAGE(QString filename) {
 			tmpfile->setAutoDelete(true);
 			QString tmpname = tmpfile->name();
 			image->save(tmpname,"BMP");
-				
+
 			// read into Image
 			Image im;
 			im.read(tmpname.latin1());
-			
+
 			im.magick(ic->currentText().latin1());
 			im.write(filename.latin1());
 		}
@@ -818,12 +860,12 @@ void ExportDialog::dumpIMAGE(QString filename) {
 	}
 	else {		// export GRAPH
 		GraphList *gl = plot->getGraphList();
-		GRAPHType st = gl->getStruct(item);
-	
+		GRAPHType st = gl->getType(item);
+
 		if(st == GRAPHIMAGE) {
 			GraphIMAGE *g = gl->getGraphIMAGE(item);
 			QPixmap pm = g->Pixmap();
-	
+
 #ifdef HAVE_MAGICK
 			if(!pm.save(filename,ic->currentText())) {
 				// save in tmp file
@@ -831,11 +873,11 @@ void ExportDialog::dumpIMAGE(QString filename) {
 				tmpfile->setAutoDelete(true);
 				QString tmpname = tmpfile->name();
 				pm.save(tmpname,"BMP");
-				
+
 				// read into Image
 				Image image;
 				image.read(tmpname.latin1());
-				
+
 				image.magick(ic->currentText().latin1());
 				image.write(filename.latin1());
 			}
@@ -844,17 +886,17 @@ void ExportDialog::dumpIMAGE(QString filename) {
 		else {
 			GraphM *g = gl->getGraphM(item);
 			double *array = g->Data();
-			int nx=g->NX(), ny = g->NY();	
+			int nx=g->NX(), ny = g->NY();
 			LRange range = g->Range(2);
 			Plot2DSurface *plot2 =(Plot2DSurface *) plot;
-		
+
 			// depth = 8, numColors = 256
 			QImage *image = new QImage(nx,ny,8,256);
 			for (int i=0;i<256;i++) {
 				QColor c = plot2->Color(i);
 				image->setColor (i, c.rgb() );
 			}
-	
+
 			for (int i=0;i<nx;i++) {
 				for (int j=0;j<ny;j++) {
 					unsigned int value =  (int)((array[j+ny*i]-range.rMin())/(range.rMax()-range.rMin())*255.0);
@@ -868,11 +910,11 @@ void ExportDialog::dumpIMAGE(QString filename) {
 				tmpfile->setAutoDelete(true);
 				QString tmpname = tmpfile->name();
 				image->save(tmpname,"BMP");
-				
+
 				// read into Image
 				Image im;
 				im.read(tmpname.latin1());
-				
+
 				im.magick(ic->currentText().latin1());
 				im.write(filename.latin1());
 			}
@@ -885,12 +927,14 @@ void ExportDialog::dumpIMAGE(QString filename) {
 void ExportDialog::dumpBINARY(QDataStream *d) {
 	int start = startrow->text().toInt();
 	int end = endrow->text().toInt();
-	
+
+	d->setByteOrder(byteordercb->currentItem());
+
 	if(item<0) {		// exporting data from spreadsheet
 		kdDebug()<<"exporting spreadsheet "<<endl;
 	 	QTable *table = mw->activeSpreadsheet()->Table();
-		// export header ???
-/*		if(headercb->isChecked()) {
+/*		// export header ???
+		if(headercb->isChecked()) {
 			for(int i=0;i<table->numCols();i++) {
 				if(i>0) *t<<sep;
 				*t<<table->horizontalHeader()->label(i);
@@ -903,35 +947,35 @@ void ExportDialog::dumpBINARY(QDataStream *d) {
 			if(end>0 && i>=end) return;
 			for(int j=0;j<table->numCols();j++) {
 				switch(binarytypecb->currentItem()) {
-				case 0: *d<<table->text(i,j).toDouble(); break;
-				case 1: *d<<table->text(i,j).toFloat(); break;
-				case 2: *d<<table->text(i,j).toLong(); break;
-				case 3: *d<<(Q_INT8)table->text(i,j).toDouble(); break;
-				case 4: *d<<(Q_INT16)table->text(i,j).toDouble(); break;
-				case 5: *d<<(Q_INT32)table->text(i,j).toDouble(); break;
-				case 6: *d<<(Q_INT64)table->text(i,j).toDouble(); break;
+				case BDOUBLE: *d<<table->text(i,j).toDouble(); break;
+				case BFLOAT: *d<<table->text(i,j).toFloat(); break;
+				case BLONG: *d<<table->text(i,j).toLong(); break;
+				case BINT8: *d<<(Q_INT8)table->text(i,j).toDouble(); break;
+				case BINT16: *d<<(Q_INT16)table->text(i,j).toDouble(); break;
+				case BINT32: *d<<(Q_INT32)table->text(i,j).toDouble(); break;
+				case BINT64: *d<<(Q_INT64)table->text(i,j).toDouble(); break;
 				}
 			}
-		}	
+		}
 	}
 	else {			// exporting data from GRAPH
 		GraphList *gl = plot->getGraphList();
-		GRAPHType st =  gl->getStruct(item);
+		GRAPHType st =  gl->getType(item);
 		switch(st) {
 		case GRAPH2D: {
 			Graph2D *g = gl->getGraph2D(item);
 			Point *ptr=g->Data();
 			for (int i=start-1;i<g->Number();i++) {
 				if(end>0 && i>end) return;
-				
+
 				switch(binarytypecb->currentItem()) {
-				case 0: *d<<ptr[i].X()<<ptr[i].Y(); break;
-				case 1: *d<<(float)ptr[i].X()<<(float)ptr[i].Y(); break;
-				case 2: *d<<(Q_LONG)ptr[i].X()<<(Q_LONG)ptr[i].Y(); break;
-				case 3: *d<<(Q_INT8)ptr[i].X()<<(Q_INT8)ptr[i].Y(); break;
-				case 4: *d<<(Q_INT16)ptr[i].X()<<(Q_INT16)ptr[i].Y(); break;
-				case 5: *d<<(Q_INT32)ptr[i].X()<<(Q_INT32)ptr[i].Y(); break;
-				case 6: *d<<(Q_INT64)ptr[i].X()<<(Q_INT64)ptr[i].Y(); break;
+				case BDOUBLE: *d<<ptr[i].X()<<ptr[i].Y(); break;
+				case BFLOAT: *d<<(float)ptr[i].X()<<(float)ptr[i].Y(); break;
+				case BLONG: *d<<(Q_LONG)ptr[i].X()<<(Q_LONG)ptr[i].Y(); break;
+				case BINT8: *d<<(Q_INT8)ptr[i].X()<<(Q_INT8)ptr[i].Y(); break;
+				case BINT16: *d<<(Q_INT16)ptr[i].X()<<(Q_INT16)ptr[i].Y(); break;
+				case BINT32: *d<<(Q_INT32)ptr[i].X()<<(Q_INT32)ptr[i].Y(); break;
+				case BINT64: *d<<(Q_INT64)ptr[i].X()<<(Q_INT64)ptr[i].Y(); break;
 				}
 			}}
 			break;
@@ -940,15 +984,15 @@ void ExportDialog::dumpBINARY(QDataStream *d) {
 			Point3D *ptr=g->Data();
 			for (int i=start-1;i< g->NX()*g->NY();i++) {
 				if(end>0 && i>end) return;
-				
+
 				switch(binarytypecb->currentItem()) {
-				case 0: *d<<ptr[i].X()<<ptr[i].Y()<<ptr[i].Z(); break;
-				case 1: *d<<(float)ptr[i].X()<<(float)ptr[i].Y()<<(float)ptr[i].Z(); break;
-				case 2: *d<<(Q_LONG)ptr[i].X()<<(Q_LONG)ptr[i].Y()<<(Q_LONG)ptr[i].Z(); break;
-				case 3: *d<<(Q_INT8)ptr[i].X()<<(Q_INT8)ptr[i].Y()<<(Q_INT8)ptr[i].Z(); break;
-				case 4: *d<<(Q_INT16)ptr[i].X()<<(Q_INT16)ptr[i].Y()<<(Q_INT16)ptr[i].Z(); break;
-				case 5: *d<<(Q_INT32)ptr[i].X()<<(Q_INT32)ptr[i].Y()<<(Q_INT32)ptr[i].Z(); break;
-				case 6: *d<<(Q_INT64)ptr[i].X()<<(Q_INT64)ptr[i].Y()<<(Q_INT64)ptr[i].Z(); break;
+				case BDOUBLE: *d<<ptr[i].X()<<ptr[i].Y()<<ptr[i].Z(); break;
+				case BFLOAT: *d<<(float)ptr[i].X()<<(float)ptr[i].Y()<<(float)ptr[i].Z(); break;
+				case BLONG: *d<<(Q_LONG)ptr[i].X()<<(Q_LONG)ptr[i].Y()<<(Q_LONG)ptr[i].Z(); break;
+				case BINT8: *d<<(Q_INT8)ptr[i].X()<<(Q_INT8)ptr[i].Y()<<(Q_INT8)ptr[i].Z(); break;
+				case BINT16: *d<<(Q_INT16)ptr[i].X()<<(Q_INT16)ptr[i].Y()<<(Q_INT16)ptr[i].Z(); break;
+				case BINT32: *d<<(Q_INT32)ptr[i].X()<<(Q_INT32)ptr[i].Y()<<(Q_INT32)ptr[i].Z(); break;
+				case BINT64: *d<<(Q_INT64)ptr[i].X()<<(Q_INT64)ptr[i].Y()<<(Q_INT64)ptr[i].Z(); break;
 				}
 			}}
 			break;
@@ -957,15 +1001,15 @@ void ExportDialog::dumpBINARY(QDataStream *d) {
 			Point4D *ptr=g->Data();
 			for (int i=start-1;i< g->Number();i++) {
 				if(end>0 && i>end) return;
-			
+
 				switch(binarytypecb->currentItem()) {
-				case 0: *d<<ptr[i].X()<<ptr[i].Y()<<ptr[i].Z()<<ptr[i].T(); break;
-				case 1: *d<<(float)ptr[i].X()<<(float)ptr[i].Y()<<(float)ptr[i].Z()<<(float)ptr[i].T(); break;
-				case 2: *d<<(Q_LONG)ptr[i].X()<<(Q_LONG)ptr[i].Y()<<(Q_LONG)ptr[i].Z()<<(Q_LONG)ptr[i].T(); break;
-				case 3: *d<<(Q_INT8)ptr[i].X()<<(Q_INT8)ptr[i].Y()<<(Q_INT8)ptr[i].Z()<<(Q_INT8)ptr[i].T(); break;
-				case 4: *d<<(Q_INT16)ptr[i].X()<<(Q_INT16)ptr[i].Y()<<(Q_INT16)ptr[i].Z()<<(Q_INT16)ptr[i].T(); break;
-				case 5: *d<<(Q_INT32)ptr[i].X()<<(Q_INT32)ptr[i].Y()<<(Q_INT32)ptr[i].Z()<<(Q_INT32)ptr[i].T(); break;
-				case 6: *d<<(Q_INT64)ptr[i].X()<<(Q_INT64)ptr[i].Y()<<(Q_INT64)ptr[i].Z()<<(Q_INT64)ptr[i].T(); break;
+				case BDOUBLE: *d<<ptr[i].X()<<ptr[i].Y()<<ptr[i].Z()<<ptr[i].T(); break;
+				case BFLOAT: *d<<(float)ptr[i].X()<<(float)ptr[i].Y()<<(float)ptr[i].Z()<<(float)ptr[i].T(); break;
+				case BLONG: *d<<(Q_LONG)ptr[i].X()<<(Q_LONG)ptr[i].Y()<<(Q_LONG)ptr[i].Z()<<(Q_LONG)ptr[i].T(); break;
+				case BINT8: *d<<(Q_INT8)ptr[i].X()<<(Q_INT8)ptr[i].Y()<<(Q_INT8)ptr[i].Z()<<(Q_INT8)ptr[i].T(); break;
+				case BINT16: *d<<(Q_INT16)ptr[i].X()<<(Q_INT16)ptr[i].Y()<<(Q_INT16)ptr[i].Z()<<(Q_INT16)ptr[i].T(); break;
+				case BINT32: *d<<(Q_INT32)ptr[i].X()<<(Q_INT32)ptr[i].Y()<<(Q_INT32)ptr[i].Z()<<(Q_INT32)ptr[i].T(); break;
+				case BINT64: *d<<(Q_INT64)ptr[i].X()<<(Q_INT64)ptr[i].Y()<<(Q_INT64)ptr[i].Z()<<(Q_INT64)ptr[i].T(); break;
 				}
 			}}
 			break;
@@ -973,17 +1017,17 @@ void ExportDialog::dumpBINARY(QDataStream *d) {
 			GraphM *g = gl->getGraphM(item);
 			double *array = g->Data();
 			int nx=g->NX(), ny = g->NY();
-		
+
 			for (int i=0;i<ny;i++) {
 				for (int j=0;j<nx;j++) {
 					switch(binarytypecb->currentItem()) {
-					case 0: *d<<array[j+nx*i]; break;
-					case 1: *d<<(float)array[j+nx*i]; break;
-					case 2: *d<<(Q_LONG)array[j+nx*i]; break;
-					case 3: *d<<(Q_INT8)array[j+nx*i]; break;
-					case 4: *d<<(Q_INT16)array[j+nx*i]; break;
-					case 5: *d<<(Q_INT32)array[j+nx*i]; break;
-					case 6: *d<<(Q_INT64)array[j+nx*i]; break;
+					case BDOUBLE: *d<<array[j+nx*i]; break;
+					case BFLOAT: *d<<(float)array[j+nx*i]; break;
+					case BLONG: *d<<(Q_LONG)array[j+nx*i]; break;
+					case BINT8: *d<<(Q_INT8)array[j+nx*i]; break;
+					case BINT16: *d<<(Q_INT16)array[j+nx*i]; break;
+					case BINT32: *d<<(Q_INT32)array[j+nx*i]; break;
+					case BINT64: *d<<(Q_INT64)array[j+nx*i]; break;
 					}
 				}
 			}}
@@ -996,28 +1040,38 @@ void ExportDialog::dumpBINARY(QDataStream *d) {
 			for (int i=0;i<pm.width();i++) {
 				for (int j=0;j<pm.height();j++) {
 					switch(binarytypecb->currentItem()) {
-					case 0: *d<<qGray(image.pixel(i,j)); break;
-					case 1: *d<<(float)qGray(image.pixel(i,j)); break;
-					case 2: *d<<(Q_LONG)qGray(image.pixel(i,j)); break;
-					case 3: *d<<(Q_INT8)qGray(image.pixel(i,j)); break;
-					case 4: *d<<(Q_INT16)qGray(image.pixel(i,j)); break;
-					case 5: *d<<(Q_INT32)qGray(image.pixel(i,j)); break;
-					case 6: *d<<(Q_INT64)qGray(image.pixel(i,j)); break;
+					case BDOUBLE: *d<<qGray(image.pixel(i,j)); break;
+					case BFLOAT: *d<<(float)qGray(image.pixel(i,j)); break;
+					case BLONG: *d<<(Q_LONG)qGray(image.pixel(i,j)); break;
+					case BINT8: *d<<(Q_INT8)qGray(image.pixel(i,j)); break;
+					case BINT16: *d<<(Q_INT16)qGray(image.pixel(i,j)); break;
+					case BINT32: *d<<(Q_INT32)qGray(image.pixel(i,j)); break;
+					case BINT64: *d<<(Q_INT64)qGray(image.pixel(i,j)); break;
 					}
 				}
 			}}
 			break;
 		default: break;
 		}
-	}	
+	}
+}
+
+void ExportDialog::dumpHDF5(QString filename) {
+#ifdef HAVE_HDF5
+	int start = startrow->text().toInt()-1;
+	int end = endrow->text().toInt();
+
+	FilterHDF5 hdf5 = FilterHDF5(filename);
+	hdf5.exportFile(mw,hdf5allcb->isChecked(),hdf5datatypecb->currentItem(),hdf5ordercb->currentItem(),start,end);
+#endif
 }
 
 void ExportDialog::wizardKexiDB(const QString &name) {
 	//same as ImportDialog::wizardKexiDB()
 	kdDebug()<<"ExportDialog::wizardKexiDB()"<<endl;
-	
+
 	int res;
-	if(name == i18n("Driver")) {	
+	if(name == i18n("Driver")) {
 		kdDebug()<<"	TAB Driver"<<endl;
 	}
 	else if(name == i18n("Connection")) {
@@ -1063,23 +1117,23 @@ void ExportDialog::finishKexiDB() {
 	//TODO : use this
 	int start = startrow->text().toInt();
 	int end = endrow->text().toInt();
-	
+
 	kdDebug()<<" CREATE TABLE "<<tablename<<endl;
 	kexi->initWrite();
-	
+
 	int rows=0, cols=0;
 	QString *data=0;
 	QStringList fieldlist;
 	if(item<0) {		// exporting data from spreadsheet
 		kdDebug()<<"exporting spreadsheet "<<endl;
 	 	QTable *table = mw->activeSpreadsheet()->Table();
-		
+
 		rows=table->numRows();
 		cols=table->numCols();
 		kdDebug()<<"	Rows/Cols="<<rows<<' '<<cols<<endl;
-		
+
 		data = new QString[rows*cols];
-		
+
 		// use header label
 #if QT_VERSION > 0x030007
 		for(int i=0;i<cols;i++) {
@@ -1098,7 +1152,7 @@ void ExportDialog::finishKexiDB() {
 	}
 	else {
 		GraphList *gl = plot->getGraphList();
-		GRAPHType st =  gl->getStruct(item);
+		GRAPHType st =  gl->getType(item);
 		switch(st) {
 		case GRAPH2D: {
 			Graph2D *g = gl->getGraph2D(item);
@@ -1161,7 +1215,7 @@ void ExportDialog::finishKexiDB() {
 			QImage image = pm.convertToImage();
 			cols=pm.width();
 			rows = pm.height();
-			
+
 			data = new QString[rows*cols];
 			for (int i=0;i<rows;i++) {
 				for (int j=0;j<cols;j++) {
@@ -1193,9 +1247,9 @@ void ExportDialog::dumpKexiDB() {
 
 	QWizard *wizard = new QWizard(this);
 	//TODO
-	QObject::connect(wizard,SIGNAL(selected(const QString &)),this,SLOT(wizardKexiDB(const QString&))); 
-	QObject::connect(wizard->finishButton(),SIGNAL(clicked()),this,SLOT(finishKexiDB())); 
-	
+	QObject::connect(wizard,SIGNAL(selected(const QString &)),this,SLOT(wizardKexiDB(const QString&)));
+	QObject::connect(wizard->finishButton(),SIGNAL(clicked()),this,SLOT(finishKexiDB()));
+
 	QVBox *page1 = new QVBox(wizard);
 	new QLabel(i18n("Please select driver : "),page1);
 	driver= new KComboBox(page1);
@@ -1203,9 +1257,9 @@ void ExportDialog::dumpKexiDB() {
 
 	wizard->addPage(page1,i18n("Driver"));
 	wizard->setHelpEnabled(page1,false);
-	
+
 	QVBox *page2 = new QVBox(wizard);
-	
+
 	connectionlabel = new QLabel("",page2);
 	new QLabel(i18n("Please provide connection informations  : "),page2);
 	QHBox *hb = new QHBox(page2);
@@ -1218,17 +1272,17 @@ void ExportDialog::dumpKexiDB() {
 	new QLabel(i18n("Password : "),hb);
 	password = new KLineEdit(i18n("mysql"),hb);
 	password->setEchoMode(QLineEdit::Password);
-	
+
 	wizard->addPage(page2,i18n("Connection"));
 	wizard->setHelpEnabled(page2,false);
-	
+
 	QVBox *page3 = new QVBox(wizard);
 	new QLabel(i18n("Please select database  : "),page3);
 	databases = new KComboBox(page3);
 	databases->setEditable(true);
 	wizard->addPage(page3,i18n("Database"));
 	wizard->setHelpEnabled(page3,false);
-	
+
 	QVBox *page4 = new QVBox(wizard);
 	tablelabel = new QLabel("",page4);
 	new QLabel(i18n("Please select table : "),page4);
