@@ -7,18 +7,16 @@
 
 #define BUFFER_FRAMES 4096
 
-FilterAUDIOFILE::FilterAUDIOFILE(QString filename)
-	: filename(filename)
+FilterAUDIOFILE::FilterAUDIOFILE(QString fn)
+	: filename(fn)
 {
+	fileok=false;
 #ifdef HAVE_AUDIOFILE
 	if(!filename.isEmpty()) {
 		file = afOpenFile(filename, "r", NULL);
-	
-		if (file == AF_NULL_FILEHANDLE)		// not an audio file or not readable
-			fileok=false;
-		else {
+
+		if (file != AF_NULL_FILEHANDLE) {	// an audio file and readable
 			fileok=true;
-		
 			format=afGetFileFormat(file,0);
 		}
 	}
@@ -40,15 +38,15 @@ QString FilterAUDIOFILE::Format(int f) {
 
 	return 0;
 }
- 
+
 double *FilterAUDIOFILE::Data() {
 #ifdef HAVE_AUDIOFILE
 	int format, width;
 	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
-	
+
 	int size = frameCount()*channelCount();
 	double *data = new double[size];
-	
+
 	switch(format) {
 	case AF_SAMPFMT_UNSIGNED:	// unsigned
 		switch(width) {
@@ -65,7 +63,7 @@ double *FilterAUDIOFILE::Data() {
 				kdDebug()<<" 1/2 : "<<data[2*i]<<'/'<<data[2*i+1]<<endl;
 			}
 			break;
-		case 16: {			
+		case 16: {
 			unsigned short *buffer = new unsigned short[size];
 			afReadFrames(file, AF_DEFAULT_TRACK,buffer,size);
 
@@ -104,12 +102,12 @@ double *FilterAUDIOFILE::Data() {
 	return 0;
 #endif
 }
- 
+
 QString FilterAUDIOFILE::sampleFormat() {
 #ifdef HAVE_AUDIOFILE
 	int format, width;
 	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
-	
+
 	switch(format) {
 	case AF_SAMPFMT_TWOSCOMP:
 		return i18n("two's complement");break;
@@ -119,10 +117,10 @@ QString FilterAUDIOFILE::sampleFormat() {
 		return i18n("float");break;
 	case AF_SAMPFMT_DOUBLE:
 		return i18n("double");break;
-		
+
 	}
 #endif
-		
+
 	return i18n("UNKNOWN");
 }
 
@@ -130,7 +128,7 @@ int FilterAUDIOFILE::sampleWidth() {
 #ifdef HAVE_AUDIOFILE
 	int format, width;
 	afGetVirtualSampleFormat(file, AF_DEFAULT_TRACK, &format,&width);
-	
+
 	return width;
 #else
 	return 0;
