@@ -35,8 +35,8 @@ extern "C" init arith_fncts[];
 using namespace std;
 
 /*! newtype -> new 3D Plot type*/
-FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int item, PType newtype)
-	: Dialog(mw, name), l(l), item(item)
+FunctionDialog::FunctionDialog(MainWin *m, const char *name, ListDialog *l, int it, PType newtype)
+	: Dialog(m, name), l(l), item(it)
 {
 	kdDebug()<<"FunctionDialog()"<<endl;
 	Plot *plot=0;
@@ -78,7 +78,7 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 	else {
 		GraphList *gl = plot->getGraphList();
 		graph = gl->getGraph(item);
-		st = gl->getStruct(item);
+		st = gl->getType(item);
 
 		style = graph->getStyle();
 		symbol = graph->getSymbol();
@@ -134,12 +134,12 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 		selcb->insertItem(tmp+"()");
 	}
 	QObject::connect(selcb,SIGNAL(activated(int)),SLOT(insertFunction(int)));
-	
+
 	KConfig *config = mw->Config();
 	config->setGroup( "Function" );
 
 	QString entry = QString("PlotType %1 ").arg(type);
-	
+
 	// hide them; shown later if necessary
 	concb->hide();
 	conlabel->hide();
@@ -159,23 +159,21 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 		funle->setReadOnly(true);
 
 	hb = new QHBox(tab1);
-	reread = new QCheckBox(i18n("Recreate Function"),hb);
-	reread->hide();
+	reread = 0;
 	if (graph == 0 || (graph != 0 && graph->Source() == SFUNCTION)) {
 		conlabel->show();
 		concb->show();
 		sellabel->show();
 		selcb->show();
-		reread->show();
+		reread = new QCheckBox(i18n("Recreate Function"),hb);
 		reread->setChecked(true);
-	} 
-	if (graph == 0) {		//new function
-		reread->hide();
 	}
+	if (graph == 0 )	// don't show for new function
+		reread->hide();
 
 	KPushButton *setLabel = new KPushButton(i18n("Update Label"),hb);
 	QObject::connect(setLabel,SIGNAL(clicked()),SLOT(updateLabel()));
-	
+
 	hb = new QHBox(tab1);
 	new QLabel(i18n("Range : "),hb);
 
@@ -224,7 +222,7 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 		ny = new KIntNumInput(nry,hb);
 		ny->setMinValue(1);
 	}
-	
+
 	if (graph != 0 && graph->Source() == SSPREADSHEET) {
 		xmin->setEnabled(false);
 		xmax->setEnabled(false);
@@ -234,13 +232,16 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 
 	QVBox *tab2 = new QVBox(tw);
 	Label* label = new Label(config->readEntry(entry+"Function",fun));
-	if (graph != 0) label = graph->getLabel();
+	if (graph != 0) {
+		delete label;
+		label = graph->getLabel();
+	}
 	rtw = new RichTextWidget((QWidget *)tab2,label,0);
-	
+
 	tw->addTab(tab1,i18n("Parameter"));
 	tw->addTab(tab2,i18n("Label"));
 
-	QVBox *styletab, *annotatetab;
+	QVBox *styletab, *annotatetab, *errorbartab;
 	if (type == PSURFACE) {
 		styletab = surfaceStyle(tw,item==-1?true:false);
 		tw->addTab(styletab,i18n("Style"));
@@ -248,10 +249,12 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 	else if (type != PQWT3D) {
 		styletab = simpleStyle(tw, style, symbol);
 		annotatetab = annotateValuesTab(tw,graph);
+		errorbartab = errorbarTab(tw,symbol);
 		tw->addTab(styletab,i18n("Style"));
 		tw->addTab(annotatetab,i18n("Annotate Values"));
+		tw->addTab(errorbartab,i18n("Errorbars"));
 	}
-	
+
 	kdDebug()<<"build destinations"<<endl;
 	// result selection
 	hb = new QHBox(vbox);
@@ -264,26 +267,31 @@ FunctionDialog::FunctionDialog(MainWin *mw, const char *name, ListDialog *l, int
 	wlist<<i18n("new Worksheet")<<i18n("new Spreadsheet");
 	sheetcb->insertStringList(wlist);
 	sheetcb->setCurrentItem(mw->activeSheetIndex());
-	
+
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
-	resize((int)(1.0*minimumSize().width()),minimumSize().height());
-	
+	resize((int)(1.2*minimumSize().width()),minimumSize().height());
+
 	kdDebug()<<"FunctionDialog() DONE"<<endl;
 }
 
+FunctionDialog::~FunctionDialog() {
+	delete rtw;
+}
+
 void FunctionDialog::saveSettings(bool pressed) {
+	kdDebug()<<"FunctionDialog::saveSettings("<<pressed<<")"<<endl;
 	KConfig *config = mw->Config();
 	config->setGroup( "Function" );
 
 	QString entry = QString("PlotType %1 ").arg(type);
 
 	config->writeEntry(entry+"Function",funle->text());
-	// not used config->writeEntry(entry+"Reread",reread->isChecked());
+	// TODO : not used config->writeEntry(entry+"Reread",reread->isChecked());
 	config->writeEntry(entry+"XMin",xmin->text().toDouble());
 	config->writeEntry(entry+"XMax",xmax->text().toDouble());
 	if(ymin != 0 && ymax != 0) {
@@ -296,13 +304,21 @@ void FunctionDialog::saveSettings(bool pressed) {
 
 	if(! pressed)
 		return;
-	
+
 	rtw->getLabel()->saveSettings(config,entry);
 
-	if(type != PQWT3D) {
-		config->writeEntry(entry+"Annotate Type",typecb->currentItem());
-		config->writeEntry(entry+"Annotate Position",positioncb->currentItem());
-		config->writeEntry(entry+"Annotate Distance",distance->value());
+	if(type == PSURFACE)
+		saveSurfaceStyle();
+
+	if(type != PQWT3D && type != PSURFACE) {
+		if(typecb)
+			config->writeEntry(entry+"Annotate Type",typecb->currentItem());
+		if(positioncb)
+			config->writeEntry(entry+"Annotate Position",positioncb->currentItem());
+		if(distance)
+			config->writeEntry(entry+"Annotate Distance",distance->value());
+
+		saveErrorbarSettings();
 	}
 }
 
@@ -327,14 +343,14 @@ void FunctionDialog::insertFunction(int i) {
 // search for a usable plot; add worksheet if necessary
 void FunctionDialog::findPlot() {
 	kdDebug()<<"FunctionDialog::findPlot()"<<endl;
-	int item = sheetcb->currentItem(), count = sheetcb->count();
-	kdDebug()<<"	sheetcb->currentItem() = "<<item<<" of "<<count<<endl;
+	int sitem = sheetcb->currentItem(), count = sheetcb->count();
+	kdDebug()<<"	sheetcb->currentItem() = "<<sitem<<" of "<<count<<endl;
 
-	if(item>=count-2)		// new sheet selected
+	if(sitem>=count-2)		// new sheet selected
 		return;
-	
+
 	QWidgetList list = mw->getWorkspace()->windowList();
-	p = (Worksheet *) list.at(item);
+	p = (Worksheet *) list.at(sitem);
 	if(p==0 || p->getWidgetType() != WWORKSHEET) {
 		p = mw->activeWorksheet();
 		return;
@@ -343,7 +359,7 @@ void FunctionDialog::findPlot() {
 	Plot *plot=0;
 	if(p)
 		plot = p->getPlot(p->API());
-		
+
 	if(plot && plot->Type() == PQWT3D || type == PQWT3D) {	// new worksheet if plot is qwt3d or type = qwt3d
 		kdDebug()<<"	QWT Plot found! type = "<<type<<endl;
 		if(plot && plot->getGraphList()->Number() > 0 ) {
@@ -355,7 +371,7 @@ void FunctionDialog::findPlot() {
 		else
 			p->newPlot(type);
 	}
-	else if(item < count-2 && plot && plot->Type() != type)		// new plot if choosen of other type.
+	else if(sitem < count-2 && plot && plot->Type() != type)		// new plot if choosen of other type.
 		p->newPlot(type);					// not if already new sheet selected
 }
 
@@ -363,25 +379,32 @@ int FunctionDialog::apply_clicked() {
 	kdDebug()<<"FunctionDialog::apply_clicked()"<<endl;
 
 	findPlot();
-	
+
 	// add function
 	// TODO : use richtext label
 //	QString label = labelle->text();
 	int status=0;
-	if (reread->isChecked())
+	if (reread && reread->isChecked()) {
+		kdDebug()<<"	reread is checked"<<endl;
 		status = addFunction();
-	else {
+	}
+	else {	// only edit function
+		kdDebug()<<"	plot type = "<<type<<endl;
 		if(type == PSURFACE) {
+			kdDebug()<<"	surface plot"<<endl;
 			if (p != 0) {
+				kdDebug()<<"		p != 0 surface plot"<<endl;
 				Plot2DSurface *plot = (Plot2DSurface *)p->getPlot(p->API());
 
 				if (plot != 0) {
+					kdDebug()<<"	reading settings"<<endl;
 					plot->enableDensity(dcb->isChecked());
 					plot->enableContour(ccb->isChecked());
 					plot->setNumber(numberle->text().toInt());
 					// OLD : plot->setPalette(pcb->currentItem());
 					plot->setContourColor(contourcolor->color());
 					plot->setColoredContour(coloredcb->isChecked());
+					plot->setContourWidth(contourwidthle->text().toInt());
 					plot->setMesh(meshcb->isChecked());
 					plot->setRelative(relativecb->isChecked());
 					plot->setBrush(dbrushcb->currentItem());
@@ -390,15 +413,19 @@ int FunctionDialog::apply_clicked() {
 			}
 		}
 		else {
-			Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),
-				fcolor->color(),width->value(),
-				pencb->currentItem(),brushcb->currentItem());
+			Style *style = new Style((StylesType)cb2->currentItem(),color->color(),filled->isChecked(),
+				fcolor->color(),width->value(),pencb->currentItem(),brushcb->currentItem());
 			style->setBoxWidth(boxwidth->value());
 			style->setAutoBoxWidth(autobox->isChecked());
 			style->setPointsSorting(sortpointscb->isChecked());
 			Symbol *symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
 					(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 			AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
+			Errorbar *errorbar = new Errorbar(ebarcolor->color(), ebarxsize->value(), ebarysize->value(),
+				(Qt::PenStyle) ebarstylecb->currentItem(), ebarwidth->value(), (EType) ebarxtypecb->currentItem(),
+				(EType) ebarytypecb->currentItem(), ebarbcolor->color(), ebarbwidth->value(),
+				(Qt::PenStyle) ebarbstylecb->currentItem() );
+			symbol->setErrorbar(errorbar);
 			graph->setStyle(style);
 			graph->setSymbol(symbol);
 			graph->setAnnotateValues(av);
@@ -409,6 +436,7 @@ int FunctionDialog::apply_clicked() {
 	if(l) l->updateList();
 	if(p) {
 		p->updatePixmap();
+		// update item (graphlist changes)
 		item = p->getPlot(p->API())->getGraphList()->Number()-1;
 	}
 
@@ -439,9 +467,10 @@ int FunctionDialog::addFunction() {
 	QProgressDialog progress( i18n("Creating function ..."), i18n("Cancel"), NX,this, "progress", true );
 	progress.setMinimumDuration(2000);
 	if (type == P2D || type == PPOLAR) {
+		kdDebug()<<"	\"2d\" or \" polar \" selected"<<endl;
 		Point *ptr = new Point[NX];
 
-		double ymin=0, ymax=1;
+		double ymi=0, yma=1;
 		double xmi = parse((char *) xmin->text().latin1());
 		double xma = parse((char *) xmax->text().latin1());
 		init_table();
@@ -453,6 +482,7 @@ int FunctionDialog::addFunction() {
 			double x = (xma-xmi)*i/(double)(NX-1)+xmi;
 			char var[]="x";
 			assign_variable(var,x);
+//			kdDebug()<<"	parsing "<<fun.latin1()<<endl;
 #ifdef HAVE_GSL
 			gsl_set_error_handler_off();
 #endif
@@ -461,45 +491,45 @@ int FunctionDialog::addFunction() {
 			if(parse_errors()>0) {
 				progress.cancel();
 				KMessageBox::error(mw, i18n("Parse Error!\n Please check the given function."));
-        			delete_table();
+				delete_table();
 				return 1;
 			}
 
 			bool nanvalue=false;
-			if (!finite(x)) { x=0; nanvalue=true; }
-			if (!finite(y)) { y=0; nanvalue=true; }
+			if (!finite(x))	{ x=0; nanvalue=true; }
+			if (!finite(y))	{ y=0; nanvalue=true; }
 
-			if (i == 0) ymin=ymax=y;
-			y<ymin?ymin=y:0;
-			y>ymax?ymax=y:0;
+			if (i == 0) ymi=yma=y;
+			y<ymi?ymi=y:0;
+			y>yma?yma=y:0;
 
 			ptr[i].setPoint(x,y);
 			if(nanvalue)
 				ptr[i].setMasked();
 			if ( progress.wasCancelled() ) {
-        			delete_table();
+				delete_table();
 				return 1;
 			}
 		}
 		delete_table();
-		
+
 		if(p!=0 && graph != 0)
 			p->getPlot(p->API())->getGraphList()->delGraph(item);
 
-		if(ymax-ymin == 0) {
-			ymin -= 1;
-			ymax += 1;
+		if(yma-ymi == 0) {
+			ymi -= 1;
+			yma += 1;
 		}
 
 		if(type == PPOLAR) {
 			xmi = 0;
 			xma = 2*M_PI;
 		}
-		
+
 		LRange range[2];
 		range[0] = LRange(xmi,xma);
-		range[1] = LRange(ymin,ymax);
-		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),
+		range[1] = LRange(ymi,yma);
+		Style *style = new Style((StylesType)cb2->currentItem(),color->color(),filled->isChecked(),
 			fcolor->color(),width->value(),
 			pencb->currentItem(),brushcb->currentItem());
 		style->setBoxWidth(boxwidth->value());
@@ -513,6 +543,7 @@ int FunctionDialog::addFunction() {
 
 		Graph2D *g = new Graph2D(fun,title,range,SFUNCTION,type,style,symbol,ptr,NX);
 		g->setLabel(label);
+		kdDebug()<<"	label->isTeXLabel() : "<<label->isTeXLabel()<<endl;
 
 		AnnotateValues av(typecb->currentItem(),positioncb->currentItem(),distance->value());
 		g->setAnnotateValues(av);
@@ -530,7 +561,7 @@ int FunctionDialog::addFunction() {
 		ymi = parse((char *) (ymin->text()).latin1());
 		yma = parse((char *) (ymax->text()).latin1());
 		init_table();
-			
+
 		for (int i=0;i<NY;i++) {
 			if(i%10==0)progress.setProgress( i );
     			qApp->processEvents();
@@ -541,10 +572,10 @@ int FunctionDialog::addFunction() {
 				var[0]='x';
 				assign_variable(var,(xma-xmi)*j/(double)(NX-1)+xmi);
 #ifdef HAVE_GSL
-				gsl_set_error_handler_off();
+			gsl_set_error_handler_off();
 #endif
 				double z = parse((char *) fun.latin1());
-			
+
 				if(parse_errors()>0) {
 					progress.cancel();
 					KMessageBox::error(mw, i18n("Parse Error!\n Please check the given function."));
@@ -552,7 +583,8 @@ int FunctionDialog::addFunction() {
 					return 1;
 				}
 
-				if (!finite(z)) z=0;
+				bool nanvalue=false;
+				if (!finite(z)) { z=0; nanvalue=true; }
 
 				//kdDebug()<<"z = "<<z<<" (i/j = "<<i<<'/'<<j<<")\n";
 
@@ -563,17 +595,20 @@ int FunctionDialog::addFunction() {
 
 				z<zmin?zmin=z:0;
 				z>zmax?zmax=z:0;
-				
+
 				a[j+NX*i] = z;
+				// TODO : mask if nanvalue
 			}
 			if ( progress.wasCancelled() ) {
-        			delete_table();
+				delete_table();
 				return 1;
 			}
 		}
 		delete_table();
 
-		if(p!=0 && type == PSURFACE) {
+		if(p==0) kdDebug()<<"	p==0"<<endl;
+		if( p!=0 && type == PSURFACE) {
+			kdDebug()<<"	p!=0 && type == PSURFACE"<<endl;
 			Plot2DSurface *plot = (Plot2DSurface *)p->getPlot(p->API());
 
 			// edit graph
@@ -581,12 +616,15 @@ int FunctionDialog::addFunction() {
 				plot->getGraphList()->delGraph(item);
 
 			if (plot != 0) {
+				kdDebug()<<"	plot!=0"<<endl;
+				kdDebug()<<"	reading settings"<<endl;
 				plot->enableDensity(dcb->isChecked());
 				plot->enableContour(ccb->isChecked());
 				plot->setNumber(numberle->text().toInt());
 				// OLD : plot->setPalette(pcb->currentItem());
 				plot->setContourColor(contourcolor->color());
 				plot->setColoredContour(coloredcb->isChecked());
+				plot->setContourWidth(contourwidthle->text().toInt());
 				plot->setMesh(meshcb->isChecked());
 				plot->setRelative(relativecb->isChecked());
 				plot->setBrush(dbrushcb->currentItem());
@@ -622,7 +660,7 @@ int FunctionDialog::addFunction() {
 			kdDebug()<<endl;
 		}*/
 
-		Style *style = new Style(0);
+		Style *style = new Style(LINESTYLE);
 		Symbol *symbol = new Symbol(SNONE);
 		GraphM *g = new GraphM(fun,title,range,SFUNCTION,type,style,symbol,a,NX,NY);
 		g->setLabel(label);
@@ -645,7 +683,7 @@ int FunctionDialog::addFunction() {
 			double y = (yma-ymi)*i/(double)(NY-1)+ymi;
 			char var[]="y";
 			assign_variable(var,y);
-			
+
 			for (int j = 0;j < NX;j++) {
 				double x = (xma-xmi)*j/(double)(NX-1)+xmi;
 				var[0]='x';
@@ -654,7 +692,7 @@ int FunctionDialog::addFunction() {
 				gsl_set_error_handler_off();
 #endif
 				double z = parse((char *) fun.latin1());
-			
+
 				if(parse_errors()>0) {
 					progress.cancel();
 					KMessageBox::error(mw, i18n("Parse Error!\n Please check the given function."));
@@ -674,11 +712,10 @@ int FunctionDialog::addFunction() {
 				ptr[i*NX+j].setPoint(x,y,z);
 				if(nanvalue)
 					ptr[i*NX+j].setMasked();
-
 			}
 			if ( progress.wasCancelled() ) {
 				delete_table();
-        			return 1;
+				return 1;
 			}
 		}
 		delete_table();
@@ -698,7 +735,7 @@ int FunctionDialog::addFunction() {
 
 		kdDebug()<<"Z RANGE = "<<zmin<<' '<<zmax<<endl;
 
-		Style *style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),width->value(),
+		Style *style = new Style((StylesType)cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),width->value(),
 			pencb->currentItem(),brushcb->currentItem());
 		style->setBoxWidth(boxwidth->value());
 		style->setAutoBoxWidth(autobox->isChecked());
@@ -718,6 +755,6 @@ int FunctionDialog::addFunction() {
 	rtw->setLabel(nlabel);
 
 	kdDebug()<<"FunctionDialog::apply_clicked() : DONE"<<endl;
-	
+
 	return 0;
 }
