@@ -10,18 +10,29 @@ using namespace std;
 GraphList::GraphList() {
 	kdDebug()<<"GraphList()"<<endl;
 	clear();
-	kdDebug()<<"	NUMBER = "<<Number()<<endl;
 }
 
 void GraphList::clear() {
-	nr2D = nr3D = nrM = nrGRASS = nr4D = nrIMAGE = nrL = 0;
-	for (int i=0;i<7*MAX_NR;i++)
+//	kdDebug()<<"GraphList::clear()"<<endl;
+	nr2D = nr3D = nrM = nr4D = nrIMAGE = nrL = 0;
+	for (int i=0;i<NR_TYPES*MAX_NR;i++)
 		id[i]=-1;
+	for (int i=0;i<MAX_NR;i++) {
+		list2D[i]=0;
+		list3D[i]=0;
+		listM[i]=0;
+		list4D[i]=0;
+		listIMAGE[i]=0;
+		listL[i]=0;
+	}
+	// TODO : free deleted graphs ?
 }
 
 void GraphList::saveXML(QDomDocument doc, QDomElement root) {
+	kdDebug()<<"GraphList::saveXML()"<<endl;
 	for (unsigned int i=0;i < Number();i++) {
-		QDomElement tag = getGraph(i)->saveGraphXML(doc,getStruct(i));
+		kdDebug()<<"	saving graph "<<i<<endl;
+		QDomElement tag = getGraph(i)->saveGraphXML(doc,getType(i));
    		root.appendChild( tag );
 	}
 }
@@ -47,8 +58,8 @@ int GraphList::addGraph2D(Graph2D *g) {
 //	kdDebug()<<nr2D<<' '<<nr3D<<' '<<nrM<<' '<<nrGRASS<<' '<<nr4D<<' '<<nrIMAGE<<endl;
 
 	if(isNotFull() && nr2D<MAX_NR) {
-		id[nr2D] = nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
-		list2D[nr2D++] = *g;
+		id[nr2D] = Number();
+		list2D[nr2D++] = g;
 
 		//kdDebug()<<"GraphList::addGraph2D : nr2D = "<<nr2D<<endl;
 		return 1;
@@ -58,13 +69,13 @@ int GraphList::addGraph2D(Graph2D *g) {
 
 int GraphList::addGraph3D(Graph3D *g) {
 	if(isNotFull() && nr3D<MAX_NR) {
-		id[MAX_NR+nr3D]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
-		list3D[nr3D++] = *g;
+		id[MAX_NR+nr3D] = Number();
+		list3D[nr3D++] = g;
 
 		kdDebug()<<"GraphList::addGraph3D : id["<<MAX_NR+nr3D-1<<"] = "<<endl;
 		kdDebug()<<id[MAX_NR+nr3D-1]<<endl;
 		kdDebug()<<"Type = "<<g->Type()<<endl;
-		kdDebug()<<"Type = "<<list3D[nr3D-1].Type()<<endl;
+		kdDebug()<<"Type = "<<list3D[nr3D-1]->Type()<<endl;
 
 		return 1;
 	}
@@ -73,12 +84,12 @@ int GraphList::addGraph3D(Graph3D *g) {
 
 int GraphList::addGraphM(GraphM *g) {
 	if(isNotFull() && nrM<MAX_NR) {
-		id[2*MAX_NR+nrM]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
-		listM[nrM++] = *g;
+		id[2*MAX_NR+nrM] = Number();
+		listM[nrM++] = g;
 
 		kdDebug()<<"GraphList::addGraphM : id["<<2*MAX_NR+nrM-1<<"] = "<<id[2*MAX_NR+nrM-1]<<endl;
 		kdDebug()<<"Type = "<<g->Type()<<endl;
-		kdDebug()<<"Type = "<<listM[nrM-1].Type()<<endl;
+		kdDebug()<<"Type = "<<listM[nrM-1]->Type()<<endl;
 
 		return 1;
 	}
@@ -87,13 +98,13 @@ int GraphList::addGraphM(GraphM *g) {
 
 int GraphList::addGraph4D(Graph4D *g) {
 	if(isNotFull() && nr4D<MAX_NR) {
-		id[5*MAX_NR+nr4D]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
-		list4D[nr4D++] = *g;
+		id[5*MAX_NR+nr4D] = Number();
+		list4D[nr4D++] = g;
 
 		kdDebug()<<"GraphList::addGraph4D : id["<<5*MAX_NR+nr4D-1<<"] = "<<endl;
 		kdDebug()<<id[5*MAX_NR+nr4D-1]<<endl;
 		kdDebug()<<"Type = "<<g->Type()<<endl;
-		kdDebug()<<"Type = "<<list4D[nr4D-1].Type()<<endl;
+		kdDebug()<<"Type = "<<list4D[nr4D-1]->Type()<<endl;
 
 		return 1;
 	}
@@ -102,13 +113,13 @@ int GraphList::addGraph4D(Graph4D *g) {
 
 int GraphList::addGraphIMAGE(GraphIMAGE *g) {
 	if(isNotFull() && nrIMAGE<MAX_NR) {
-		id[6*MAX_NR+nrIMAGE]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
-		listIMAGE[nrIMAGE++] = *g;
+		id[6*MAX_NR+nrIMAGE] = Number();
+		listIMAGE[nrIMAGE++] = g;
 
 		kdDebug()<<"GraphList::addGraphIMAGE : id["<<6*MAX_NR+nrIMAGE-1<<"] = "<<endl;
 		kdDebug()<<id[6*MAX_NR+nrIMAGE-1]<<endl;
 		kdDebug()<<"Type = "<<g->Type()<<endl;
-		kdDebug()<<"Type = "<<listIMAGE[nrIMAGE-1].Type()<<endl;
+		kdDebug()<<"Type = "<<listIMAGE[nrIMAGE-1]->Type()<<endl;
 
 		return 1;
 	}
@@ -117,13 +128,13 @@ int GraphList::addGraphIMAGE(GraphIMAGE *g) {
 
 int GraphList::addGraphL(GraphL *g) {
 	if(isNotFull() && nrL < MAX_NR) {
-		id[7*MAX_NR+nr4D]=nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL;
-		listL[nrL++] = *g;
+		id[7*MAX_NR+nr4D] = Number();
+		listL[nrL++] = g;
 
 		kdDebug()<<"GraphList::addGraphL : id["<<7*MAX_NR+nrL-1<<"] = "<<endl;
 		kdDebug()<<id[7*MAX_NR+nrL-1]<<endl;
 		kdDebug()<<"Type = "<<g->Type()<<endl;
-		kdDebug()<<"Type = "<<listL[nrL-1].Type()<<endl;
+		kdDebug()<<"Type = "<<listL[nrL-1]->Type()<<endl;
 
 		return 1;
 	}
@@ -131,76 +142,95 @@ int GraphList::addGraphL(GraphL *g) {
 }
 
 int GraphList::delGraph(unsigned int index) {
-	unsigned int i=index, did;
+	kdDebug()<<"GraphList::delGraph()"<<endl;
+	unsigned int i=Index(index);
+	kdDebug()<<"	deleting graph "<<index<<" (index "<<i<<" in listX[])"<<endl;
 
-	//kdDebug()<<"GraphList::delGraph : index = "<<index<<endl;
-
-	if(index <= nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL) {
-		GRAPHType s = getStruct(index);
-		did=((int)s)*MAX_NR+index;      // deleted index in id[]
+	if(index <= Number()) {
+		GRAPHType s = getType(index);
+		kdDebug()<<"	GraphType = "<<s<<endl;
 		switch (s) {
 		case GRAPH2D:
-			nr2D--;
+			delete list2D[i];
 			while (i<nr2D) {
 				list2D[i] = list2D[i+1];
+				id[i] = id[i+1];
 				i++;
 			}
+			nr2D--;
 			break;
 		case GRAPH3D:
-			nr3D--;
+			delete list3D[i];
 			while (i<nr3D) {
 				list3D[i] = list3D[i+1];
+				id[MAX_NR+i] = id[MAX_NR+i+1];
 				i++;
 			}
+			nr3D--;
 			break;
 		case GRAPHM:
-			nrM--;
+			delete listM[i];
 			while (i<nrM) {
 				listM[i] = listM[i+1];
+				id[2*MAX_NR+i] = id[2*MAX_NR+i+1];
 				i++;
 			}
+			nrM--;
 			break;
 		case GRAPH4D:
-			nr4D--;
+			delete list4D[i];
 			while (i<nr4D) {
 				list4D[i] = list4D[i+1];
+				id[5*MAX_NR+i] = id[5*MAX_NR+i+1];
 				i++;
 			}
+			nr4D--;
 			break;
 		case GRAPHIMAGE:
-			nrIMAGE--;
+			delete listIMAGE[i];
 			while (i<nrIMAGE) {
 				listIMAGE[i] = listIMAGE[i+1];
+				id[6*MAX_NR+i] = id[6*MAX_NR+i+1];
 				i++;
 			}
+			nrIMAGE--;
 			break;
 		case GRAPHL:
-			nrL--;
+			delete listL[i];
 			while (i<nrL) {
 				listL[i] = listL[i+1];
+				id[7*MAX_NR+i] = id[7*MAX_NR+i+1];
 				i++;
 			}
+			nrL--;
 			break;
 		default:
 			break;
-		}	
+		}
 
-                // decrement all id values above the deleted id (did)
-//              kdDebug()<<"    id[]="<<id[did]<<endl;
-                for(int j=0;j<MAX_NR*NR_TYPES;j++) {
-                        if(id[j]>id[did])
-                                id[j]=id[j]-1;
-                }
+		// decrement all id values above
+		for(int j=0;j<MAX_NR*NR_TYPES;j++) {
+			// cast to int! id[] is signed.
+			if(id[j] > (int) index)
+				id[j] -= 1;
+		}
 
-//		kdDebug()<<"GraphList::delGraph : nr(2D,3D,M,4D,IMAGE) = "<<endl;
-//		kdDebug()<<nr2D<<' '<<nr3D<<' '<<nrM<<' '<<nr4D<<''<<nrIMAGE<<endl;
+		kdDebug()<<"GraphList::delGraph : nr(2D,3D,M,4D,IMAGE) = "<<endl;
+		kdDebug()<<nr2D<<' '<<nr3D<<' '<<nrM<<' '<<nr4D<<' '<<nrIMAGE<<endl;
+		for(int k=0;k<NR_TYPES;k++) {
+			//for(int j=0;j<MAX_NR;j++)
+			for(int j=0;j<10;j++)
+				printf(" id[%d] = %d",k*MAX_NR+j,id[k*MAX_NR+j]);
+			printf("\n");
+		}
 
 		return 1;
 	}
+
 	return 0;
 }
 
-GRAPHType GraphList::getStruct(int index) {
+GRAPHType GraphList::getType(int index) {
 	for(int i=0;i<MAX_NR;i++) {
 		//printf("\ti=%d, id[i]=%d,id[i+MAX_NR]=%d,id[i+2*MAX_NR]=%d\n",
 		//		i,id[i],id[i+MAX_NR],id[i+2*MAX_NR]);
@@ -233,30 +263,31 @@ GRAPHType GraphList::getStruct(int index) {
 	return GRAPH2D;	//default return
 }
 
+// return index in listX[] from graph index
 int GraphList::Index(int index) {
+//	kdDebug()<<"GraphList::Index("<<index<<")"<<endl;
 	for(int i=0;i<MAX_NR;i++) {
-		if (id[i] == index || id[MAX_NR+i] == index || id[2*MAX_NR+i] == index || id[3*MAX_NR+i] == index ||
-			id[4*MAX_NR+i] == index || id[5*MAX_NR+i] == index || id[6*MAX_NR+i] == index ||
-			id[7*MAX_NR+i] == index	) {
-			return i;
+		for(int j=0;j<NR_TYPES;j++) {
+			if(id[j*MAX_NR+i] == index)
+				return i;
 		}
 	}
 	return 0;
 }
 
 Graph *GraphList::getGraph(unsigned int i) {
-	kdDebug()<<"GraphList::getGraph(i) i="<<i<<endl;
-	if(i <= nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL) {
-		GRAPHType s = getStruct(i);
-		kdDebug()<<"Graph Struct = "<<s<<endl;
-		//kdDebug()<<"Index = "<<Index(i)<<endl;
-		switch (s) {
-		case GRAPH2D: return (Graph *) &list2D[Index(i)]; break;
-		case GRAPH3D: return (Graph *) &list3D[Index(i)]; break;
-		case GRAPHM: return (Graph *) &listM[Index(i)]; break;
-		case GRAPH4D: return (Graph *) &list4D[Index(i)]; break;
-		case GRAPHIMAGE: return (Graph *) &listIMAGE[Index(i)]; break;
-		case GRAPHL: return (Graph *) &listL[Index(i)]; break;
+	kdDebug()<<"GraphList::getGraph("<<i<<")"<<endl;
+	if(i <= Number()) {
+		GRAPHType gtype = getType(i);
+		kdDebug()<<"Graph Type = "<<gtype<<endl;
+		kdDebug()<<"Index = "<<Index(i)<<endl;
+		switch (gtype) {
+		case GRAPH2D: return (Graph *) list2D[Index(i)]; break;
+		case GRAPH3D: return (Graph *) list3D[Index(i)]; break;
+		case GRAPHM: return (Graph *) listM[Index(i)]; break;
+		case GRAPH4D: return (Graph *) list4D[Index(i)]; break;
+		case GRAPHIMAGE: return (Graph *) listIMAGE[Index(i)]; break;
+		case GRAPHL: return (Graph *) listL[Index(i)]; break;
 		default: break;
 		}
 	}
@@ -264,38 +295,39 @@ Graph *GraphList::getGraph(unsigned int i) {
 }
 
 Graph2D *GraphList::getGraph2D(int i) {
+	kdDebug()<<"GraphList::getGraph2D("<<i<<")"<<endl;
 	if (i >= Index(i))
-		return &list2D[Index(i)];
+		return list2D[Index(i)];
 	return 0;
-}	
+}
 
 Graph3D *GraphList::getGraph3D(int i) {
 	if (i >= Index(i))
-		return &list3D[Index(i)];
+		return list3D[Index(i)];
 	return 0;
-}	
+}
 
 GraphM *GraphList::getGraphM(int i) {
 	if (i >= Index(i))
-		return &listM[Index(i)];
+		return listM[Index(i)];
 	return 0;
-}	
+}
 
 Graph4D *GraphList::getGraph4D(int i) {
 	if (i >= Index(i))
-		return &list4D[Index(i)];
+		return list4D[Index(i)];
 	return 0;
-}	
+}
 
 GraphIMAGE *GraphList::getGraphIMAGE(int i) {
 	if (i >= Index(i))
-		return &listIMAGE[Index(i)];
+		return listIMAGE[Index(i)];
 	return 0;
-}	
+}
 
 GraphL *GraphList::getGraphL(int i) {
 	if (i >= Index(i))
-		return &listL[Index(i)];
+		return listL[Index(i)];
 	return 0;
-}	
+}
 
