@@ -11,8 +11,9 @@ class GraphListView: public KListView
 	Q_OBJECT
 public:
 	GraphListView(QWidget *p);
-	void showZ() { addColumn(i18n("Z Range")); }
-	void showT() { addColumn(i18n("T Range")); }
+	// 7 normal columns
+	void showZ() { if(columns()<8) addColumn(i18n("Z Range")); }
+	void showT() { if(columns()<9) addColumn(i18n("T Range")); }
 };
 
 #endif //GRAPHLISTVIEW_H
