@@ -29,6 +29,8 @@ GraphM::GraphM(QString n, QString l, LRange r[3], LSource src, PType t, Style *s
 		for (int j=0;j<ny;j++)
 			array[j+i*ny] = a[j+i*ny];
 
+	delete [] a;
+
 	/*for (int i=0;i<nx;i++) {
 		for (int j=0;j<ny;j++) {
 			kdDebug()<<' '<<array[j+ny*i]<<endl;
@@ -37,6 +39,12 @@ GraphM::GraphM(QString n, QString l, LRange r[3], LSource src, PType t, Style *s
 	}*/
 }
 
+GraphM::~GraphM() {
+	delete [] array;
+
+	delete label;
+}
+
 GraphM *GraphM::Clone() {
 	GraphM *newg = new GraphM(*this);
 	Label *l = new Label();
@@ -71,7 +79,7 @@ void GraphM::saveXML(QDomDocument doc, QDomElement graphtag) {
 	tag.setAttribute("x",QString::number(nx));
 	tag.setAttribute("y",QString::number(ny));
     	graphtag.appendChild( tag );
-	
+
 	kdDebug()<<"	saving data nx/ny = "<<nx<<' '<<ny<<endl;
 /*	old style
 	for (int i=0;i< nx;i++) {
@@ -84,7 +92,7 @@ void GraphM::saveXML(QDomDocument doc, QDomElement graphtag) {
     			graphtag.appendChild( dtag );
 		}
 	}
-*/	
+*/
 	for (int i=0;i< nx;i++) {
 		QDomElement dtag = doc.createElement( "Data" );
 		for (int j=0;j< ny;j++)
@@ -118,7 +126,7 @@ void GraphM::save(QTextStream *t, QProgressDialog *progress) {
 
 void GraphM::open(QTextStream *t, int version, QProgressDialog *progress) {
 	openGraph(t,version);
-	
+
 	*t>>nx>>ny;
 
 	double zmin, zmax;
@@ -135,7 +143,7 @@ void GraphM::open(QTextStream *t, int version, QProgressDialog *progress) {
 	// read data
 	array = new double[nx*ny];
 	t->readLine();
-	
+
 	progress->setTotalSteps(number);
 	for (int i=0;i<nx;i++) {
 		if(i%100 == 0) progress->setProgress(i);
@@ -143,8 +151,8 @@ void GraphM::open(QTextStream *t, int version, QProgressDialog *progress) {
 
 		//kdDebug()<<"line "<<i<<" : "<<line<<endl;
 
-                line = line.simplifyWhiteSpace();
-        	QStringList oneline = QStringList::split(QChar(' '), line );
+		line = line.simplifyWhiteSpace();
+		QStringList oneline = QStringList::split(QChar(' '), line );
 
 		int j=0;
 		for ( QStringList::Iterator it = oneline.begin(); it != oneline.end(); ++it ) {
@@ -222,7 +230,7 @@ QStringList GraphM::Info(){
 	s << QString::number(range[0].rMin())+ " .. " + QString::number(range[0].rMax());
 	s << QString::number(range[1].rMin())+ " .. " + QString::number(range[1].rMax());
 	s << QString::number(range[2].rMin())+ " .. " + QString::number(range[2].rMax());
-	
+
 	return s;
 }
 
@@ -230,14 +238,14 @@ QStringList GraphM::Info(){
 QPixmap GraphM::Pixmap() {
 	kdDebug()<<"GraphM:Pixmap()"<<endl;
 	QPixmap pm(nx,ny);
-	
+
 	// 8 bit
 	QImage *image = new QImage(nx,ny,8,256);
 	for (int i=0;i<256;i++) {
 		QColor c(i,i,i);
 		image->setColor (i, c.rgb() );
 	}
-	
+
 	for (int i=0;i<ny;i++) {
 		for (int j=0;j<nx;j++) {
 			unsigned int value =
@@ -254,12 +262,12 @@ QPixmap GraphM::Pixmap() {
 void GraphM::setPixmap(QPixmap pm) {
 	kdDebug()<<"GraphM:setPixmap()"<<endl;
 	QImage image = pm.convertToImage();
-	
+
 	nx = pm.width();
 	ny = pm.height();
 
 	free(array);
-	
+
 	// set matrix data from pixmap
 	array= new double[nx*ny];
 	for (int i=0;i<ny;i++) {
