@@ -9,8 +9,8 @@
 #include <gsl/gsl_histogram2d.h>
 #endif
 
-HistListDialog::HistListDialog(MainWin *mw, const char *name)
-	: ListDialog(mw, name)
+HistListDialog::HistListDialog(MainWin *m, const char *name)
+	: ListDialog(m, name)
 {
 	setCaption(i18n("Histogram Dialog"));
 	KConfig *config = mw->Config();
@@ -29,7 +29,7 @@ HistListDialog::HistListDialog(MainWin *mw, const char *name)
 		b=s->Table()->numRows();
 	ble = new KLineEdit(QString::number(b),hb);
 	ble->setValidator(new QDoubleValidator(ble));
-	
+
 	hb = new QHBox(tab1);
 	new QLabel(i18n(" Bins : "),hb);
 	binni = new KIntNumInput(config->readNumEntry("Bins",100),hb);
@@ -39,7 +39,7 @@ HistListDialog::HistListDialog(MainWin *mw, const char *name)
 		updateRange(1);
 		QObject::connect(lv,SIGNAL(selectionChanged()),SLOT(updateRange()));
 	}
-	
+
 	Style *style=0;
 	Symbol *symbol=0;
 	QVBox *styletab;
@@ -52,7 +52,7 @@ HistListDialog::HistListDialog(MainWin *mw, const char *name)
 	tw->addTab(styletab,i18n("Style"));
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
-        QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
@@ -78,7 +78,7 @@ int HistListDialog::apply_clicked() {
 	if(s) {
 		QTable *table = s->Table();
 		int col = table->currentColumn();
-		
+
 		// add column if needed
 		bool empty=true;
 		for(int i=0;i<table->numRows();i++) {
@@ -90,7 +90,7 @@ int HistListDialog::apply_clicked() {
 
 		gsl_histogram *h = gsl_histogram_alloc (bins);
 		gsl_histogram_set_ranges_uniform (h, a, b);
-		
+
 		// insert new data
 		int newcol = table->numCols()-1;
 		for (int i = 0;i<table->numRows();i++) {
@@ -100,7 +100,7 @@ int HistListDialog::apply_clicked() {
 					gsl_histogram_increment(h,table->text(i,col).toDouble()-(b-a)/bins);
 			}
 		}
-		
+
 		// insert into last column
 		for (int i = 0;i<bins;i++) {
 			table->setText(i,newcol,QString::number(gsl_histogram_get (h,i)));
@@ -111,19 +111,19 @@ int HistListDialog::apply_clicked() {
 	}
 
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
-	
+
 	GraphList *gl = p->getPlot(p->API())->getGraphList();
 	if(gl->Number()==0) {
 		KMessageBox::error(this,i18n("No graph found!"));
 		return -2;
 	}
 
-	GRAPHType st = gl->getStruct(item);
+	GRAPHType st = gl->getType(item);
 
 	Style *style=0;
 	Symbol *symbol=0;
 	if(st != GRAPHM) {
-		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
+		style = new Style((StylesType)cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
 			width->value(),pencb->currentItem(),brushcb->currentItem());
 		style->setBoxWidth(boxwidth->value());
 		style->setAutoBoxWidth(autobox->isChecked());
@@ -153,14 +153,14 @@ int HistListDialog::apply_clicked() {
 		gsl_histogram_free (h);
 
 		mw->calculateRanges2D(ptr,bins,&xmin,&xmax,&ymin,&ymax);
-		
+
 		// create the new graph
 		LRange range[2];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
-		
+
 		QString fun = QString(i18n("histogram (")+QString::number(bins)+i18n(") of ")+g->getLabel()->simpleTitle());
-		
+
 		Graph2D *ng = new Graph2D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,bins);
 		mw->addGraph2D(ng,sheetcb->currentItem());
 	}
@@ -175,7 +175,7 @@ int HistListDialog::apply_clicked() {
 			KMessageBox::error(this,i18n("Sorry. This function is not yet implemented!"));
 			return -3;
 		}
-		
+
 		gsl_histogram *h = gsl_histogram_alloc (bins);
 		gsl_histogram_set_ranges_uniform (h, a, b);
 		for (int i = 0;i<nx;i++)
@@ -190,13 +190,13 @@ int HistListDialog::apply_clicked() {
 		gsl_histogram_free (h);
 
 		mw->calculateRanges2D(ptr,bins,&xmin,&xmax,&ymin,&ymax);
-		
+
 		LRange range[2];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
-		
+
 		QString fun = QString(i18n("histogram (")+QString::number(bins)+i18n(") of ")+g->getLabel()->simpleTitle());
-		
+
 		// 3D->2D graph
 		Graph2D *ng = new Graph2D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,bins);
 		mw->addGraph2D(ng,sheetcb->currentItem());
@@ -221,13 +221,13 @@ int HistListDialog::apply_clicked() {
 		gsl_histogram_free (h);
 
 		mw->calculateRanges2D(ptr,bins,&xmin,&xmax,&ymin,&ymax);
-		
+
 		LRange range[2];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
-		
+
 		QString fun = QString(i18n("histogram (")+QString::number(bins)+i18n(") of ")+g->getLabel()->simpleTitle());
-		
+
 		// 4D->2D graph
 		Graph2D *ng = new Graph2D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,bins);
 		mw->addGraph2D(ng,sheetcb->currentItem());
@@ -245,7 +245,7 @@ int HistListDialog::apply_clicked() {
 		for(int i=0;i<nx;i++) {
 			gsl_histogram *h = gsl_histogram_alloc (ybins);
 			gsl_histogram_set_ranges_uniform (h, a, b);
-			
+
 			for (int j = 0;j<ny;j++)
 				gsl_histogram_increment(h,data[i*ny+j]);
 
@@ -253,21 +253,21 @@ int HistListDialog::apply_clicked() {
 				double x = i;
 				double y = j;
 				double z = gsl_histogram_get (h,j);
-				
+
 				ptr[i*ybins+j].setPoint(x,y,z);
 			}
 			gsl_histogram_free (h);
 		}
-		
+
 		mw->calculateRanges3D(ptr,nx*ybins,&xmin,&xmax,&ymin,&ymax,&zmin, &zmax);
-		
+
 		LRange range[3];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
 		range[2] = LRange(zmin,zmax);
-		
+
 		QString fun = QString(i18n("histogram 2d (")+QString::number(nx*ybins)+i18n(") of ")+g->getLabel()->simpleTitle());
-		
+
 		// M->3D graph
 		Graph3D *ng = new Graph3D(fun,fun,range,SSPREADSHEET,PSURFACE,style,symbol,ptr,nx,ybins);
 		mw->addGraph3D(ng,sheetcb->currentItem(),type);
