@@ -7,8 +7,8 @@
 
 using namespace std;
 
-ImageListDialog::ImageListDialog(MainWin *mw, const char *name)
-	: ListDialog(mw, name)
+ImageListDialog::ImageListDialog(MainWin *m, const char *name)
+	: ListDialog(m, name)
 {
 	setCaption(i18n("Image Manipulation Dialog"));
 	KConfig *config = mw->Config();
@@ -31,24 +31,24 @@ ImageListDialog::ImageListDialog(MainWin *mw, const char *name)
 	ylabel = new QLabel("",hb);
 	yle = new KLineEdit(config->readEntry("Parameter2","0"),hb);
 	yle->setValidator(new QDoubleValidator(yle));
-	
+
 	noisecb = new KComboBox(hb);
 	QStringList noiselist;
 	noiselist<<i18n("Uniform noise")<<i18n("Gaussian noise")<<i18n("Multiplicative Gaussian noise");
 	noiselist<<i18n("Impulse noise")<<i18n("Laplacian noise")<<i18n("Poisson noise");
 	noisecb->insertStringList(noiselist);
 	noisecb->setCurrentItem(config->readNumEntry("Noise",0));
-	
+
 	kcb = new KColorButton(config->readColorEntry("Color",&Qt::blue),hb);
-	
+
 	zlabel = new QLabel("",hb);
 	zle = new KLineEdit(config->readEntry("Parameter3","0"),hb);
 	zle->setValidator(new QDoubleValidator(zle));
-	
+
 	// TODO : scale : aspect ratio ?
-	
+
 	updateOptions(0);
-	
+
 	if(p!=0) {
 		//Style style;
 		//Symbol symbol;
@@ -64,7 +64,7 @@ ImageListDialog::ImageListDialog(MainWin *mw, const char *name)
 		//tw->addTab(styletab,i18n("Style"));
 	}
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
-        QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
@@ -87,7 +87,7 @@ void ImageListDialog::saveSettings() {
 void ImageListDialog::updateOptions(int item) {
 	int gitem = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
 	GraphList *gl =  p->getPlot(p->API())->getGraphList();
-	GRAPHType st = gl->getStruct(gitem);
+	GRAPHType st = gl->getType(gitem);
 	QPixmap pm;
 	if (st == GRAPHM) {
 		GraphM *g = gl->getGraphM(gitem);
@@ -106,7 +106,7 @@ void ImageListDialog::updateOptions(int item) {
 	zle->hide();
 	noisecb->hide();
 	kcb->hide();
-	
+
 	switch(item) {
 	case ADAPTIVETHRESHOLD:
 	case SHAVE:
@@ -156,13 +156,13 @@ void ImageListDialog::updateOptions(int item) {
 		xle->setText("0.5");
 		kcb->show();
 		break;
-	case CONTRAST: 
+	case CONTRAST:
 		xlabel->show();
 		xlabel->setText(i18n("Sharpen : "));
 		xle->show();
 		xle->setText("1");
 		break;
-	case CYCLECOLORMAP: 
+	case CYCLECOLORMAP:
 		xlabel->show();
 		xlabel->setText(i18n("Amount : "));
 		xle->show();
@@ -186,7 +186,7 @@ void ImageListDialog::updateOptions(int item) {
 		yle->setText("1");
 		kcb->show();
 		break;
-	case MGAMMA: 
+	case MGAMMA:
 		xlabel->show();
 		xlabel->setText(i18n("Gamma : "));
 		xle->show();
@@ -256,7 +256,7 @@ void ImageListDialog::updateOptions(int item) {
 		xle->setText("6");
 		yle->setText("6");
 		break;
-	case REDUCENOISE: 
+	case REDUCENOISE:
 		xlabel->show();
 		xlabel->setText(i18n("Order : "));
 		xle->show();
@@ -272,7 +272,7 @@ void ImageListDialog::updateOptions(int item) {
 		xle->setText("1");
 		yle->setText("0");
 		break;
-	case ROTATE: 
+	case ROTATE:
 		xlabel->show();
 		xlabel->setText(i18n("Degree : "));
 		xle->show();
@@ -332,13 +332,13 @@ void ImageListDialog::updateOptions(int item) {
 		xle->show();
 		xle->setText("3");
 		break;
-	case SWIRL: 
+	case SWIRL:
 		xlabel->show();
 		xlabel->setText(i18n("Degree : "));
 		xle->show();
 		xle->setText("10");
 		break;
-	case THRESHOLD: 
+	case THRESHOLD:
 		xlabel->show();
 		xlabel->setText(i18n("Threshold : "));
 		xle->show();
@@ -366,7 +366,7 @@ int ImageListDialog::apply_clicked() {
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
 
 	GraphList *gl = p->getPlot(p->API())->getGraphList();
-	GRAPHType st = gl->getStruct(item);
+	GRAPHType st = gl->getType(item);
 
 	QPixmap pm;
 	if (st == GRAPHM) {
@@ -383,15 +383,15 @@ int ImageListDialog::apply_clicked() {
 	tmpfile->setAutoDelete(true);
 	QString filename = tmpfile->name();
 	pm.save(filename,"BMP");
-		
+
 	// read image from file
 	Image image;
 	image.read(filename.latin1());
-		
+
 	double x = xle->text().toDouble();
 	double y = yle->text().toDouble();
 	double z = zle->text().toDouble();
-	
+
 	// apply methods to image
 	switch(typecb->currentItem()) {
 #if MagickLibVersion > 0x551
@@ -414,7 +414,7 @@ int ImageListDialog::apply_clicked() {
 	case FLIP: image.flip(); break;
 	case FLOODFILLCOLOR: image.floodFillColor((int)x,(int)y,getColor(kcb->color())); break;
 	case FLOP: image.flop(); break;
-	case MGAMMA: image.gamma(x); break; 
+	case MGAMMA: image.gamma(x); break;
 	case GAUSSIANBLUR: image.gaussianBlur(x,y); break;
 	case IMPLODE : image.implode(x); break;
 	case MAGNIFY: image.magnify(); break;
@@ -447,10 +447,10 @@ int ImageListDialog::apply_clicked() {
 	case WAVE: image.wave(x,y); break;
 	case ZOOM: image.zoom(Geometry((int)x,(int)y)); break;
 	}
-		
+
 	// write changes to file
 	image.write(filename.latin1());
-		
+
 	// load file into pixmap and set it
 	pm.load(filename);
 
