@@ -4,8 +4,8 @@
 
 using namespace std;
 
-IntegrationListDialog::IntegrationListDialog(MainWin *mw, const char *name)
-	: ListDialog(mw, name)
+IntegrationListDialog::IntegrationListDialog(MainWin *m, const char *name)
+	: ListDialog(m, name)
 {
 	setCaption(i18n("Integration Dialog"));
 	KConfig *config = mw->Config();
@@ -73,7 +73,7 @@ IntegrationListDialog::IntegrationListDialog(MainWin *mw, const char *name)
 	tw->addTab(styletab,i18n("Style"));
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
-        QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
@@ -94,11 +94,11 @@ void IntegrationListDialog::saveSettings() {
 
 int IntegrationListDialog::apply_clicked() {
 	double sum=0, baseline = baselinele->text().toDouble();
-	
+
 	if(s) {
 		QTable *table = s->Table();
 		int col = table->currentColumn();
-		
+
 		// add column if needed
 		bool empty=true;
 		for(int i=0;i<table->numRows();i++) {
@@ -114,39 +114,38 @@ int IntegrationListDialog::apply_clicked() {
 			if (baselinecb->isChecked()) {
 				y1 -= baseline;
 				y2 -= baseline;
-			}	
+			}
 
 			double area = (y1+y2)/2.0;
-			
+
 			if (areacb->isChecked())
 				sum += fabs(area);
 			else
 				sum += area;
-				
+
 			// insert into last column
 			table->setText(i,newcol,QString::number(sum));
 		}
 		return 0;
 	}
-	
+
 	GraphList *gl = p->getPlot(p->API())->getGraphList();
 	if(gl->Number()==0) {
 		KMessageBox::error(this,i18n("No graph found!"));
 		return -2;
 	}
 
-	if (baselinecb->isChecked()) {
+	if (baselinecb->isChecked())
 		p->getPlot(p->API())->setBaseline(baseline);
-	}
-	
+
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
 
-	GRAPHType st = gl->getStruct(item);
-	
+	GRAPHType st = gl->getType(item);
+
 	Style *style=0;
 	Symbol *symbol=0;
 	if(st != GRAPHM) {
-		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
+		style = new Style((StylesType)cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
 			width->value(),pencb->currentItem(),brushcb->currentItem());
 		style->setBoxWidth(boxwidth->value());
 		style->setAutoBoxWidth(autobox->isChecked());
@@ -172,23 +171,23 @@ int IntegrationListDialog::apply_clicked() {
 			if (baselinecb->isChecked()) {
 				y1 -= baseline;
 				y2 -= baseline;
-			}	
+			}
 			double area = (y1+y2)/2.0*(a[i+1].X()-a[i].X());
-			
+
 			if (areacb->isChecked())
 				sum += fabs(area);
 			else
 				sum += area;
-			
+
 			double x = (a[i].X()+a[i+1].X())/2;
 			double y = sum;
-			
+
 			ptr[n++].setPoint(x,y);
 		}
 
 		if (addgraph->isChecked()) {
 			mw->calculateRanges2D(ptr,n,&xmin,&xmax,&ymin,&ymax);
-			
+
 			LRange range[2];
 			range[0] = LRange(xmin,xmax);
 			range[1] = LRange(ymin,ymax);
@@ -217,23 +216,22 @@ int IntegrationListDialog::apply_clicked() {
 				y2 -= baseline;
 			}
 			double area = (y1+y2)/2.0*(a[i+1].X()-a[i].X());
-			
+
 			if (areacb->isChecked())
 				sum += fabs(area);
 			else
 				sum += area;
-			
+
 			double x = (a[i].X()+a[i+1].X())/2;
 			double y = sum;
 			double z = a[i].Z();
-			
+
 			ptr[n++].setPoint(x,y,z);
 		}
-		
 
 		if (addgraph->isChecked()) {
 			mw->calculateRanges3D(ptr,n,&xmin,&xmax,&ymin,&ymax,&zmin,&zmax);
-			
+
 			LRange range[3];
 			range[0] = LRange(xmin,xmax);
 			range[1] = LRange(ymin,ymax);
@@ -265,23 +263,23 @@ int IntegrationListDialog::apply_clicked() {
 				y2 -= baseline;
 			}
 			double area = (y1+y2)/2.0*(a[i+1].X()-a[i].X());
-			
+
 			if (areacb->isChecked())
 				sum += fabs(area);
 			else
 				sum += area;
-			
+
 			double x = (a[i].X()+a[i+1].X())/2;
 			double y = sum;
 			double z = a[i].Z();
 			double t = a[i].T();
-			
+
 			ptr[n++].setPoint(x,y,z,t);
 		}
 
 		if (addgraph->isChecked()) {
 			mw->calculateRanges4D(ptr,n,&xmin,&xmax,&ymin,&ymax,&zmin,&zmax,&tmin,&tmax);
-			
+
 			LRange range[4];
 			range[0] = LRange(xmin,xmax);
 			range[1] = LRange(ymin,ymax);
