@@ -6,11 +6,12 @@
 #include "defs.h"
 
 #ifdef HAVE_GSL
+#include <gsl/gsl_errno.h>
 #include <gsl/gsl_spline.h>
 #endif
 
-InterpolationListDialog::InterpolationListDialog(MainWin *mw, const char *name)
-	: ListDialog(mw, name)
+InterpolationListDialog::InterpolationListDialog(MainWin *m, const char *name)
+	: ListDialog(m, name)
 {
 	setCaption(i18n("Interpolation Dialog"));
 	KConfig *config = mw->Config();
@@ -52,7 +53,7 @@ InterpolationListDialog::InterpolationListDialog(MainWin *mw, const char *name)
 		updateRange();
 		QObject::connect(lv,SIGNAL(selectionChanged()),SLOT(updateRange()));
 	}
-	
+
 	Style *style=0;
 	Symbol *symbol=0;
 	QVBox *styletab;
@@ -65,7 +66,7 @@ InterpolationListDialog::InterpolationListDialog(MainWin *mw, const char *name)
 	tw->addTab(styletab,i18n("Style"));
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
-        QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
@@ -85,6 +86,7 @@ void InterpolationListDialog::saveSettings() {
 }
 
 int InterpolationListDialog::apply_clicked() {
+	kdDebug()<<"InterpolationListDialog::apply_clicked()"<<endl;
 #ifdef HAVE_GSL
 	double a=(ale->text()).toDouble();
 	double b=(ble->text()).toDouble();
@@ -102,11 +104,12 @@ int InterpolationListDialog::apply_clicked() {
 	case 5: inter_type = gsl_interp_akima_periodic;break;
 	}
 
-	if(s) {
+	if(s!=0) {	// spreadsheet
+		kdDebug()<<"	interpolating data from spreadsheet"<<endl;
 		QTable *table = s->Table();
 		int col = table->currentColumn();
 		int n = table->numRows();
-		
+
 		// add column if needed
 		bool empty=true;
 		for(int i=0;i<n;i++) {
@@ -125,10 +128,9 @@ int InterpolationListDialog::apply_clicked() {
 
 		gsl_spline *spline = gsl_spline_alloc(inter_type, n);
 		gsl_spline_init(spline, ax, ay, n);
-		
+
 		int newcol = table->numCols()-1;
 		for (int i = 0;i<number;i++) {
-			
 			// insert into last column
 			table->setText((int)(i*n/number),newcol,QString::number((double) gsl_spline_eval(spline, i*n/number, acc)));
 		}
@@ -139,19 +141,24 @@ int InterpolationListDialog::apply_clicked() {
 		return 0;
 	}
 
-	GraphList *gl = p->getPlot(p->API())->getGraphList();
+	Plot *plot = p->getPlot(p->API());
+	if(plot==0) {
+		KMessageBox::error(this,i18n("No plot found!"));
+		return -3;
+	}
+	GraphList *gl = plot->getGraphList();
 	if(gl->Number()==0) {
 		KMessageBox::error(this,i18n("No graph found!"));
 		return -2;
 	}
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
 
-	GRAPHType st = gl->getStruct(item);
+	GRAPHType st = gl->getType(item);
 
 	Style *style=0;
 	Symbol *symbol=0;
 	if(st != GRAPHM) {
-		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
+		style = new Style((StylesType)cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
 			width->value(),pencb->currentItem(),brushcb->currentItem());
 		style->setBoxWidth(boxwidth->value());
 		style->setAutoBoxWidth(autobox->isChecked());
@@ -162,6 +169,7 @@ int InterpolationListDialog::apply_clicked() {
 
 	double xmin=0, xmax=1, ymin=0, ymax=1, zmin=0, zmax=1, tmin=0, tmax=1;
 	if (st == GRAPH2D) {
+		kdDebug()<<"	GRAPH2D"<<endl;
 		Graph2D *g = gl->getGraph2D(item);
 		int nx = g->Number();
 		Point *data = g->Data();
@@ -199,9 +207,21 @@ int InterpolationListDialog::apply_clicked() {
 			}
 			kdDebug()<<"	new nx="<<nx<<endl;
 		}
+		//for(int i=0;i<nx;i++)
+		//	kdDebug()<<"x/y="<<ax[i]<<' '<<ay[i]<<endl;
 
 		gsl_spline *spline = gsl_spline_alloc(inter_type, nx);
-		gsl_spline_init(spline, ax, ay, nx);
+		if(spline==0) {
+			KMessageBox::error(this,i18n("Could not allocate spline!"));
+			return -4;
+		}
+
+		int status = gsl_spline_init(spline, ax, ay, nx);
+		if(status) {
+			KMessageBox::error(this,i18n("Could not initalize spline!"));
+			printf ("error: %s\n", gsl_strerror (status));
+			return -5;
+		}
 
 		for (int i = 0;i<number;i++) {
 			double x = a+i/(double)(number-1)*(b-a);
@@ -211,11 +231,11 @@ int InterpolationListDialog::apply_clicked() {
 		}
 		delete[] ax;
 		delete[] ay;
-		
+
 		mw->calculateRanges2D(ptr,number,&xmin,&xmax,&ymin,&ymax);
 
-		gsl_spline_free (spline);
-		
+		gsl_spline_free(spline);
+
 		LRange range[2];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
@@ -226,6 +246,7 @@ int InterpolationListDialog::apply_clicked() {
 		mw->addGraph2D(ng,sheetcb->currentItem());
 	}
 	else if (st == GRAPH3D) {
+		kdDebug()<<"	GRAPH3D"<<endl;
 		Graph3D *g = gl->getGraph3D(item);
 		int nx = g->Number();
 		Point3D *data = g->Data();
@@ -240,7 +261,7 @@ int InterpolationListDialog::apply_clicked() {
 			ay[i]=data[i].Y();
 			az[i]=data[i].Z();
 		}
-		
+
 		if (sorted->isChecked()) {
 			for(int i=0;i<nx-1;i++) {	// sort data
 				for(int j=0;j<nx-1;j++) {
@@ -269,6 +290,8 @@ int InterpolationListDialog::apply_clicked() {
 			}
 			kdDebug()<<"	new nx="<<nx<<endl;
 		}
+		//for(int i=0;i<nx;i++)
+		//	kdDebug()<<"x/y="<<ax[i]<<' '<<ay[i]<<endl;
 
 		gsl_spline *spline = gsl_spline_alloc(inter_type, nx);
 		gsl_spline_init(spline, ax, ay, nx);
@@ -276,21 +299,21 @@ int InterpolationListDialog::apply_clicked() {
 		for (int i = 0;i<number;i++) {
 			double x = a+i/(double)(number-1)*(b-a);
 			double y = gsl_spline_eval(spline, x, acc);
-			
+
 			double z=0;
 			 if(i<nx)
 			 	z = az[i];
-			
+
 			ptr[i].setPoint(x,y,z);
 		}
 		delete[] ax;
 		delete[] ay;
 		delete[] az;
-		
+
 		mw->calculateRanges3D(ptr,number,&xmin,&xmax,&ymin,&ymax,&zmin,&zmax);
 
 		gsl_spline_free (spline);
-		
+
 		LRange range[3];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
@@ -304,6 +327,7 @@ int InterpolationListDialog::apply_clicked() {
 		mw->addGraph3D(ng,sheetcb->currentItem(),type);
 	}
 	else if (st == GRAPH4D) {
+		kdDebug()<<"	GRAPH4D"<<endl;
 		Graph4D *g = gl->getGraph4D(item);
 		int nx = g->Number();
 		Point4D *data = g->Data();
@@ -317,10 +341,10 @@ int InterpolationListDialog::apply_clicked() {
 		for(int i=0;i<nx;i++){
 			ax[i]=data[i].X();
 			ay[i]=data[i].Y();
-			ay[i]=data[i].Z();
-			ay[i]=data[i].T();
+			az[i]=data[i].Z();
+			at[i]=data[i].T();
 		}
-		
+
 		if (sorted->isChecked()) {
 			for(int i=0;i<nx-1;i++) {	// sort data
 				for(int j=0;j<nx-1;j++) {
@@ -352,18 +376,19 @@ int InterpolationListDialog::apply_clicked() {
 			}
 			kdDebug()<<"	new nx="<<nx<<endl;
 		}
-
+		//for(int i=0;i<nx;i++)
+		//	kdDebug()<<"x/y="<<ax[i]<<' '<<ay[i]<<endl;
 		gsl_spline *spline = gsl_spline_alloc(inter_type, nx);
 		gsl_spline_init(spline, ax, ay, nx);
 
 		for (int i = 0;i<number;i++) {
 			double x = a+i/(double)(number-1)*(b-a);
 			double y = gsl_spline_eval(spline, x, acc);
-			
+
 			double z=0, t=0;
-			 if(i<nx) {
-			 	z = data[i].Z();
-			 	t = data[i].T();
+			if(i<nx) {
+			 	z = az[i];
+			 	t = at[i];
 			}
 
 			ptr[i].setPoint(x,y,z,t);
@@ -372,11 +397,11 @@ int InterpolationListDialog::apply_clicked() {
 		delete[] ay;
 		delete[] az;
 		delete[] at;
-		
+
 		mw->calculateRanges4D(ptr,number,&xmin,&xmax,&ymin,&ymax,&zmin,&zmax,&tmin,&tmax);
 
 		gsl_spline_free (spline);
-		
+
 		LRange range[4];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
@@ -388,9 +413,10 @@ int InterpolationListDialog::apply_clicked() {
 		Graph4D *ng = new Graph4D(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,number,g->GType());
 		mw->addGraph4D(ng,sheetcb->currentItem());
 	}
+	kdDebug()<<"	OK DONE"<<endl;
 
 	gsl_interp_accel_free (acc);
-	
+
 	updateList();
 #else
 		KMessageBox::error(this, i18n("Sorry. Your installation doesn't support the GSL!"));
