@@ -21,9 +21,9 @@ static KCmdLineOptions options[] = {
 int main(int argc, char *argv[]) {
 	KAboutData aboutData("LabPlot","LabPlot", LVERSION,
 		I18N_NOOP("An application for plotting and analysis of 2d and 3d functions and data."),
-		KAboutData::License_GPL, "(c) 2006, Stefan Gerlach",0,"http://labplot.sourceforge.net",
-		"gerlach@mbi-berlin.de");
-	aboutData.addAuthor("Stefan Gerlach", 0, "gerlach@mbi-berlin.de");
+		KAboutData::License_GPL, "(c) 2007, Stefan Gerlach","http://labplot.sourceforge.net",0,
+		"stefan.gerlach@uni-konstanz.de");
+	aboutData.addAuthor("Stefan Gerlach",0, "stefan.gerlach@uni-konstanz.de");
 	KCmdLineArgs::init(argc, argv, &aboutData);
 	KCmdLineArgs::addCmdLineOptions(options);
 
@@ -37,7 +37,7 @@ int main(int argc, char *argv[]) {
 		filename = args->arg(0);
 
 	KApplication a;
-	
+
 #if QT_VERSION > 0x030102
 	if (args->isSet("-splash")) {
 		static LabPlotSplash *splash = new LabPlotSplash("labplot.png");
@@ -51,6 +51,5 @@ int main(int argc, char *argv[]) {
 	a.setMainWidget(w);
 	w->show();
 
-	
-	return a.exec(); 
+	return a.exec();
 }
