@@ -19,8 +19,7 @@ public:
 
 #ifdef HAVE_QSA_FAC
     virtual QObject *create( const QString &type,
-			     const QSArgumentList &args,
-			     QObject *context );
+    	const QSArgumentList &args,QObject *context );
 #endif
 private:
 	MainWin *mw;
