@@ -11,7 +11,7 @@ class PeriodicListDialog : public ListDialog
 public:
 	PeriodicListDialog(MainWin *mw, const char *name);
 public slots:
-	void setPeriod(int p) {nni->setValue(p); }			//!< set period number of points
+	void setPeriod(int v) {nni->setValue(v); }			//!< set period number of points
 	void setAverage(bool a=true) { averagecb->setChecked(a); }	//!< average over period
 	int Apply() { return apply_clicked(); }
 private:
