@@ -23,18 +23,27 @@ Plot::Plot(Worksheet *w)
 	KConfig *config = w->getMainWin()->Config();
 	aspect_enabled = config->readBoolEntry("AspectRatio",false);
 
-	bgcolor = config->readColorEntry("BackgroundColor",&Qt::white);
-	gbgcolor = config->readColorEntry("GraphBackgroundColor",&Qt::white);
+	bgcolor.setColor(config->readColorEntry("BackgroundColor",&Qt::white));
+	bgcolor.setStyle((Qt::BrushStyle)config->readNumEntry("BackgroundBrush",Qt::SolidPattern));
+	gbgcolor.setColor(config->readColorEntry("GraphBackgroundColor",&Qt::white));
+	gbgcolor.setStyle((Qt::BrushStyle)config->readNumEntry("GraphBackgroundBrush",Qt::SolidPattern));
 
+	QFont font;
+	if(worksheet==0) {
+		kdDebug()<<"WARNING : no Worksheet defined!"<<endl;
+	}
+	else {
+		MainWin *mw = worksheet->getMainWin();
+		if(mw)
+			font = mw->defaultFont();
+	}
 	// title (richtext title)
-	if(worksheet==0) kdDebug()<<"no Worksheet defined!"<<endl;
-	QFont font = worksheet->getMainWin()->defaultFont();
 	title = new Label(i18n("Title"),font,QColor(Qt::black));
 	title->setPosition(0.4,0.04);
 
 	font.setPointSize((int)(0.4*font.pointSize()));
 	legend.setFont(font);
-	
+
 	position.setPoint(config->readDoubleNumEntry("Position X",0.0),config->readDoubleNumEntry("Position Y",0.0));
 	size.setPoint(config->readDoubleNumEntry("Size X",1.0),config->readDoubleNumEntry("Size Y",1.0));
 	p1.setPoint(.15,.15);
@@ -62,17 +71,19 @@ Plot::Plot(Worksheet *w)
 	fillg2 = config->readNumEntry("FillG2",2);
 	fillbrush = QBrush(config->readColorEntry("FillColor",&Qt::red),
 		(Qt::BrushStyle)config->readNumEntry("FillBrush",Qt::SolidPattern));
-	kdDebug()<<"Plot OK"<<endl;
+	kdDebug()<<"Plot::Plot() DONE"<<endl;
+
+	datamodegraph=0;
 }
 
 // read default axis settings
-void Plot::readAxisSettings(Axis *a, int type, int item) {
+void Plot::readAxisSettings(Axis *a, int ptype, int item) {
 	KConfig *config = worksheet->getMainWin()->Config();
 	config->setGroup( "Axes" );
-	
+
 	// default values for different plots
 	bool e=true, borderenabled=true, gridenabled=false;
-	switch (type) {
+	switch (ptype) {
 	case P2D:
 		if(item>1) {
 			e = false;
@@ -87,8 +98,8 @@ void Plot::readAxisSettings(Axis *a, int type, int item) {
 		break;
 	default:break;
 	}
-	
-	QString entry = QString("PlotType %1 Axis %2 ").arg(type).arg(item); 
+
+	QString entry = QString("PlotType %1 Axis %2 ").arg(ptype).arg(item);
 
 	a->Enable(config->readBoolEntry(entry+"Enabled",e));
 	a->setPosition(config->readNumEntry(entry+"Position"));
@@ -98,7 +109,7 @@ void Plot::readAxisSettings(Axis *a, int type, int item) {
 	// dont set range -> automatic
 
 	a->getLabel()->readSettings(config,entry);
-	
+
 	a->setTickPos(config->readNumEntry(entry+"TickPosition"));
 	a->setTickType(config->readNumEntry(entry+"TickStyle",1));
 	a->enableMajorTicks(config->readBoolEntry(entry+"MajorTicksEnabled",true));
@@ -109,7 +120,7 @@ void Plot::readAxisSettings(Axis *a, int type, int item) {
 	a->setMinorTickWidth(config->readNumEntry(entry+"MinorTickWidth",1));
 	a->setTickColor(config->readColorEntry(entry+"TickColor",&Qt::black));
 
-	if(type == PQWT3D) {
+	if(ptype == PQWT3D) {
 		a->setMajorTickLength(config->readDoubleNumEntry(entry+"MajorTickLength",0.05));
 		a->setMinorTickLength(config->readDoubleNumEntry(entry+"MinorTickLength",0.05));
 	}
@@ -125,7 +136,7 @@ void Plot::readAxisSettings(Axis *a, int type, int item) {
 	a->setTickLabelPrefix(config->readEntry(entry+"TickLabelPrefix"));
 	a->setTickLabelSuffix(config->readEntry(entry+"TickLabelSuffix"));
 	a->setTickLabelRotation(config->readNumEntry(entry+"TickLabelRotation"));
-	
+
 	a->enableMajorGrid(config->readBoolEntry(entry+"MajorGridEnabled",gridenabled));
 	a->enableMinorGrid(config->readBoolEntry(entry+"MinorGridEnabled",gridenabled));
 	a->setMajorGridWidth(config->readNumEntry(entry+"MajorGridWidth",1));
@@ -134,13 +145,13 @@ void Plot::readAxisSettings(Axis *a, int type, int item) {
 	a->setMinorGridWidth(config->readNumEntry(entry+"MinorGridWidth",1));
 	a->setMinorGridType((Qt::PenStyle)config->readNumEntry(entry+"MinorGridStyle",(int)Qt::DotLine));
 	a->setMinorGridColor(config->readColorEntry(entry+"MinorGridColor",&Qt::black));
-	
+
 	a->enableBorder(config->readBoolEntry(entry+"BorderEnabled",borderenabled));
 	a->setBorderColor(config->readColorEntry(entry+"BorderColor",&Qt::black));
 	a->setBorderWidth(config->readNumEntry(entry+"BorderWidth",1));
 }
 
-void Plot::sortPoints(QPointArray pa,int s, int e) {
+void Plot::sortPoints(QPointArray pa, int s, int e) {
 	// bubble sort
 /*	QPoint tmp;
 	for(unsigned int i=a;i<e;i++) {
@@ -200,11 +211,11 @@ void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,
 //	kdDebug()<<"POINTARRAY "<<i<<'='<<pa[i].x()<<' '<<pa[i].y()<<endl;
 
 	switch(style->Type()) {
-	case 0:	// line
+	case LINESTYLE:
 		if (filled) {
 			p->setPen(Qt::NoPen);
 			p->setBrush(brush);
-		
+
 			QPointArray fillpa(pa.size()+2);
 			if(fabs((double)(rmax-rmin)) > 0) {	//draw only region
 				int index=0,newindex=1;
@@ -227,10 +238,11 @@ void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,
 		}
 		p->drawPolyline(pa);
 		break;
-	case 2:	{ // steps	: only for 2d
+	case NOLINESTYLE: break;
+	case STEPSSTYLE: { // only for 2d
 		QPointArray stepspa(2*pa.size());
 		// start
-		stepspa[0]=pa[0];		
+		stepspa[0]=pa[0];
 		stepspa[1]=QPoint((pa[0].x()+pa[1].x())/2,pa[0].y());
 		// end
 		stepspa[2*pa.size()-2]=QPoint((int)((pa[pa.size()-2].x()+pa[pa.size()-1].x())/2.0),pa[pa.size()-1].y());
@@ -264,10 +276,10 @@ void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,
 		}
 		p->drawPolyline(stepspa);
 		}; break;
-	case 3:	// boxes	: only for 2d
+	case BOXESSTYLE: // only for 2d
 		for(unsigned int i=0;i<pa.size();i++) {
 			QPointArray boxpa(4);
-			
+
 			if(style->AutoBoxWidth()) {
 				if(i==0) {
 					boxpa[0]=QPoint(pa[i].x()-(int)((pa[i+1].x()-pa[i].x())/2.0),pa[i].y());
@@ -301,14 +313,14 @@ void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,
 			p->drawPolygon(boxpa);
 		}
 		break;
-	case 4:	// impulses	: only for 2d
+	case IMPULSESSTYLE:	// only for 2d
 		for (unsigned int i=0;i<pa.size();i++)
 			p->drawLine(pa[i].x(),pa[i].y(),pa[i].x(),basey);
 		break;
-	case 5:	// yboxes	:only for 2d
+	case YBOXESSTYLE:	// only for 2d
 		for(unsigned int i=0;i<pa.size();i++) {
 			QPointArray boxpa(4);
-			
+
 			if(style->AutoBoxWidth()) {
 				if(i==0) {
 					boxpa[0]=QPoint(pa[i].x(),(int)(pa[i].y()-(pa[i+1].y()-pa[i].y())/2.0));
@@ -335,7 +347,7 @@ void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,
 				boxpa[2]=QPoint(basex, pa[i].y()+bw/2);
 				boxpa[3]=QPoint(basex, pa[i].y()-bw/2);
 			}
-			
+
 			p->setBrush(Qt::NoBrush);
 			if (filled)
 				p->setBrush(brush);
@@ -349,46 +361,27 @@ void Plot::drawStyle(QPainter *p, Style *style, Symbol *symbol, QPointArray pa,
 		symbol->draw(p,pa[i].x(),pa[i].y());
 }
 
-
-//! draw errorbars for x-y-dy, x-y-dx-dy and x-y-dy1-dy2
-// at (x,y) from xleft to xright and ybottom to ytop
-void Plot::drawErrorBar(QPainter *p, QPointArray pa, QPointArray hpa, QPointArray vpa) {
-	for(unsigned int i=0;i<pa.size();i++) {
-		int x=pa[i].x(), y=pa[i].y();
-		int xleft=hpa[i].x(), xright=hpa[i].y();
-		int ytop=vpa[i].x(),ybottom=vpa[i].y();
-		
-		if (xleft != x) {
-			p->drawLine(xleft,y,x,y);
-			p->drawLine(xleft,y-2,xleft,y+2);
-		}
-		if (xright != x) {
-			p->drawLine(x,y,xright,y);
-			p->drawLine(xright,y-2,xright,y+2);
-		}
-		if (ytop != y) {
-			p->drawLine(x,y,x,ytop);
-			p->drawLine(x-2,ytop,x+2,ytop);
-		}
-		if (ybottom != y) {
-			p->drawLine(x,y,x,ybottom);
-			p->drawLine(x-2,ybottom,x+2,ybottom);
-		}
-	}
-}
-
 QDomElement Plot::savePlotXML(QDomDocument doc) {
+	kdDebug()<<"savePlotXML()"<<endl;
 	QDomElement plottag = doc.createElement( "Plot" );
 	plottag.setAttribute("type",QString::number(type));
 
 	QDomElement tag = doc.createElement( "Background" );
    	plottag.appendChild( tag );
-  	QDomText t = doc.createTextNode( bgcolor.name() );
+	QDomText t = doc.createTextNode( bgcolor.color().name() );
     	tag.appendChild( t );
+	tag = doc.createElement( "BackgroundBrush" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(gbgcolor.style()) );
+	tag.appendChild( t );
 	tag = doc.createElement( "GraphBackground" );
    	plottag.appendChild( tag );
-  	t = doc.createTextNode( gbgcolor.name() );
+	t = doc.createTextNode( gbgcolor.color().name() );
     	tag.appendChild( t );
+	tag = doc.createElement( "GraphBackgroundBrush" );
+	plottag.appendChild( tag );
+	t = doc.createTextNode( QString::number(gbgcolor.style()) );
+	tag.appendChild( t );
 	tag = doc.createElement( "Transparent" );
    	plottag.appendChild( tag );
   	t = doc.createTextNode( QString::number(transparent) );
@@ -410,7 +403,7 @@ QDomElement Plot::savePlotXML(QDomDocument doc) {
 	tag.setAttribute("min",QString::number(actrange[2].rMin()));
 	tag.setAttribute("max",QString::number(actrange[2].rMax()));
    	plottag.appendChild( tag );
-	
+
 	tag = doc.createElement( "Baseline" );
 	tag.setAttribute("x",QString::number(xbaseline));
 	tag.setAttribute("y",QString::number(baseline));
@@ -469,6 +462,7 @@ QDomElement Plot::savePlotXML(QDomDocument doc) {
 	// save aditional plot stuff
 	saveXML(doc,plottag);
 
+	kdDebug()<<"	saving graph list"<<endl;
 	graphlist->saveXML(doc,plottag);
 
 	return plottag;
@@ -476,8 +470,8 @@ QDomElement Plot::savePlotXML(QDomDocument doc) {
 
 void Plot::save(QTextStream *t) {
 	kdDebug()<<"Plot::save()"<<endl;
-	*t<<bgcolor.name()<<endl;
-	*t<<gbgcolor.name()<<endl;
+	*t<<bgcolor.color().name()<<endl;
+	*t<<gbgcolor.color().name()<<endl;
 	*t<<transparent<<endl;
 	*t<<clipoffset<<endl;
 
@@ -494,9 +488,9 @@ void Plot::save(QTextStream *t) {
 	*t<<size.X()<<' '<<size.Y()<<endl;
 	*t<<p1.X()<<' '<<p1.Y()<<endl;
 	*t<<p2.X()<<' '<<p2.Y()<<endl;
-	
+
 	*t<<aspect_enabled<<endl;
-	
+
 	//marks
 	*t<<marks_enabled<<' '<<markx->rMin()<<' '<<markx->rMax()<<' '<<marky->rMin()<<' '<<marky->rMax()<<endl;
 
@@ -526,7 +520,7 @@ void Plot::save(QTextStream *t) {
 #ifdef HAVE_GL
 	else if (type == PQWT3D) {
 		PlotQWT3D *plot = (PlotQWT3D *)this;
-		
+
 		*t<<(int) plot->PlotStyle()<<endl;
 		*t<<(int) plot->CoordinateStyle()<<endl;
 		*t<<(int) plot->FloorStyle()<<endl;
@@ -551,7 +545,7 @@ void Plot::save(QTextStream *t) {
 
 	unsigned int i;
 	for (i=0;i < graphlist->Number();i++) {
-		switch (graphlist->getStruct(i)) {
+		switch (graphlist->getType(i)) {
 		case GRAPH2D:
 			*t<<"Graph2D "<<i<<endl;
 			graphlist->getGraph2D(i)->save(t,progress);
@@ -586,11 +580,11 @@ void Plot::save(QTextStream *t) {
 Qwt3D::ColorVector Plot::convertOldColormap(int index) {
 	Qwt3D::ColorVector cv;
 	cv.clear();
-		
+
 	Qwt3D::RGBA rgb;
 
 	switch(index) {
-	case 0: 
+	case 0:
 		for(int i=0;i<255;i++) {
 			rgb.a = 1;
 			i>127?rgb.r = (2*(i-128))/255.0:rgb.r = 0;
@@ -788,21 +782,26 @@ Qwt3D::ColorVector Plot::convertOldColormap(int index) {
 		}
 		break;
 	}
-	
+
 	return cv;
 }
 #endif
 
 void Plot::openPlotXML(QDomNode node) {
+	kdDebug()<<"openPlotXML()"<<endl;
 	while(!node.isNull()) {
 		QDomElement e = node.toElement();
-//		kdDebug()<<"PLOT TAG = "<<e.tagName()<<endl;
-//		kdDebug()<<"PLOT TEXT = "<<e.text()<<endl;
+		kdDebug()<<"PLOT TAG = "<<e.tagName()<<endl;
+		kdDebug()<<"PLOT TEXT = "<<e.text()<<endl;
 
 		if(e.tagName() == "Background")
-			bgcolor = QColor(e.text());
+			bgcolor.setColor(QColor(e.text()));
+		else if(e.tagName() == "BackgroundBrush")
+			bgcolor.setStyle(Qt::BrushStyle(e.text().toInt()));
 		else if(e.tagName() == "GraphBackground")
-			gbgcolor = QColor(e.text());
+			gbgcolor.setColor(QColor(e.text()));
+		else if(e.tagName() == "GraphBackgroundBrush")
+			gbgcolor.setStyle(Qt::BrushStyle(e.text().toInt()));
 		else if(e.tagName() == "Transparent")
 			transparent = (bool) e.text().toInt();
 		else if(e.tagName() == "ClipOffset")
@@ -830,15 +829,15 @@ void Plot::openPlotXML(QDomNode node) {
 		else if(e.tagName() == "Size")
 			size.setPoint(e.attribute("x").toDouble(),e.attribute("y").toDouble());
 		else if(e.tagName() == "PlotArea") {
-			p1.setPoint(e.attribute("xmin").toDouble(),e.attribute("xmax").toDouble());
-			p2.setPoint(e.attribute("ymin").toDouble(),e.attribute("ymax").toDouble());
+			p1.setPoint(e.attribute("xmin").toDouble(),e.attribute("ymin").toDouble());
+			p2.setPoint(e.attribute("xmax").toDouble(),e.attribute("ymax").toDouble());
 		}
 		else if(e.tagName() == "AspectRatio")
 			aspect_enabled = (bool) e.text().toInt();
 		else if(e.tagName() == "Marks") {
 			marks_enabled = (bool) e.attribute("enabled").toInt();
-			markx->setRange(e.attribute("xmin").toDouble(),e.attribute("ymin").toDouble());
-			marky->setRange(e.attribute("xmax").toDouble(),e.attribute("ymax").toDouble());
+			markx->setRange(e.attribute("xmin").toDouble(),e.attribute("xmax").toDouble());
+			marky->setRange(e.attribute("ymin").toDouble(),e.attribute("ymax").toDouble());
 		}
 		else if(e.tagName() == "Fill") {
 			fill_enabled = (bool) e.attribute("enabled").toInt();
@@ -848,44 +847,51 @@ void Plot::openPlotXML(QDomNode node) {
 			fillbrush = QBrush(e.attribute("color"),(Qt::BrushStyle) e.attribute("brush").toInt());
 		}
 		else if(e.tagName() == "Label")
-			title->openXML(e.firstChild());		
+			title->openXML(e.firstChild());
 		else if(e.tagName() == "Legend")
 			legend.openXML(e.firstChild());
 		else if(e.tagName() == "Graph") {
+			kdDebug()<<"	TAG Graph (type = "<<e.attribute("type").toInt()<<")"<<endl;
 			switch(e.attribute("type").toInt()) {
 			case GRAPH2D: {
+				kdDebug()<<"	new Graph2D() called"<<endl;
 				Graph2D *g = new Graph2D();
 				g->openXML(e.firstChild());
 				worksheet->addGraph2D(g,type);
 				}; break;
 			case GRAPH3D: {
+				kdDebug()<<"	new Graph3D() called"<<endl;
 				Graph3D *g = new Graph3D();
 				g->openXML(e.firstChild());
 				worksheet->addGraph3D(g,type);
 				}; break;
 			case GRAPH4D: {
+				kdDebug()<<"	new Graph4D() called"<<endl;
 				Graph4D *g = new Graph4D();
 				g->openXML(e.firstChild());
 				worksheet->addGraph4D(g);
 				}; break;
 			case GRAPHM: {
+				kdDebug()<<"	new GraphM() called"<<endl;
 				GraphM *g = new GraphM();
 				g->openXML(e.firstChild());
 				worksheet->addGraphM(g,type);
 				}; break;
 			case GRAPHIMAGE: {
+				kdDebug()<<"	new GraphIMAGE() called"<<endl;
 				GraphIMAGE *g = new GraphIMAGE();
 				g->openXML(e.firstChild());
 				worksheet->addGraphIMAGE(g);
 				}; break;
 			case GRAPHL: {
+				kdDebug()<<"	new GraphL() called"<<endl;
 				GraphL *g = new GraphL();
 				g->openXML(e.firstChild());
 				worksheet->addGraphL(g,type);
 				}; break;
 			}
 		}
-		
+
 		// plot type stuff
 		openXML(e);
 
@@ -923,7 +929,7 @@ void Plot::open(QTextStream *t, int version) {
 			actrange[i].setMax(y);
 			kdDebug()<<"	ActRange"<<i<<" min/max = "<<x<<' '<<y<<endl;
 		}
-		
+
 		if(version>18) {
 			int e1,e2;
 			*t>>baseline>>e1>>xbaseline>>e2;
@@ -951,7 +957,7 @@ void Plot::open(QTextStream *t, int version) {
 			p1.setPoint(x,y);
 			*t>>x>>y;
 			p2.setPoint(x,y);
-			
+
 			if(version>22) {
 				int e;
 				*t>>e;
@@ -975,7 +981,7 @@ void Plot::open(QTextStream *t, int version) {
 				*t>>v>>filltype;
 				fill_enabled = bool(v);
 				*t>>fillg1>>fillg2;
-					
+
 				*t>>c>>v;
 				fillbrush = QBrush(c,(Qt::BrushStyle) v);
 			}
@@ -1011,7 +1017,7 @@ void Plot::open(QTextStream *t, int version) {
 		plot->enableContour(ce);
 		if(version>22)
 			*t>>n;
-		else {	
+		else {
 			*t>>n>>p;
 #ifdef HAVE_GL
 			plot->setColorVector(convertOldColormap(p));
@@ -1036,9 +1042,9 @@ void Plot::open(QTextStream *t, int version) {
 			Qwt3D::RGBA rgb;
 #endif
 
-			int size;
-			*t>>size;
-			for(int i=0;i<size;i++) {
+			int cvsize;
+			*t>>cvsize;
+			for(int i=0;i<cvsize;i++) {
 #ifdef HAVE_GL
 				*t >> rgb.r >> rgb.g >> rgb.b>>rgb.a;
 				cv.push_back(rgb);
@@ -1088,10 +1094,10 @@ void Plot::open(QTextStream *t, int version) {
 		cv.clear();
 		Qwt3D::RGBA rgb;
 #endif
-		
-		int size;
-		*t>>size;
-		for(int i=0;i<size;i++) {
+
+		int cvsize;
+		*t>>cvsize;
+		for(int i=0;i<cvsize;i++) {
 #ifdef HAVE_GL
 			*t >> rgb.r >> rgb.g >> rgb.b>>rgb.a;
 			cv.push_back(rgb);
@@ -1197,7 +1203,7 @@ void Plot::saveAxis(QTextStream *t, Axis *axis) {
 // called from Plot<Type> with all axes
 void Plot::openAxis(QTextStream *t,int version,Axis *axis) {
 	kdDebug()<<"Plot::openAxis()"<<endl;
-	QString family, color, bgcolor;
+	QString family, color, bgc;
 	int pointsize, weight, italic, trans;
 	double x,y;
 
@@ -1220,7 +1226,7 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis) {
 	axis->enableBorder(be);
 	axis->enableMajorGrid(ge);
 	kdDebug()<<"BORDER/MAJORGRID "<<be<<' '<<ge<<endl;
-	
+
 	if(version > 14) {
 		*t>>ge;
 		axis->enableMinorGrid(ge);
@@ -1248,7 +1254,7 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis) {
 			kdDebug()<<"GRID WIDTHs : "<<e1<<e2<<e3<<e4<<endl;
 		}
 	}
-	
+
 	l=t->readLine();	// needed. don't know why ...
 
 	// open axis label
@@ -1269,7 +1275,7 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis) {
 		if(version > 20)
 			*t>>is_texlabel;
 		if (version > 21) {
-			*t>>bgcolor;
+			*t>>bgc;
 			*t>>trans;
 		}
 	}
@@ -1293,7 +1299,7 @@ void Plot::openAxis(QTextStream *t,int version,Axis *axis) {
 	label->setBoxed(boxed);
 	label->setRotation(rotation);
 	label->setTeXLabel(is_texlabel);
-	label->setBackgroundColor(bgcolor);
+	label->setBackgroundColor(bgc);
 	label->setTransparent(trans);
 	axis->setLabel(label);
 
@@ -1386,7 +1392,7 @@ void Plot::autoScaleX() {
 	double min=range[0].rMin(), max=range[0].rMax();
 
 	worksheet->checkRanges(scale,&min,&max);
-	
+
 	actrange[0].setMin(min);
 	actrange[0].setMax(max);
 }
@@ -1396,7 +1402,7 @@ void Plot::autoScaleY() {
 	double min=range[1].rMin(), max=range[1].rMax();
 
 	worksheet->checkRanges(scale,&min,&max);
-	
+
 	actrange[1].setMin(min);
 	actrange[1].setMax(max);
 }
@@ -1406,11 +1412,11 @@ void Plot::autoScaleZ() {
 	double min=range[2].rMin(), max=range[2].rMax();
 
 	worksheet->checkRanges(scale,&min,&max);
-	
+
 	actrange[2].setMin(min);
 	actrange[2].setMax(max);
 }
-	
+
 //! build the tic label string according to atlf
 QString Plot::TicLabel(int atlf, int prec, QString dtf, double value) {
 	QString label;
@@ -1440,7 +1446,7 @@ QString Plot::TicLabel(int atlf, int prec, QString dtf, double value) {
 	case TIME: {
 		QTime time;
 		time=time.addMSecs((int) (value*1000));
-			
+
 		QString format;
 		if(fabs(value)<1)
 			format="z";
@@ -1485,7 +1491,7 @@ QString Plot::TicLabel(int atlf, int prec, QString dtf, double value) {
 			// TODO : round minutes
 			format="h:mm:ss";
 		}
-			
+
 		// overwrite auto format
 		if (dtf != i18n("auto"))
 			format = dtf;
@@ -1526,7 +1532,7 @@ QString Plot::TicLabel(int atlf, int prec, QString dtf, double value) {
 //! get the tic label value from the string according to atlf (range of axes)
 double Plot::TicLabelValue(int atlf, QString string) {
 	double value=0;
-	
+
 	switch(atlf) {
 	case AUTO:
 	case NORMAL:
@@ -1544,18 +1550,18 @@ double Plot::TicLabelValue(int atlf, QString string) {
 		} break;
 	case DATE: {
 		QDate date;
-		date = date.fromString(string,Qt::ISODate);              // must be yyyy-MM-dd
+		date = date.fromString(string,Qt::ISODate);	      // must be yyyy-MM-dd
 		//kdDebug()<<"DATE : "<<date.toString()<<endl;
 		//kdDebug()<<"\tdaysTo1970 : "<<date.daysTo(QDate(1970,1,1))<<endl;
 		value = -1.0*date.daysTo(QDate(1970,1,1));
 		}
 		break;
 	case DATETIME: {
-                QDateTime datetime;
-                datetime = datetime.fromString(string,Qt::ISODate);
-//              kdDebug()<<"DATETIME : "<<datetime.toString()<<endl;
-//              kdDebug()<<"\tsecsTo1970 : "<<-datetime.secsTo(QDate(1970,1,1))<<endl;
-                value = -1.0*datetime.secsTo(QDate(1970,1,1));
+		QDateTime datetime;
+		datetime = datetime.fromString(string,Qt::ISODate);
+//		kdDebug()<<"DATETIME : "<<datetime.toString()<<endl;
+//		kdDebug()<<"\tsecsTo1970 : "<<-datetime.secsTo(QDate(1970,1,1))<<endl;
+		value = -1.0*datetime.secsTo(QDate(1970,1,1));
 		}
 		break;
 	case DEGREE:
@@ -1570,7 +1576,7 @@ double Plot::TicLabelValue(int atlf, QString string) {
 void Plot::shiftRight() {
 	TScale scale = ((Plot2D *)this)->getAxis(0)->Scale();
 	double r1=actrange[0].rMin(), r2=actrange[0].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
 
 	double r=worksheet->partRanges(scale,r1,r2);
@@ -1590,16 +1596,16 @@ void Plot::shiftRight() {
 void Plot::shiftLeft() {
 	TScale scale = ((Plot2D *)this)->getAxis(0)->Scale();
 	double r1=actrange[0].rMin(), r2=actrange[0].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
 	case LINEAR: case SQRT: case SX2: nr1 = r1+r; nr2 = r2+r; break;
 	case LOG10: case LOG2: case LN: nr1 = r1*r; nr2 = r2*r; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(scale,&nr1,&nr2);
 
@@ -1610,36 +1616,36 @@ void Plot::shiftLeft() {
 void Plot::shiftUp() {
 	TScale scale = ((Plot2D *)this)->getAxis(1)->Scale();
 	double r1=actrange[1].rMin(), r2=actrange[1].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
 	case LINEAR: case SQRT: case SX2: nr1 = r1-r; nr2 = r2-r; break;
 	case LOG10: case LOG2: case LN: nr1 = r1/r; nr2 = r2/r; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(scale,&nr1,&nr2);
 
 	actrange[1].setMin(nr1);
 	actrange[1].setMax(nr2);
 }
-	
+
 void Plot::shiftDown() {
 	TScale scale = ((Plot2D *)this)->getAxis(1)->Scale();
 	double r1=actrange[1].rMin(), r2=actrange[1].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
 	case LINEAR: case SQRT: case SX2: nr1 = r1+r; nr2 = r2+r; break;
 	case LOG10: case LOG2: case LN: nr1 = r1*r; nr2 = r2*r; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(scale,&nr1,&nr2);
 
@@ -1650,16 +1656,16 @@ void Plot::shiftDown() {
 void Plot::scaleXUp() {
 	TScale scale = ((Plot2D *)this)->getAxis(0)->Scale();
 	double r1=actrange[0].rMin(), r2=actrange[0].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
 	case LINEAR: case SQRT: case SX2: nr1 = r1+r; nr2 = r2-r; break;
 	case LOG10: case LOG2: case LN: nr1 = r1*r; nr2 = r2/r; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(scale,&nr1,&nr2);
 
@@ -1670,16 +1676,16 @@ void Plot::scaleXUp() {
 void Plot::scaleXDown() {
 	TScale scale = ((Plot2D *)this)->getAxis(0)->Scale();
 	double r1=actrange[0].rMin(), r2=actrange[0].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
 	case LINEAR: case SQRT: case SX2: nr1 = r1-r; nr2 = r2+r; break;
 	case LOG10: case LOG2: case LN: nr1 = r1/r; nr2 = r2*r; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(scale,&nr1,&nr2);
 
@@ -1690,29 +1696,29 @@ void Plot::scaleXDown() {
 void Plot::scaleYUp() {
 	TScale scale = ((Plot2D *)this)->getAxis(1)->Scale();
 	double r1=actrange[1].rMin(), r2=actrange[1].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
 	case LINEAR: case SQRT: case SX2: nr1 = r1+r; nr2 = r2-r; break;
 	case LOG10: case LOG2: case LN: nr1 = r1*r; nr2 = r2/r; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(scale,&nr1,&nr2);
 
 	actrange[1].setMin(nr1);
 	actrange[1].setMax(nr2);
 }
-	
+
 void Plot::scaleYDown() {
 	TScale scale = ((Plot2D *)this)->getAxis(1)->Scale();
 	double r1=actrange[1].rMin(), r2=actrange[1].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
@@ -1731,16 +1737,16 @@ void Plot::scaleZUp() {
 	// does this work ?
 	TScale scale = ((Plot2D *)this)->getAxis(2)->Scale();
 	double r1=actrange[2].rMin(), r2=actrange[2].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
 	case LINEAR: case SQRT: case SX2: nr1 = r1+r; nr2 = r2-r; break;
 	case LOG10: case LOG2: case LN: nr1 = r1*r; nr2 = r2/r; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(scale,&nr1,&nr2);
 
@@ -1752,16 +1758,16 @@ void Plot::scaleZDown() {
 	// does this work ?
 	TScale scale = ((Plot2D *)this)->getAxis(2)->Scale();
 	double r1=actrange[2].rMin(), r2=actrange[2].rMax();
-	
+
 	worksheet->checkRanges(scale,&r1,&r2);
-	
+
 	double r=worksheet->partRanges(scale,r1,r2);
 	double nr1, nr2;
 	switch(scale) {
 	case LINEAR: case SQRT: case SX2: nr1 = r1-r; nr2 = r2+r; break;
 	case LOG10: case LOG2: case LN: nr1 = r1/r; nr2 = r2*r; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(scale,&nr1,&nr2);
 
@@ -1769,18 +1775,18 @@ void Plot::scaleZDown() {
 	actrange[2].setMax(nr2);
 }
 
-void Plot::zoomIn() { 
+void Plot::zoomIn() {
 	TScale xscale = ((Plot2D *)this)->getAxis(0)->Scale();
 	TScale yscale = ((Plot2D *)this)->getAxis(1)->Scale();
 	TScale zscale = ((Plot2D *)this)->getAxis(2)->Scale();
 	double x1=actrange[0].rMin(), x2=actrange[0].rMax();
 	double y1=actrange[1].rMin(), y2=actrange[1].rMax();
 	double z1=actrange[2].rMin(), z2=actrange[2].rMax();
-	
+
 	worksheet->checkRanges(xscale,&x1,&x2);
 	worksheet->checkRanges(yscale,&y1,&y2);
 	worksheet->checkRanges(zscale,&z1,&z2);
-	
+
 	double x=worksheet->partRanges(xscale,x1,x2);
 	double y=worksheet->partRanges(yscale,y1,y2);
 	double z=worksheet->partRanges(zscale,z1,z2);
@@ -1797,7 +1803,7 @@ void Plot::zoomIn() {
 	case LINEAR: case SQRT: case SX2: nz1 = z1+z; nz2 = z2-z; break;
 	case LOG10: case LOG2: case LN: nz1 = z1*z; nz2 = z2/z; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(xscale,&nx1,&nx2);
 	worksheet->checkRanges(yscale,&ny1,&ny2);
@@ -1808,18 +1814,18 @@ void Plot::zoomIn() {
 	actrange[2].setMin(nz1);actrange[2].setMax(nz2);
 }
 
-void Plot::zoomOut() { 
+void Plot::zoomOut() {
 	TScale xscale = ((Plot2D *)this)->getAxis(0)->Scale();
 	TScale yscale = ((Plot2D *)this)->getAxis(1)->Scale();
 	TScale zscale = ((Plot2D *)this)->getAxis(2)->Scale();
 	double x1=actrange[0].rMin(), x2=actrange[0].rMax();
 	double y1=actrange[1].rMin(), y2=actrange[1].rMax();
 	double z1=actrange[2].rMin(), z2=actrange[2].rMax();
-	
+
 	worksheet->checkRanges(xscale,&x1,&x2);
 	worksheet->checkRanges(yscale,&y1,&y2);
 	worksheet->checkRanges(zscale,&z1,&z2);
-	
+
 	double x=worksheet->partRanges(xscale,x1,x2);
 	double y=worksheet->partRanges(yscale,y1,y2);
 	double z=worksheet->partRanges(zscale,z1,z2);
@@ -1836,7 +1842,7 @@ void Plot::zoomOut() {
 	case LINEAR: case SQRT: case SX2: nz1 = z1-z; nz2 = z2+z; break;
 	case LOG10: case LOG2: case LN: nz1 = z1/z; nz2 = z2*z; break;
 	}
-	
+
 	// just checking
 	worksheet->checkRanges(xscale,&nx1,&nx2);
 	worksheet->checkRanges(yscale,&ny1,&ny2);
@@ -1853,10 +1859,7 @@ Point Plot::dataValue(double x) {
 
 	double xmin=actrange[0].rMin(), xmax=actrange[0].rMax();
 	double ymin=actrange[1].rMin(), ymax=actrange[1].rMax();
-	
-	//TODO : which graph
-	int graph=0;
-	
+
 	if(x<p1.X())
 		return Point(p1.X(),p2.Y());
 	else if( x>p2.X())
@@ -1883,14 +1886,14 @@ Point Plot::dataValue(double x) {
 	}
 
 //	kdDebug()<<"	X for datamode = "<<x<<endl;
-	
-	GRAPHType s = graphlist->getStruct(graph);
-	
+
+	GRAPHType s = graphlist->getType(datamodegraph);
+
 	switch(s) {
 	case GRAPH2D: {
-		Graph2D *g = graphlist->getGraph2D(graph);
+		Graph2D *g = graphlist->getGraph2D(datamodegraph);
 		Point *ptr = g->Data();
-		
+
 		for(int i=0;i<g->Number()-1;i++) {
 			if(ptr[i].X() < x && ptr[i+1].X() > x) {
 				x = ptr[i].X();
@@ -1900,9 +1903,9 @@ Point Plot::dataValue(double x) {
 		}
 		}; break;
 	case GRAPH3D: {
-		Graph3D *g = graphlist->getGraph3D(graph);
+		Graph3D *g = graphlist->getGraph3D(datamodegraph);
 		Point3D *ptr = g->Data();
-		
+
 		for(int i=0;i<g->Number()-1;i++) {
 			if(ptr[i].X() < x && ptr[i+1].X() > x) {
 				x = ptr[i].X();
@@ -1912,9 +1915,9 @@ Point Plot::dataValue(double x) {
 		}
 		}; break;
 	case GRAPH4D: {
-		Graph4D *g = graphlist->getGraph4D(graph);
+		Graph4D *g = graphlist->getGraph4D(datamodegraph);
 		Point4D *ptr = g->Data();
-		
+
 		for(int i=0;i<g->Number()-1;i++) {
 			if(ptr[i].X() < x && ptr[i+1].X() > x) {
 				x = ptr[i].X();
@@ -1925,9 +1928,9 @@ Point Plot::dataValue(double x) {
 		}; break;
 	default: break;
 	}
-	
+
 	worksheet->getMainWin()->message("( " + QString::number(x) + " / " + QString::number(y) + " )");
-	
+
 	// convert to world coordinates
 //	kdDebug()<<"	Y for datamode = "<<y<<endl;
 	switch(type){
@@ -1959,10 +1962,10 @@ Point Plot::dataValue(double x) {
 	default: break;
 	}
 //	kdDebug()<<"	Y-VALUE for datamode = "<<y<<endl;
-	
+
 	return Point(x,y);
 }
-	
+
 //! calcuate tic number for auto tics
 int Plot::autoTicks(double min, double max) {
 //	kdDebug()<<"Plot::autoTicks : min/max = "<<min<<' '<<max<<endl;
@@ -1974,10 +1977,10 @@ int Plot::autoTicks(double min, double max) {
 	// just to make sure
 	if(tics<=0)
 		return -1;
-	
+
 	// always between 4 and 10 tics
 	while(tics<4)
 		tics *= 2;
 
-	return tics;	
+	return tics;
 }
