@@ -18,8 +18,8 @@ QStringList Plot2DSimple::Info() {
 		s<<QString("yes");
 	else
 		s<<QString("no");
-	s<<bgcolor.name();
-	s<<gbgcolor.name();
+	s<<bgcolor.color().name();
+	s<<gbgcolor.color().name();
 
 	return s;
 }
@@ -36,8 +36,8 @@ void Plot2DSimple::drawFill(QPainter *p,int w, int h) {
 	// clipping rect with some space (clipoffset)
 	p->setClipRect(xmin-clipoffset,ymin-clipoffset,xmax-xmin+2*clipoffset,ymax-ymin+2*clipoffset);
 
-	GRAPHType s1 = graphlist->getStruct(fillg1);
-	GRAPHType s2 = graphlist->getStruct(fillg2);
+	GRAPHType s1 = graphlist->getType(fillg1);
+	GRAPHType s2 = graphlist->getType(fillg2);
 
 	if (s1 == GRAPH2D && s2 ==  GRAPH2D) {
 		Graph2D *g1 = graphlist->getGraph2D(fillg1);
@@ -107,57 +107,55 @@ void Plot2DSimple::calculateXY(Point d,double *x, double *y, int w, int h) {
 
 	switch(axis[0].Scale()) {
 		case LINEAR:	*x += (d.X() - minx) * (xmax-xmin)/(maxx-minx); break;
-		case LOG10:	
-			if (d.X() <= 0)
-				*x = xmin;
+		case LOG10:
+			if(d.X() <= 0)
+				*x=xmin;
 			else
-				*x += (log10(d.X()/minx)) * (xmax-xmin)/(log10(maxx/minx)); 
+				*x += (log10(d.X()/minx)) * (xmax-xmin)/(log10(maxx/minx));
 			break;
-		case LOG2:	
-			if (d.X() <= 0)
-				*x = xmin;
+		case LOG2:
+			if(d.X() <= 0)
+				*x=xmin;
 			else
 				*x += (log2(d.X()/minx)) * (xmax-xmin)/(log2(maxx/minx));
 			break;
 		case LN:
-			if (d.X() <= 0)
-				*x = xmin;
-			else	
+			if(d.X() <= 0)
+				*x=xmin;
+			else
 				*x += (log(d.X()/minx)) * (xmax-xmin)/(log(maxx/minx));
 			break;
 		case SQRT:
-			if (d.X() < 0)
-				*x = xmin;
-			else	
-				*x += (sqrt(d.X())-sqrt(minx)) * (xmax-xmin)/(sqrt(maxx)-sqrt(minx));
-			break;
+			if(d.X() < 0)
+				*x=xmin;
+			else
+				*x += (sqrt(d.X())-sqrt(minx)) * (xmax-xmin)/(sqrt(maxx)-sqrt(minx)); break;
 		case SX2:	*x += ((d.X()*d.X())-(minx*minx))*(xmax-xmin)/((maxx*maxx)-(minx*minx)); break;
 	}
 	switch(axis[1].Scale()) {
-		case LINEAR:
-			*y -= (d.Y() - miny) * (ymax-ymin)/(maxy-miny);	break;
+		case LINEAR:	*y -= (d.Y() - miny) * (ymax-ymin)/(maxy-miny); break;
 		case LOG10:
-			if (d.Y() <= 0)
-				*y = ymax;
-			else	
+			if(d.Y() <= 0)
+				*y=ymax;
+			else
 				*y -= (log10(d.Y()/miny)) * (ymax-ymin)/(log10(maxy/miny));
 			break;
 		case LOG2:
-			if (d.Y() <= 0)
-				*y = ymax;
-			else	
+			if(d.Y() <= 0)
+				*y=ymax;
+			else
 				*y -= (log2(d.Y()/miny)) * (ymax-ymin)/(log2(maxy/miny));
 			break;
 		case LN:
-			if (d.Y() <= 0)
-				*y = ymax;
-			else	
+			if(d.Y() <= 0)
+				*y=ymax;
+			else
 				*y -= (log(d.Y()/miny)) * (ymax-ymin)/(log(maxy/miny));
 			break;
 		case SQRT:
-			if (d.Y() < 0)
-				*y = ymax;
-			else	
+			if(d.Y() < 0)
+				*y=ymax;
+			else
 				*y -= (sqrt(d.Y())-sqrt(miny)) * (ymax-ymin)/(sqrt(maxy)-sqrt(miny));
 			break;
 		case SX2:	*y -= ((d.Y()*d.Y())-(miny*miny)) * (ymax-ymin)/((maxy*maxy)-(miny*miny)); break;
@@ -165,7 +163,7 @@ void Plot2DSimple::calculateXY(Point d,double *x, double *y, int w, int h) {
 }
 
 void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
-	kdDebug()<<" Plot2DSimple::drawCurves"<<endl;
+	kdDebug()<<"Plot2DSimple::drawCurves()"<<endl;
 	const int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	const int xmax = (int)(w*(size.X()*p2.X()+position.X()));
 	const int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
@@ -174,14 +172,14 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 
 	// clipping rect with some space (clipoffset)
 	p->setClipRect(xmin-clipoffset,ymin-clipoffset,xmax-xmin+2*clipoffset,ymax-ymin+2*clipoffset);
-			
+
 	double minx = actrange[0].rMin();
 	double maxx = actrange[0].rMax();
 	double miny = actrange[1].rMin();
 	double maxy = actrange[1].rMax();
-	
+
 	for (unsigned int i=0; i < graphlist->Number() ; i++) {
-		GRAPHType s = graphlist->getStruct(i);
+		GRAPHType s = graphlist->getType(i);
 
 		//kdDebug()<<"GRAPH "<<i<<endl;
 		//kdDebug()<<"STRUCT "<<s<<endl;
@@ -206,7 +204,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				for(int j=0;j<g->Number();j++) {
 					if(d[j].Masked() == true)
 						continue;
-						
+
 					if(worksheet->getMainWin()->speedMode()) {
 						int mod = (int) (g->Number()/worksheet->getMainWin()->speedModeValue());
 						if(mod==0) mod=1;
@@ -215,17 +213,17 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 
 					double x=xmin,y=ymax;
 					calculateXY(d[j],&x,&y,w,h);
-					
+
 					// dont draw outside border
 					// HACK : prevent drawing errors with too large coordinates
-					if(oldy > 10*ymax && y > 10*ymax || oldy < -1000 && y < -1000 || 
+					if(oldy > 10*ymax && y > 10*ymax || oldy < -1000 && y < -1000 ||
 						oldx > 10*xmax && x > 10*xmax || oldx < -1000 && x < -1000)
 						;
 					else
 						pa[pointindex++]=QPoint((int)x,(int)y);
-						
+
 					g->getAnnotateValues().draw(p,(int)x,(int)y,d[j].X(),d[j].Y());
-					
+
 					oldx = x;oldy = y;
 				}
 				pa.resize(pointindex);	// resize to clear all unneeded points (from draw outside border)
@@ -254,14 +252,14 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 			for(int j=0 ;j < N;j++) {
 				if(d[j].Masked() == true)
 					continue;
-				
+
 				if(worksheet->getMainWin()->speedMode()) {
 					int mod = (int) (N/worksheet->getMainWin()->speedModeValue());
 					if(mod==0) mod=1;
 					if(j%mod != 0) continue;	// speed mode
 				}
 				double x=xmin,y=ymax;
-					
+
 				// see Graph2D
 				switch(axis[0].Scale()) {
 				case LINEAR:	x += (d[j].X() - minx) * (xmax-xmin)/(maxx-minx); break;
@@ -273,7 +271,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				}
 
 				double ybottom=0, ytop=0;
-	
+
 				switch(axis[1].Scale()) {
 				case LINEAR: {
 					y = ymax - (d[j].Y() - miny) * (ymax-ymin)/(maxy-miny);
@@ -318,24 +316,26 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				// errorbar points;
 				hpa[pointindex]=QPoint((int)x,(int)x);
 				vpa[pointindex]=QPoint((int)ytop,(int)ybottom);
-				
+
 				// HACK : prevent drawing errors with too large coordinates
-				if(oldy>10*ymax && y>10*ymax || oldy<-1000 && y<-1000 || 
+				if(oldy>10*ymax && y>10*ymax || oldy<-1000 && y<-1000 ||
 					oldx>10*xmax && x>10*xmax || oldx<-1000 && x<-1000)
 					;
 				else
 					pa[pointindex++]=QPoint((int)x,(int)y);
-						
+
 				g->getAnnotateValues().draw(p,(int)x,(int)y,d[j].X(),d[j].Y(),d[j].Z());
-				
+
 				oldx = x;oldy = y;
 			}
 			pa.resize(pointindex);	// resize to clear all unneeded points (from draw outside border)
-			if(g->getStyle()->PointsSortingEnabled())
+			Style *style=g->getStyle();
+			Symbol *symbol = g->getSymbol();
+			if(style->PointsSortingEnabled())
 				sortPoints(pa,0,pa.size()-1);
-			drawStyle(p,g->getStyle(),g->getSymbol(),pa,xmin,xmax,ymin,ymax);
-			p->setPen(g->getStyle()->Color());
-			drawErrorBar(p,pa,hpa,vpa);
+			drawStyle(p,style,symbol,pa,xmin,xmax,ymin,ymax);
+			p->setPen(style->Color());
+			symbol->errorBar()->draw(p,pa,hpa,vpa);
 		}
 		else if (s == GRAPH4D) {		// x-y-dx-dy or x-y-dy1-dy2
 			Graph4D *g = graphlist->getGraph4D(i);
@@ -346,15 +346,15 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 			Point4D *d = g->Data();
 			double oldx=0, oldy=0;
 			int N=g->Number();
-			bool type = g->GType();
+			bool gtype = g->GType();
 			double xscale, yscale;
 			QPointArray pa(N), hpa(N), vpa(N);
 			int pointindex=0;
-			
+
 			for(int j=0 ;j < N;j++) {
 				if(d[j].Masked() == true)
 					continue;
-				
+
 				if(worksheet->getMainWin()->speedMode()) {
 					int mod = (int) (N/worksheet->getMainWin()->speedModeValue());
 					if(mod==0) mod=1;
@@ -367,7 +367,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case LINEAR: {
 					xscale = (xmax-xmin)/(maxx-minx);
 					x = xmin + (d[j].X() - minx) * xscale;
-					if (type == 0) {	// x-y-dx-dy
+					if (gtype == 0) {	// x-y-dx-dy
 						double diffx = d[j].Z() * xscale;
 						xright = x+diffx;
 						xleft = x-diffx;
@@ -378,7 +378,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case LOG10: {
 					xscale = (xmax-xmin)/(log10(maxx/minx));
 					x = xmin + (log10(d[j].X()/minx)) * xscale;
-					if (type == 0) {	// x-y-dx-dy
+					if (gtype == 0) {	// x-y-dx-dy
 						xleft = xmin + (log10((d[j].X()-d[j].Z())/minx)) * xscale;
 						xright = xmin + (log10((d[j].X()+d[j].Z())/minx)) * xscale;
 					}
@@ -388,7 +388,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case LOG2: {
 					xscale = (xmax-xmin)/(log2(maxx/minx));
 					x = xmin + (log2(d[j].X()/minx)) * xscale;
-					if (type == 0) {	// x-y-dx-dy
+					if (gtype == 0) {	// x-y-dx-dy
 						xleft = xmin + (log2((d[j].X()-d[j].Z())/minx)) * xscale;
 						xright = xmin + (log2((d[j].X()+d[j].Z())/minx)) * xscale;
 					}
@@ -398,7 +398,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case LN: {
 					xscale = (xmax-xmin)/(log(maxx/minx));
 					x = xmin + (log(d[j].X()/minx)) * xscale;
-					if (type == 0) {	// x-y-dx-dy
+					if (gtype == 0) {	// x-y-dx-dy
 						xleft = xmin + (log((d[j].X()-d[j].Z())/minx)) * xscale;
 						xright = xmin + (log((d[j].X()+d[j].Z())/minx)) * xscale;
 					}
@@ -409,7 +409,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 					xscale = (xmax-xmin)/(sqrt(maxx)-sqrt(minx));
 
 					x = xmin + (sqrt(d[j].X())-sqrt(minx)) * xscale;
-					if (type == 0) {	// x-y-dx-dy
+					if (gtype == 0) {	// x-y-dx-dy
 						xleft = xmin + (sqrt(d[j].X()-d[j].Z())-sqrt(minx)) * xscale;
 						xright = xmin + (sqrt(d[j].X()+d[j].Z())-sqrt(minx)) * xscale;
 					}
@@ -420,7 +420,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 					xscale = (xmax-xmin)/(maxx*maxx-minx*minx);
 
 					x = xmin + (d[j].X()*d[j].X()-minx*minx) * xscale;
-					if (type == 0) {	// x-y-dx-dy
+					if (gtype == 0) {	// x-y-dx-dy
 						xleft = xmin + ((d[j].X()-d[j].Z())*(d[j].X()-d[j].Z())-minx*minx) * xscale;
 						xright = xmin + ((d[j].X()+d[j].Z())*(d[j].X()+d[j].Z())-minx*minx) * xscale;
 					}
@@ -433,7 +433,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case LINEAR: {
 					yscale = (ymax-ymin)/(maxy-miny);
 					y = ymax - (d[j].Y() - miny) * yscale;
-					if (type == 0) {	// x-y-dx-dy
+					if (gtype == 0) {	// x-y-dx-dy
 						double diff = d[j].T() * yscale;
 						ytop = y+diff;
 						ybottom = y-diff;
@@ -448,16 +448,16 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case LOG10: {
 					yscale = (ymax-ymin)/log10(maxy/miny);
 					y = ymax - log10(d[j].Y()/miny) * yscale;
-					if (type == 0)
+					if (gtype == 0)
 						ybottom = ymax - log10((d[j].Y()-d[j].T())/miny) * yscale;
-					else 
+					else
 						ybottom = ymax - log10((d[j].Y()-d[j].Z())/miny) * yscale;
 					ytop = ymax - log10((d[j].Y()+d[j].T())/miny) * yscale;
 					}; break;
 				case LOG2: {
 					yscale = (ymax-ymin)/log2(maxy/miny);
 					y = ymax - log2(d[j].Y()/miny) * yscale;
-					if (type == 0)
+					if (gtype == 0)
 						ybottom = ymax - log2((d[j].Y()-d[j].T())/miny) * yscale;
 					else
 						ybottom = ymax - log2((d[j].Y()-d[j].Z())/miny) * yscale;
@@ -466,7 +466,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case LN: {
 					yscale = (ymax-ymin)/log(maxy/miny);
 					y = ymax - log(d[j].Y()/miny) * yscale;
-					if (type == 0)
+					if (gtype == 0)
 						ybottom = ymax - log((d[j].Y()-d[j].T())/miny) * yscale;
 					else
 						ybottom = ymax - log((d[j].Y()-d[j].Z())/miny) * yscale;
@@ -475,7 +475,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case SQRT: {
 					yscale = (ymax-ymin)/(sqrt(maxy)-sqrt(miny));
 					y = ymax - (sqrt(d[j].Y())-sqrt(miny)) * yscale;
-					if (type == 0)
+					if (gtype == 0)
 						ybottom = ymax - (sqrt(d[j].Y()-d[j].T())-sqrt(miny)) * yscale;
 					else
 						ybottom = ymax - (sqrt(d[j].Y()-d[j].Z())-sqrt(miny)) * yscale;
@@ -484,7 +484,7 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 				case SX2: {
 					yscale = (ymax-ymin)/(maxy*maxy-miny*miny);
 					y = ymax - ((d[j].Y()*d[j].Y())-miny*miny) * yscale;
-					if (type == 0)
+					if (gtype == 0)
 						ybottom = ymax - ((d[j].Y()-d[j].T())*(d[j].Y()-d[j].T())-miny*miny) * yscale;
 					else
 						ybottom = ymax - ((d[j].Y()-d[j].Z())*(d[j].Y()-d[j].Z())-miny*miny) * yscale;
@@ -494,13 +494,13 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 
 				//kdDebug()<<"xleft="<<xleft<<",xright="<<xright<<endl;
 				//kdDebug()<<"ytop="<<ytop<<",ybottom="<<ybottom<<endl;
-				
+
 				// errorbar points;
 				hpa[pointindex]=QPoint((int)xleft,(int)xright);
 				vpa[pointindex]=QPoint((int)ytop,(int)ybottom);
 
 				// HACK : prevent drawing errors with too large coordinates
-				if(oldy>10*ymax && y>10*ymax || oldy<-1000 && y<-1000 || 
+				if(oldy>10*ymax && y>10*ymax || oldy<-1000 && y<-1000 ||
 					oldx>10*xmax && x>10*xmax || oldx<-1000 && x<-1000)
 					;
 				else
@@ -508,17 +508,20 @@ void Plot2DSimple::drawCurves(QPainter *p,int w, int h) {
 
 				// TODO : use Z,T too ?
 				g->getAnnotateValues().draw(p,(int)x,(int)y,d[j].X(),d[j].Y());
-				
+
 				oldx = x;oldy = y;
 			}
 			pa.resize(pointindex);	// resize to clear all unneeded points (from draw outside border)
-			if(g->getStyle()->PointsSortingEnabled())
+			Style *style = g->getStyle();
+			Symbol *symbol = g->getSymbol();
+			if(style->PointsSortingEnabled())
 				sortPoints(pa,0,pa.size()-1);
-			drawStyle(p,g->getStyle(),g->getSymbol(),pa,xmin,xmax,ymin,ymax);
-			p->setPen(g->getStyle()->Color());
-			drawErrorBar(p,pa,hpa,vpa);
+			drawStyle(p,style,symbol,pa,xmin,xmax,ymin,ymax);
+			p->setPen(style->Color());
+			symbol->errorBar()->draw(p,pa,hpa,vpa);
 		}
 	}
 
 	p->setClipping(false);
+	kdDebug()<<"Plot2DSimple::drawCurves() DONE"<<endl;
 }
