@@ -29,6 +29,8 @@ public:
 	void setContourColor(QString c) { contour_color = QColor(c); }
 	bool ColoredContour() { return colored_contour; }
 	void setColoredContour(bool c) {colored_contour = c; }
+	int ContourWidth() { return contour_width; }
+	void setContourWidth(int w=0) { contour_width=w; }
 	bool Mesh(){ return mesh; }
 	void setMesh(bool m) { mesh=m; }
 	bool Relative() { return relative; }
@@ -55,6 +57,7 @@ private:
 	bool contourenabled;	// contour enabled
 	QColor contour_color;	// contour line color
 	bool colored_contour;	// colored contour lines
+	int contour_width;	// contour width
 	bool mesh;		// draw mesh (grid)
 	bool relative;		// use relative (full) color scale (e.g. 5-10 -> 0..255) or absolute (e.g. 5-10 -> 190..255)
 	int brush;		// brush for density
