@@ -14,7 +14,7 @@ PlotPolar::PlotPolar(Worksheet *p)
 	QFont font = p->getMainWin()->defaultFont();
 	title = new Label(i18n("Polar Plot"),font,QColor(Qt::black));
 	title->setPosition(0.4,0.02);
-	
+
 	// set default axis settings for all axes
 	for(int i=0;i<2;i++)
 		readAxisSettings(&axis[i],PPOLAR,i);
@@ -30,6 +30,16 @@ PlotPolar::PlotPolar(Worksheet *p)
 	axis[0].setTickLabelPrecision(0);
 }
 
+PlotPolar::~PlotPolar() {
+	delete graphlist;
+
+	delete title;
+	delete markx;
+	delete marky;
+
+	delete region;
+}
+
 //! Infos for project explorer
 QStringList PlotPolar::Info() {
 	QStringList s;
@@ -41,20 +51,20 @@ QStringList PlotPolar::Info() {
 		s<<QString("yes");
 	else
 		s<<QString("no");
-	s<<bgcolor.name();
-	s<<gbgcolor.name();
+	s<<bgcolor.color().name();
+	s<<gbgcolor.color().name();
 
 	return s;
 }
 
 void PlotPolar::draw(QPainter *p, int w, int h) {
 	kdDebug()<<"PlotPolar::draw() w/h : "<<w<<' '<<h<<endl;
-	
+
 	if(aspect_enabled) {	// set aspect ratio to 1
 		int wsize = (int) fmin(w,h);
 		w=h=wsize;
 	}
-		
+
 	int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	int xmax = (int)(w*(size.X()*p2.X()+position.X()));
 	int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
@@ -98,7 +108,7 @@ void PlotPolar::drawCurves(QPainter *p, int w, int h) {
 
 	kdDebug()<<"xmin/xmax ymin/ymax : "<<xmin<<'/'<<xmax<<' '<<ymin<<'/'<<ymax<<endl;
 	kdDebug()<<"width/height : "<<w<<'/'<<h<<endl;
-	
+
 	// TODO : tic color ???
 	p->setPen(Qt::black);
 
@@ -136,48 +146,93 @@ void PlotPolar::drawCurves(QPainter *p, int w, int h) {
 	int xw = xmax-xmin, yh = ymax-ymin;
 	int prec = axis[1].TickLabelPrecision();
 	TFormat atlf = axis[1].TickLabelFormat();
-	if (axis[1].Enabled())  {
+	if (axis[1].Enabled() && axis[1].tickLabelEnabled())  {
+		QFont f = axis[1].TickLabelFont();
+		f.setPointSize((int)(f.pointSize()*size.X())); //  scale font size with plot
+		QFontMetrics fm(f);
+		QColor c = axis[1].TickLabelColor();
+		double offset = axis[1].Shift();
+		double scaling = axis[1].Scaling();
+		double pos = axis[1].TickLabelPosition();
+
 		for (int i=0;i<major_tics+1;i++) {
 			double value = i/(double)major_tics*maxy;
-		
-			QString label = TicLabel(atlf,prec,axis[1].DateTimeFormat(),value);	
+
+			QString label = TicLabel(atlf,prec,axis[1].DateTimeFormat(),scaling*value+offset);
 
 			// apply prefix & suffix
 			label.prepend(axis[1].TickLabelPrefix());
 			label.append(axis[1].TickLabelSuffix());
 
-			// TODO : use richtext drawing for richtext strings (see Plot2D.h : "draw it")
-			
-			//  scale font size with plot
-			QFont f = axis[1].TickLabelFont();
-			f.setPointSize((int)(f.pointSize()*size.X()));
-			p->setFont(f);
-			p->drawText(xmin+(int)(xw/2+i/(double)major_tics*xw/16)+5,
-				ymin+(int)(yh/2-i/(double)major_tics*yh/2),label);
+			p->save();
+			p->translate(xmin+(int)(xw/2+i/(double)major_tics*xw/16)-10+pos,ymin+(int)(yh/2-i/(double)major_tics*yh/2)-15+pos);
+			p->rotate(axis[1].TickLabelRotation());
+			if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
+				p->setPen(c);
+				p->setFont(f);
+
+				p->drawText(-fm.width(label)/2,fm.ascent()/2,label);
+			}
+			else {  // rich text label
+				QSimpleRichText *richtext = new QSimpleRichText(label,f);
+				QColorGroup cg;
+				cg.setColor(QColorGroup::Text,c);
+
+				richtext->draw(p,-richtext->width()/4, -fm.ascent()/2,QRect(),cg);
+				delete richtext;
+			}
+			p->restore();
 		}
 	}
-	
+
 	// phi values
-	if (axis[0].Enabled()) {
+	if (axis[0].Enabled() && axis[0].tickLabelEnabled()) {
 		prec = axis[0].TickLabelPrecision();
 		atlf = axis[0].TickLabelFormat();
-		for (int i=0;i<12;i++) {
-			double rx = xw/2+20, ry = yh/2+20;
-			double phi =30.0*i*M_PI/180.0;	
 
-			QString label = TicLabel(atlf,prec,axis[0].DateTimeFormat(),phi);
+		QFont f = axis[0].TickLabelFont();
+		f.setPointSize((int)(f.pointSize()*size.X()));	//  scale font size with plot
+		QFontMetrics fm(f);
+		QColor c = axis[0].TickLabelColor();
+		double pos = 2.0*axis[0].TickLabelPosition();
+		double offset = axis[0].Shift();
+		double scaling = axis[0].Scaling();
+		double direction = 1.0;
+		if(scaling < 0.0) {
+			scaling *= -1.0;
+			direction = -1.0;
+		}
+		double rx = xw/2+pos, ry = yh/2+pos;
+		for (int i=0;i<12;i++) {
+			double phi = 30.0*i*M_PI/180.0;
+
+			QString label = TicLabel(atlf,prec,axis[0].DateTimeFormat(),phi*scaling);
 
 			// apply prefix & suffix
 			label.prepend(axis[0].TickLabelPrefix());
 			label.append(axis[0].TickLabelSuffix());
 
-			// TODO : use richtext drawing for richtext strings (see Plot2D.h)		
-			
-			//  scale font size with plot
-			QFont f = axis[0].TickLabelFont();
-			f.setPointSize((int)(f.pointSize()*size.X()));
-			p->setFont(f);
-			p->drawText((int)(xmin+xw/2+rx*cos(phi)-10),(int)(ymin+yh/2-ry*sin(phi)+5),label);
+			phi += offset*M_PI/180.0;
+			phi *= direction;
+
+			p->save();
+			p->translate((int)(xmin+xw/2+rx*cos(phi)-5),(int)(ymin+yh/2-ry*sin(phi)));
+			p->rotate(axis[0].TickLabelRotation());
+			if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
+				p->setPen(c);
+				p->setFont(f);
+
+				p->drawText(-fm.width(label)/2,fm.ascent()/2,label);
+			}
+			else {  // rich text label
+				QSimpleRichText *richtext = new QSimpleRichText(label,f);
+				QColorGroup cg;
+				cg.setColor(QColorGroup::Text,c);
+
+				richtext->draw(p,-richtext->width()/4, -fm.ascent()/2,QRect(),cg);
+				delete richtext;
+			}
+			p->restore();
 		}
 	}
 
@@ -200,25 +255,25 @@ void PlotPolar::drawCurves(QPainter *p, int w, int h) {
 		p->drawLine((int)(xmin+xw/2+rx*cos(phi)),(int)(ymin+yh/2-ry*sin(phi)),
 			(int)(xmin+xw/2+rx*cos(phi+M_PI)),(int)(ymin+yh/2-ry*sin(phi+M_PI)));
 	}
-		
+
 	// clipping rect with some space (clipoffset)
 	p->setClipRect(xmin-clipoffset,ymin-clipoffset,xmax-xmin+2*clipoffset,ymax-ymin+2*clipoffset);
-	
+
 	// draw curves
 	for (unsigned int nr=0; nr < graphlist->Number() ; nr++) {
 		if(graphlist->getGraph(nr)->isShown() == false)
 			continue;
-		
-		GRAPHType s = graphlist->getStruct(nr);
+
+		GRAPHType s = graphlist->getType(nr);
 		if (s == GRAPH2D) {
-			Graph2D *g = graphlist->getGraph2D(nr);	
+			Graph2D *g = graphlist->getGraph2D(nr);
 
 			kdDebug()<<"GRAPH2D / 2D number="<<g->Number()<<endl;
 
 			Point *d = g->Data();
 			int N = g->Number();
 			Style *style =  g->getStyle();
-			Symbol *symbol = g->getSymbol();	
+			Symbol *symbol = g->getSymbol();
 
 			double oldx=0.0, oldy=0.0;
 			QPointArray pa(N);
@@ -226,13 +281,13 @@ void PlotPolar::drawCurves(QPainter *p, int w, int h) {
 			for (int i=0;i<N;i++) {
 				if(d[i].Masked())
 					continue;
-				
+
 				if(worksheet->getMainWin()->speedMode()) {
 					int mod = (int) (N/worksheet->getMainWin()->speedModeValue());
 					if(mod==0) mod=1;
 					if(i%mod != 0) continue;	// speed mode
 				}
-				
+
 				double phi = d[i].X(), r =  d[i].Y();
 
 				int x = xmin+xw/2+(int)(r/maxy*xw/2*cos(phi));
