@@ -8,7 +8,7 @@
 class PlotPolar:public Plot {
 public:
 	PlotPolar(Worksheet *p);
-	~PlotPolar() {}
+	~PlotPolar();
 	QStringList Info();
 	Axis *getAxis(int i) { return &axis[i]; }
 	void saveAxes(QTextStream *t);
