@@ -24,6 +24,15 @@ PlotTernary::PlotTernary(Worksheet *p)
 	axis.setMajorTicks(6);
 }
 
+PlotTernary::~PlotTernary() {
+	delete graphlist;
+
+	delete title;
+	delete markx;
+	delete marky;
+	delete region;
+}
+
 //! Infos for project explorer
 QStringList PlotTernary::Info() {
 	QStringList s;
@@ -35,19 +44,19 @@ QStringList PlotTernary::Info() {
 		s<<QString("yes");
 	else
 		s<<QString("no");
-	s<<bgcolor.name();
-	s<<gbgcolor.name();
+	s<<bgcolor.color().name();
+	s<<gbgcolor.color().name();
 
 	return s;
 }
 
 void PlotTernary::draw(QPainter *p, int w, int h) {
 	kdDebug()<<"PlotTernary::draw() w/h : "<<w<<' '<<h<<endl;
-	
+
 	if(aspect_enabled) {	// set aspect ratio to 1
 		int wsize = (int) fmin(w,h);
 		w=h=wsize;
-	}	
+	}
 
 	if (!transparent) {
 		// background color
@@ -79,13 +88,13 @@ void PlotTernary::drawCurves(QPainter *p, int w, int h) {
 	int ymax = (int)(h*(size.Y()*p2.Y()+position.Y()));
 
 	xmax-=20;	// some space for tic label
-	
+
 	double maxx = actrange[0].rMax();
 	kdDebug()<<"maxx = "<<maxx<<endl;
 
 	kdDebug()<<"xmin/xmax ymin/ymax : "<<xmin<<'/'<<xmax<<' '<<ymin<<'/'<<ymax<<endl;
 	kdDebug()<<"width/height : "<<w<<'/'<<h<<endl;
-	
+
 	// TODO : tic color ???
 	p->setPen(Qt::black);
 
@@ -96,7 +105,7 @@ void PlotTernary::drawCurves(QPainter *p, int w, int h) {
 		p->drawLine(xmin,ymax,(int)(xmax+xmin)/2,ymin);
 		p->drawLine(xmax,ymax,(int)(xmax+xmin)/2,ymin);
 	}
-	
+
 	// TODO : use 3 custom axes label, use label properties
 	QFont font = worksheet->getMainWin()->defaultFont();
 	font.setPointSize((int)(0.7*font.pointSize()));
@@ -105,7 +114,7 @@ void PlotTernary::drawCurves(QPainter *p, int w, int h) {
 	p->drawText((xmax+xmin)/2-10,ymax+40,QString("a"));
 	p->drawText(xmax-(xmax-xmin)/5+10,(ymax+ymin)/2,QString("b"));
 	p->drawText(xmin+(xmax-xmin)/5-10,(ymax+ymin)/2,QString("c"));
-	
+
 	int major_tics = (int) axis.MajorTicks();
 	if(major_tics==-1)
 		major_tics=autoTicks(0,maxx);
@@ -118,7 +127,7 @@ void PlotTernary::drawCurves(QPainter *p, int w, int h) {
 		 int y2 = ymin+i*(ymax-ymin)/(major_tics-1);
 		 int x3 = xmax-i*(xmax-xmin)/(2*(major_tics-1));
 		 int y3 = ymax-i*(ymax-ymin)/(major_tics-1);
-	
+
 		// major tics & tic label
 		if (axis.MajorTicksEnabled()) {
 			p->setPen(QPen(axis.TickColor(),axis.majorTickWidth()));
@@ -126,13 +135,13 @@ void PlotTernary::drawCurves(QPainter *p, int w, int h) {
 			p->drawLine(x1,ymax,x1-7,ymax+7);
 			p->drawLine(x2-7,y2-7,x2,y2);
 			p->drawLine(x3+10,y3,x3,y3);
-	
+
 			// tic label		TODO : tic label format
 			QFont f = axis.TickLabelFont();
 			f.setPointSize((int)(f.pointSize()*size.X()));
 			p->setFont(f);
 			p->setPen(axis.TickLabelColor());
-	
+
 			QString label = QString::number(maxx*i/(major_tics-1));
 			QFontMetrics fm(axis.TickLabelFont());
 			p->save();	// a
@@ -157,29 +166,29 @@ void PlotTernary::drawCurves(QPainter *p, int w, int h) {
 			p->drawLine(x2,y2,xmax+xmin-x2,y2);
 			p->drawLine(x3,y3,xmax+xmin-x1,ymax);
 		}
-		
+
 		// TODO : minor tics
 		// TODO : minor grid
 	}
-	
+
 	// TODO : clipping rect with some space (clipoffset)
 	//p->setClipRect(xmin-clipoffset,ymin-clipoffset,xmax-xmin+2*clipoffset,ymax-ymin+2*clipoffset);
-	
+
 	// draw curves
 	for (unsigned int nr=0; nr < graphlist->Number() ; nr++) {
 		if(graphlist->getGraph(nr)->isShown() == false)
 			continue;
-		
-		GRAPHType s = graphlist->getStruct(nr);
+
+		GRAPHType s = graphlist->getType(nr);
 		if (s == GRAPH3D) {
-			Graph3D *g = graphlist->getGraph3D(nr);	
+			Graph3D *g = graphlist->getGraph3D(nr);
 
 			kdDebug()<<"GRAPH3D / 3D number="<<g->Number()<<endl;
 
 			Point3D *d = g->Data();
 			int N = g->Number();
 			Style *style =  g->getStyle();
-			Symbol *symbol = g->getSymbol();	
+			Symbol *symbol = g->getSymbol();
 
 			double oldx=0.0, oldy=0.0;
 			QPointArray pa(N);
@@ -187,13 +196,13 @@ void PlotTernary::drawCurves(QPainter *p, int w, int h) {
 			for (int i=0;i<N;i++) {
 				if(d[i].Masked())
 					continue;
-				
+
 				if(worksheet->getMainWin()->speedMode()) {
 					int mod = (int) (N/worksheet->getMainWin()->speedModeValue());
 					if(mod==0) mod=1;
 					if(i%mod != 0) continue;	// speed mode
 				}
-				
+
 				double a = d[i].X(), c = d[i].Z();
 
 				// point 1 :  a baseline
@@ -202,20 +211,20 @@ void PlotTernary::drawCurves(QPainter *p, int w, int h) {
 				// point 2 : b baseline
 				double p2x=xmin+a/maxx*(xmax-xmin);
 				double p2y=ymax;
-				
+
 				int y = (int) (p1y+(int)(c/maxx*(ymax-ymin)));
 				int x = (int) (p1x+(y-p1y)/(p2y-p1y)*(p2x-p1x));
-				
+
 				// fix possible problem
 				if (a==maxx)
 					x=xmax;
-				
+
 //				kdDebug()<<"POINT "<<i<<endl;
 //				kdDebug()<<"p1 = "<<p1x<<'/'<<p1y<<endl;
 //				kdDebug()<<"p2 = "<<p2x<<'/'<<p2y<<endl;
 //	test line		p->drawLine(p1x,p1y,p2x,p2y);
 //				kdDebug()<<"x/y = "<<x<<' '<<y<<endl;
-				
+
 				pa[pointindex++]=QPoint(x,y);
 				oldx=x;oldy=y;
 			}
