@@ -18,12 +18,12 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	: QWidget(parent,name), l(label)
 {
 	greek = QFont(QString("Greek Times"));
-	
+
 	QGroupBox *gb = new QGroupBox(1,QGroupBox::Horizontal,QString(""),parent);
 
 	QHBox *hb = new QHBox(gb);
 	new QLabel(i18n("Position : "),hb);
-	
+
 	hb = new QHBox(gb);
 	new QLabel(QString("x : "),hb);
 	xle = new KLineEdit(QString::number(l->X()),hb);
@@ -31,9 +31,10 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	new QLabel(QString(" y : "),hb);
 	yle = new KLineEdit(QString::number(l->Y()),hb);
 	yle->setValidator(new QDoubleValidator(0.0,1.0,3,yle));
-	
+
 	hb = new QHBox(gb);
 	texcb = new QCheckBox(i18n("TeX label"),hb);
+	QObject::connect(texcb,SIGNAL(toggled(bool)),this,SLOT(texChanged(bool)));
 	if(qwtplot)
 		texcb->hide();
 
@@ -54,12 +55,12 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 		boxedcb->hide();
 		rotle->hide();
 	}
-	
+
 	hb = new QHBox(gb);
-	new QLabel(i18n("Font : "),hb); 
+	new QLabel(i18n("Font : "),hb);
 	titleFont = new KLineEdit(QString(""),hb);
 	titleFont->setMaximumWidth(200);
-	KPushButton *newtitleFont = new KPushButton(i18n("Change"),hb);
+	newtitleFont = new KPushButton(i18n("Change"),hb);
 	QObject::connect(newtitleFont,SIGNAL(clicked()),SLOT(selectFont()));
 
 	hb = new QHBox(gb);
@@ -105,7 +106,7 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	kcb = new KColorButton(l->Color(),hb);
 	kcb->setMaximumWidth(150);
 	QObject::connect(kcb,SIGNAL(changed(const QColor &)),this,SLOT(setTEColor()));
-	
+
 	KPushButton *smallgreekpb = new KPushButton( QString("\341"), hb );
 	sgletters = new KPopupMenu();
 	sgletters->setFont(greek);
@@ -127,9 +128,9 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	QObject::connect(oletters,SIGNAL(activated(int)),SLOT(insertChar(int)));
 	otherpb->setPopup(oletters);
 	for (int i=0;i<222;i++) {
-		oletters->insertItem(QString(QChar(i+161)),i+1161);	// +1000 to avoid crossing with greeks 
+		oletters->insertItem(QString(QChar(i+161)),i+1161);	// +1000 to avoid crossing with greeks
 	}
-	
+
 	smallgreekpb->setMaximumWidth(40);
 	biggreekpb->setMaximumWidth(40);
 	otherpb->setMaximumWidth(40);
@@ -142,26 +143,67 @@ RichTextWidget::RichTextWidget(QWidget *parent, Label *label, const char *name,
 	update();
 }
 
+RichTextWidget::~RichTextWidget() {
+	// CRASHES TitleDialog
+
+	delete oletters;
+	delete bgletters;
+	delete sgletters;
+}
+
 void RichTextWidget::update() {
 	kdDebug()<<"RTW::update()"<<endl;
-	
+
 	xle->setText(QString::number(l->X()));
 	yle->setText(QString::number(l->Y()));
-	
+
 	texcb->setChecked(l->isTeXLabel());
-	
+
 	boxedcb->setChecked(l->Boxed());
 	transcb->setChecked(l->Transparent());
 	bgcolor->setColor(l->BackgroundColor());
-	
+
 	rotle->setText(QString::number(l->Rotation()));
-	
+
 	te->setFont(l->Font());
 	titleFont->setText(l->Font().family() + " " + QString::number(l->Font().pointSize()));
 	te->setText(l->Title());
 	kcb->setColor(l->Color());
 }
 
+void RichTextWidget::texChanged(bool b) {
+	if(b) {
+		kcb->setEnabled(false);
+		bgcolor->setEnabled(false);
+		transcb->setEnabled(false);
+		bold->setEnabled(false);
+		italic->setEnabled(false);
+		underline->setEnabled(false);
+		superscript->setEnabled(false);
+		subscript->setEnabled(false);
+		sgletters->setEnabled(false);
+		bgletters->setEnabled(false);
+		oletters->setEnabled(false);
+		titleFont->setEnabled(false);
+		newtitleFont->setEnabled(false);
+	}
+	else {
+		kcb->setEnabled(true);
+		bgcolor->setEnabled(true);
+		transcb->setEnabled(true);
+		bold->setEnabled(true);
+		italic->setEnabled(true);
+		underline->setEnabled(true);
+		superscript->setEnabled(true);
+		subscript->setEnabled(true);
+		sgletters->setEnabled(true);
+		bgletters->setEnabled(true);
+		oletters->setEnabled(true);
+		titleFont->setEnabled(true);
+		newtitleFont->setEnabled(true);
+	}
+}
+
 void RichTextWidget::insertChar(int ch) {
 	te->setFamily(QString("Adobe Times"));
 	te->insert(QString(QChar(ch-1000)));
@@ -259,12 +301,12 @@ void RichTextWidget::apply() {
 	l->setTeXLabel(texcb->isChecked());
 	if(l->isTeXLabel())
 		te->setTextFormat(Qt::PlainText);
-	kdDebug()<<"RichTextWidget::apply() : text = "<<te->text()<<endl;
-	kdDebug()<<"	RICHTEXT = "<<te->text()<<endl;
+//	kdDebug()<<"RichTextWidget::apply()"<<endl;
+//	kdDebug()<<"	RICHTEXT = "<<te->text()<<endl;
 
 	// doesn't work :-(
 /*	const QChar *utf8text = te->text().unicode();
-	
+
 	te->setTextFormat(Qt::PlainText);
 	kdDebug()<<"	PLAINTEXT = "<<te->text().utf8()<<endl;
 	kdDebug()<<"	PLAINTEXT = "<<te->text().local8Bit()<<endl;
