@@ -3,13 +3,13 @@
 #include "SmoothListDialog.h"
 #include "defs.h"
 
-SmoothListDialog::SmoothListDialog(MainWin *mw, const char *name)
-	: ListDialog(mw, name)
+SmoothListDialog::SmoothListDialog(MainWin *m, const char *name)
+	: ListDialog(m, name)
 {
 	setCaption(i18n("Smooth Dialog"));
 	KConfig *config = mw->Config();
 	config->setGroup( "Smooth" );
-	
+
 	QTabWidget *tw = new QTabWidget(vbox);
 	QVBox *tab1 = new QVBox(tw);
 
@@ -29,9 +29,9 @@ SmoothListDialog::SmoothListDialog(MainWin *mw, const char *name)
 
 	tw->addTab(tab1,i18n("Parameter"));
 	tw->addTab(styletab,i18n("Style"));
-	
+
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
-        QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
+	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(save,SIGNAL(clicked()),SLOT(saveSettings()));
 
 	setMinimumWidth(vbox->minimumSizeHint().width());
@@ -53,16 +53,16 @@ int SmoothListDialog::apply_clicked() {
 		KMessageBox::error(this,i18n("n is even!\nPlease choose an uneven number."));
 		return -1;
 	}
-	
+
 	if(s) {
 		QTable *table = s->Table();
 		int col = table->currentColumn();
-		
+
 		if(n >= table->numRows()) {
 			KMessageBox::error(this,i18n("n bigger than number of rows!\nPlease use a smaller value."));
 			return -1;
 		}
-		
+
 		// add column if needed
 		bool empty=true;
 		for(int i=0;i<table->numRows();i++) {
@@ -80,13 +80,13 @@ int SmoothListDialog::apply_clicked() {
 				sum+=table->text(i+j,col).toDouble();
 			}
 			sum = sum/n;
-			
+
 			// insert into last column
 			table->setText(i+n/2,newcol,QString::number(sum));
 		}
 		return 0;
 	}
-	
+
 	GraphList *gl = p->getPlot(p->API())->getGraphList();
 	if(gl->Number()==0) {
 		KMessageBox::error(this,i18n("No graph found!"));
@@ -94,27 +94,27 @@ int SmoothListDialog::apply_clicked() {
 	}
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
 
-	GRAPHType st = gl->getStruct(item);
-	
+	GRAPHType st = gl->getType(item);
+
 	Style *style=0;
 	Symbol *symbol=0;
-	
+
 	if(st != GRAPHM) {
-		style = new Style(cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
+		style = new Style((StylesType)cb2->currentItem(),color->color(),filled->isChecked(),fcolor->color(),
 			width->value(),pencb->currentItem(),brushcb->currentItem());
 		style->setBoxWidth(boxwidth->value());
 		style->setAutoBoxWidth(autobox->isChecked());
 		style->setPointsSorting(sortpointscb->isChecked());
 		symbol = new Symbol((SType)symbolcb->currentItem(),scolor->color(),ssize->value(),
-			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());	
+			(FType)symbolfillcb->currentItem(),sfcolor->color(),sbrushcb->currentItem());
 	}
-	
+
 	if (st == GRAPH2D) {
 		Graph2D *g = gl->getGraph2D(item);
 		int nx = g->Number();
 		Point *ptr = new Point[nx];
 		Point *a = g->Data();
-		QString label = g->getLabel()->simpleTitle();	
+		QString label = g->getLabel()->simpleTitle();
 
 		if(n >= nx) {
 			KMessageBox::error(this,i18n("n bigger than number of points!\nPlease use a smaller value."));
@@ -140,19 +140,19 @@ int SmoothListDialog::apply_clicked() {
 		LRange range[2];
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
-		
+
 		QString fun = QString(i18n("smooth (")+QString::number(n)+i18n(") of ")+label);
-		
+
 		Graph2D *ng = new Graph2D(fun,fun,range,SSPREADSHEET,P2D,style,symbol,ptr,nx-n+1);
 		mw->addGraph2D(ng,sheetcb->currentItem());
 	}
 	else if (st == GRAPH3D) {
 		Graph3D *g = gl->getGraph3D(item);
 		int nx = g->Number();
-		QString label = g->getLabel()->simpleTitle();	
+		QString label = g->getLabel()->simpleTitle();
 		Point3D *ptr = new Point3D[nx];
 		Point3D *a = g->Data();
-		
+
 		if(n >= nx) {
 			KMessageBox::error(this,i18n("n bigger than number of points!\nPlease use a smaller value."));
 			return -1;
@@ -187,9 +187,9 @@ int SmoothListDialog::apply_clicked() {
 		range[0] = LRange(xmin,xmax);
 		range[1] = LRange(ymin,ymax);
 		range[2] = LRange(zmin,zmax);
-		
+
 		QString fun = QString(i18n("smooth (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
-		
+
 		Graph3D *ng = new Graph3D(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,nx-n+1,1);
 		ng->setNumberX((int)(g->NX()-n));
 		ng->setNumberY((int)(g->NY()));
@@ -224,7 +224,7 @@ int SmoothListDialog::apply_clicked() {
 
 			ptr[i].setPoint(x,y,z,t);
 		}
-		
+
 		mw->calculateRanges4D(ptr,nx-n+1,&xmin,&xmax,&ymin,&ymax,&zmin,&zmax,&tmin,&tmax);
 
 		// create the new Graph
@@ -233,9 +233,9 @@ int SmoothListDialog::apply_clicked() {
 		range[1] = LRange(ymin,ymax);
 		range[2] = LRange(zmin,zmax);
 		range[3] = LRange(tmin,tmax);
-		
+
 		QString fun = QString(i18n("smooth (")+QString::number(n)+i18n(") of ")+g->getLabel()->simpleTitle());
-		
+
 		Graph4D *ng = new Graph4D(fun,fun,range,SSPREADSHEET,type,style,symbol,ptr,nx-n+1,gtype);
 		mw->addGraph4D(ng,sheetcb->currentItem());
 	}
@@ -243,8 +243,8 @@ int SmoothListDialog::apply_clicked() {
 		//TODO
 		KMessageBox::error(this,i18n("Sorry. This function is not yet implemented!"));
 		return -3;
-	}	
-	
+	}
+
 	updateList();
 
 	return 0;
