@@ -14,11 +14,11 @@
 #include <LTable.h>
 #endif
 
-#ifdef HAVE_UNDO
+/*#ifdef HAVE_UNDO
 extern "C" {
 #include "undo.h"
 }
-#endif
+#endif*/
 
 #include <new>
 
@@ -41,10 +41,6 @@ public:
 	WidgetType getWidgetType() { return widgettype; }
 	QStringList Info();
 	MainWin *getMainWin() { return mw; }
-#ifdef HAVE_UNDO
-	UNDO *getUndo();
-	void setUndo(UNDO *u);
-#endif
 #ifdef USE_NEW_TABLE
 	LTable *Table() { return table; }
 #else
@@ -59,8 +55,11 @@ public:
 public slots:
 	void Menu(QPopupMenu *menu);				//!< open context menu
 	void updateValuesDialog();
+	void selectionChanged();
 	QString Title() const { return title; }			//!< get title
 	void setTitle(QString t="");				//!< set spreadsheet title
+	QString Notes() const { return notes; }			//!< get notes
+	void setNotes(QString notes="");			//!< set spreadsheet notes
 	void setListDialog(ListDialog *l) {ld=l; setCaption(i18n("Spreadsheet")+QString(" : ")+i18n("Edit data") ); }
 	void setGraph(Graph *g) { graph=g; }
 	QStringList columnInfo(int col);			//!< get info about column col
@@ -72,6 +71,9 @@ public slots:
 	void setColumnFormat(int col, QString format=0);
 	void Clear();								//!< clear spreadsheet	
 	int filledRows(int col=1);
+	int selectedColumns();
+	int selectedRows();
+	int getColumnIndex(QString title);			//!< get the index of the column with name title
 
 	void plot2DSimple() { plot2D(P2D,false); }	//!< make a simple 2d plot of all selected columns
 	void plot2DPie() { plot2D(PPIE,false); }		//!< make a pie plot of all selected columns
@@ -93,7 +95,7 @@ public slots:
 
 	void selectDestination();						//!< select destination for plot
 	int Destination() { return destination; }
-	void setDestination(int d) { destination=d; }
+	void setDestination(int v) { destination=v; }
 	
 	void addGraph2D(Graph2D *g);					// add data from graph 2d
 	void addGraph3D(Graph3D *g);					// add data from graph 3d
@@ -122,6 +124,7 @@ public slots:
 	void normSum();							//!< normalize current column to sum = 1.0
 	void normMax(double max=1.0);				//!< normalize current column to maximum = max
 	void convertComma();						//!< replace all ',' with '.'
+	void convertFORTRAN();						//!< replace all 'd' and 'D' with 'e'
 	void transposeMatrix();						//!< transpose spreadsheet matrix
 	void convertMatrixtoXYZ();					//!< convert matrix data to x-y-z data
 	void convertXYZtoMatrix();					//!< convert x-y-z data to matrix data
@@ -165,6 +168,7 @@ private:
 	void sort();
 	void qsort(int s, int e);
 	void updateGraphList();
+	void setColumnNames(int nrcols);
 	void contextMenuEvent(QContextMenuEvent *);
 	void mousePressEvent ( QMouseEvent *);
 	void resizeEvent(QResizeEvent *);
@@ -172,21 +176,19 @@ private:
 	MainWin *mw;
 	WidgetType widgettype;
 	QString title;
+	QString notes;			// notes string
 #ifdef USE_NEW_TABLE
 	LTable *table;
 #else
 	QTable *table;
 #endif
-#ifdef HAVE_UNDO
-//	UNDO *undo;
-#endif
-	ListDialog *ld;			// used when editing data from list dialog
+	ListDialog *ld;				// used when editing data from list dialog
 	SpreadsheetValuesDialog *values_dialog;
 	Graph *graph;				// used for editing
 	GRAPHType gtype;			// -""-
 	QString datafile;			// used for online data
-	QString tmpfilename;	// tmp filename for editing with editor
-	bool ascending;		// for sorting a column
+	QString tmpfilename;			// tmp filename for editing with editor
+	bool ascending;				// for sorting a column
 	int destination;			// for plots
 	QPopupMenu *plotmenu, *destmenu, *selmenu, *fillmenu, *normmenu;
 	QPopupMenu *editmenu, *convertmenu, *sortmenu, *maskmenu;
