@@ -12,14 +12,14 @@ class SpreadsheetPropertiesDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	SpreadsheetPropertiesDialog(QTable *t, QString name);
-public slots:
-	void ok_clicked() { apply_clicked(); accept(); }
-	void apply_clicked();
+	SpreadsheetPropertiesDialog(MainWin *mw, QTable *t, QString name);
 private:
 	QTable *table;
 	KComboBox *typecb, *formatcb;
 	KLineEdit *labelle, *rowle;
+private slots:
+	void ok_clicked() { apply_clicked(); accept(); }
+	void apply_clicked();
 };
 
 #endif //SPREADSHEETPROPERTIESDIALOG_H
