@@ -13,8 +13,8 @@
 
 using namespace std;
 
-TitleDialog::TitleDialog(MainWin *mw, const char *name)
-	: Dialog(mw, name)
+TitleDialog::TitleDialog(MainWin *m, const char *name)
+	: Dialog(m, name)
 {
 	kdDebug()<<"TitleDialog()"<<endl;
 	setCaption(i18n("Title Settings")+i18n(" : ")+QString(name));
@@ -30,7 +30,7 @@ TitleDialog::TitleDialog(MainWin *mw, const char *name)
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	save->setEnabled(false);
-	
+
 	setMinimumWidth(2*vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
@@ -38,7 +38,7 @@ TitleDialog::TitleDialog(MainWin *mw, const char *name)
 
 void TitleDialog::updateDialog() {
 	p = mw->activeWorksheet();
-	
+
 	if(p != 0) {
 		Plot *plot = p->getPlot(p->API());
 		if(plot != 0) {
@@ -50,9 +50,9 @@ void TitleDialog::updateDialog() {
 
 int TitleDialog::apply_clicked() {
 	kdDebug()<<"TitleDialog::apply_clicked()"<<endl;
-	
+
 	title = rtw->label();
-	
+
 	mw->updateSheetList();
 	p->updatePixmap();
 
@@ -61,5 +61,5 @@ int TitleDialog::apply_clicked() {
 
 void TitleDialog::ok_clicked() {
 	apply_clicked();
-	accept();	
+	accept();
 }
